@@ -25,24 +25,15 @@
 #include <gio/gio.h>
 #include <pk-backend.h>
 
-extern PkBackend *backend;
-extern GCancellable *cancellable;
+typedef struct {
+	gsize		environment_initialized;
+	alpm_db_t	*localdb;
+	alpm_list_t	*syncfirsts;
+	alpm_list_t	*holdpkgs;
+	alpm_handle_t	*alpm;
+} PkBackendAlpmPrivate;
 
-extern alpm_handle_t *alpm;
-extern alpm_db_t *localdb;
+void		 pk_alpm_run		(PkBackendJob *job, PkStatusEnum status,
+					 PkBackendJobThreadFunc func, gpointer data);
 
-extern gchar *xfercmd;
-extern alpm_list_t *holdpkgs;
-extern alpm_list_t *syncfirsts;
-
-gint		 pk_backend_fetchcb	(const gchar *url, const gchar *path,
-					 gint force);
-
-void		 pk_backend_run		(PkBackend *self, PkStatusEnum status,
-					 PkBackendThreadFunc func);
-
-void		 pk_backend_cancel	(PkBackend *self);
-
-gboolean	 pk_backend_cancelled	(PkBackend *self);
-
-gboolean	 pk_backend_finish	(PkBackend *self, GError *error);
+gboolean	 pk_alpm_finish		(PkBackendJob *job, GError *error);
