@@ -23,6 +23,7 @@
 #include <apt-pkg/cachefile.h>
 #include <pk-backend.h>
 
+class pkgProblemResolver;
 class AptCacheFile : public pkgCacheFile
 {
 public:
@@ -125,6 +126,13 @@ public:
      */
     std::string getLongDescriptionParsed(const pkgCache::VerIterator &ver);
 
+    bool tryToInstall(pkgProblemResolver &Fix,
+                      const pkgCache::VerIterator &ver,
+                      bool BrokenFix);
+
+    void tryToRemove(pkgProblemResolver &Fix,
+                     const pkgCache::VerIterator &ver);
+
 private:
     void buildPkgRecords();
     static std::string debParser(std::string descr);
