@@ -66,7 +66,7 @@ pk_backend_supports_parallelization (PkBackend *backend)
 /**
  * pk_backend_initialize:
  */
-void pk_backend_initialize(PkBackend *backend)
+void pk_backend_initialize(GKeyFile *conf, PkBackend *backend)
 {
     g_debug("APTcc Initializing");
 
@@ -77,11 +77,19 @@ void pk_backend_initialize(PkBackend *backend)
     // (without using the debconf frontend, PK will freeze)
     setenv("APT_LISTCHANGES_FRONTEND", "debconf", 1);
 
-    // Make sure the config is ready for the get-filters
-    // call which needs to know about multi-arch
-    pkgInitConfig(*_config);
+    // pkgInitConfig makes sure the config is ready for the
+    // get-filters call which needs to know about multi-arch
+    if (!pkgInitConfig(*_config)) {
+        g_debug("ERROR initializing backend configuration");
+    }
 
-    spawn = pk_backend_spawn_new();
+    // pkgInitSystem is needed to compare the changelog verstion to
+    // current package using DoCmpVersion()
+    if (!pkgInitSystem(*_config, _system)) {
+        g_debug("ERROR initializing backend system");
+    }
+
+    spawn = pk_backend_spawn_new(conf);
 //     pk_backend_spawn_set_job(spawn, backend);
     pk_backend_spawn_set_name(spawn, "aptcc");
 }
@@ -136,6 +144,8 @@ PkBitfield pk_backend_get_filters(PkBackend *backend)
                 PK_FILTER_ENUM_DEVELOPMENT,
                 PK_FILTER_ENUM_SUPPORTED,
                 PK_FILTER_ENUM_FREE,
+                PK_FILTER_ENUM_APPLICATION,
+                PK_FILTER_ENUM_DOWNLOADED,
                 -1);
 
     // if we have multiArch support we add the native filter
@@ -200,7 +210,7 @@ void pk_backend_cancel(PkBackend *backend, PkBackendJob *job)
     }
 }
 
-static void backend_get_depends_or_requires_thread(PkBackendJob *job, GVariant *params, gpointer user_data)
+static void backend_depends_on_or_requires_thread(PkBackendJob *job, GVariant *params, gpointer user_data)
 {
     PkRoleEnum role;
     PkBitfield filters;
@@ -219,7 +229,6 @@ static void backend_get_depends_or_requires_thread(PkBackendJob *job, GVariant *
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
     if (!apt->init()) {
         g_debug("Failed to create apt cache");
-        apt->emitFinished();
         return;
     }
 
@@ -235,7 +244,6 @@ static void backend_get_depends_or_requires_thread(PkBackendJob *job, GVariant *
                                       PK_ERROR_ENUM_PACKAGE_ID_INVALID,
                                       "%s",
                                       pi);
-            apt->emitFinished();
             return;
         }
 
@@ -245,11 +253,10 @@ static void backend_get_depends_or_requires_thread(PkBackendJob *job, GVariant *
                                       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
                                       "Couldn't find package %s",
                                       pi);
-            apt->emitFinished();
             return;
         }
 
-        if (role == PK_ROLE_ENUM_GET_DEPENDS) {
+        if (role == PK_ROLE_ENUM_DEPENDS_ON) {
             apt->getDepends(output, ver, recursive);
         } else {
             apt->getRequires(output, ver, recursive);
@@ -258,29 +265,27 @@ static void backend_get_depends_or_requires_thread(PkBackendJob *job, GVariant *
 
     // It's faster to emmit the packages here than in the matching part
     apt->emitPackages(output, filters);
-
-    apt->emitFinished();
 }
 
 /**
- * pk_backend_get_depends:
+ * pk_backend_depends_on:
  */
-void pk_backend_get_depends(PkBackend *backend, PkBackendJob *job, PkBitfield filters,
+void pk_backend_depends_on(PkBackend *backend, PkBackendJob *job, PkBitfield filters,
                             gchar **package_ids, gboolean recursive)
 {
-    pk_backend_job_thread_create(job, backend_get_depends_or_requires_thread, NULL, NULL);
+    pk_backend_job_thread_create(job, backend_depends_on_or_requires_thread, NULL, NULL);
 }
 
 /**
- * pk_backend_get_requires:
+ * pk_backend_required_by:
  */
-void pk_backend_get_requires(PkBackend *backend,
+void pk_backend_required_by(PkBackend *backend,
                              PkBackendJob *job,
                              PkBitfield filters,
                              gchar **package_ids,
                              gboolean recursive)
 {
-    pk_backend_job_thread_create(job, backend_get_depends_or_requires_thread, NULL, NULL);
+    pk_backend_job_thread_create(job, backend_depends_on_or_requires_thread, NULL, NULL);
 }
 
 /**
@@ -302,7 +307,6 @@ static void backend_get_files_thread(PkBackendJob *job, GVariant *params, gpoint
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
     if (!apt->init()) {
         g_debug("Failed to create apt cache");
-        apt->emitFinished();
         return;
     }
 
@@ -310,8 +314,6 @@ static void backend_get_files_thread(PkBackendJob *job, GVariant *params, gpoint
         pk_backend_job_error_code(job,
                                   PK_ERROR_ENUM_PACKAGE_ID_INVALID,
                                   "Invalid package id");
-        pk_backend_job_finished(job);
-        apt->emitFinished();
         return;
     }
 
@@ -323,7 +325,6 @@ static void backend_get_files_thread(PkBackendJob *job, GVariant *params, gpoint
                                       PK_ERROR_ENUM_PACKAGE_ID_INVALID,
                                       "%s",
                                       pi);
-            apt->emitFinished();
             return;
         }
 
@@ -333,14 +334,11 @@ static void backend_get_files_thread(PkBackendJob *job, GVariant *params, gpoint
                                       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
                                       "Couldn't find package %s",
                                       pi);
-            apt->emitFinished();
             return;
         }
 
         apt->emitPackageFiles(pi);
     }
-
-    apt->emitFinished();
 }
 
 /**
@@ -363,7 +361,6 @@ static void backend_get_details_thread(PkBackendJob *job, GVariant *params, gpoi
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
     if (!apt->init()) {
         g_debug ("Failed to create apt cache");
-        apt->emitFinished();
         return;
     }
 
@@ -371,8 +368,6 @@ static void backend_get_details_thread(PkBackendJob *job, GVariant *params, gpoi
         pk_backend_job_error_code(job,
                                   PK_ERROR_ENUM_PACKAGE_ID_INVALID,
                                   "Invalid package id");
-        pk_backend_job_finished(job);
-        apt->emitFinished();
         return;
     }
 
@@ -384,8 +379,6 @@ static void backend_get_details_thread(PkBackendJob *job, GVariant *params, gpoi
     } else {
         apt->emitDetails(pkgs);
     }
-
-    apt->emitFinished();
 }
 
 /**
@@ -414,7 +407,6 @@ static void backend_get_updates_thread(PkBackendJob *job, GVariant *params, gpoi
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
     if (!apt->init()) {
         g_debug("Failed to create apt cache");
-        apt->emitFinished();
         return;
     }
 
@@ -426,8 +418,6 @@ static void backend_get_updates_thread(PkBackendJob *job, GVariant *params, gpoi
 
     apt->emitUpdates(updates, filters);
     apt->emitPackages(blocked, filters, PK_INFO_ENUM_BLOCKED);
-
-    apt->emitFinished();
 }
 
 /**
@@ -440,59 +430,34 @@ void pk_backend_get_updates(PkBackend *backend, PkBackendJob *job, PkBitfield fi
 
 static void backend_what_provides_thread(PkBackendJob *job, GVariant *params, gpointer user_data)
 {
-    PkProvidesEnum provides;
     PkBitfield filters;
     const gchar *provides_text;
     gchar **values;
     bool error = false;
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
 
-    g_variant_get(params, "(tu^a&s)",
+    g_variant_get(params, "(t^a&s)",
                   &filters,
-                  &provides,
                   &values);
 
     pk_backend_job_set_status(job, PK_STATUS_ENUM_QUERY);
 
     // We can handle libraries, mimetypes and codecs
-    if (provides == PK_PROVIDES_ENUM_SHARED_LIB ||
-            provides == PK_PROVIDES_ENUM_MIMETYPE ||
-            provides == PK_PROVIDES_ENUM_CODEC ||
-            provides == PK_PROVIDES_ENUM_ANY) {
-        if (!apt->init()) {
-            g_debug("Failed to create apt cache");
-            g_strfreev(values);
-            apt->emitFinished();
-            return;
-        }
-
-        pk_backend_job_set_status(job, PK_STATUS_ENUM_QUERY);
-
-        PkgList output;
-        if (provides == PK_PROVIDES_ENUM_SHARED_LIB) {
-            apt->providesLibrary(output, values);
-        } else if (provides == PK_PROVIDES_ENUM_MIMETYPE) {
-            apt->providesMimeType(output, values);
-        } else if (provides == PK_PROVIDES_ENUM_CODEC) {
-            apt->providesCodec(output, values);
-        } else {
-            // PK_PROVIDES_ENUM_ANY, just search for everything a package can provide
-            apt->providesLibrary(output, values);
-            apt->providesCodec(output, values);
-            apt->providesMimeType(output, values);
-        }
-
-        // It's faster to emit the packages here rather than in the matching part
-        apt->emitPackages(output, filters);
-    } else {
-        provides_text = pk_provides_enum_to_string(provides);
-        pk_backend_job_error_code(job,
-                                  PK_ERROR_ENUM_NOT_SUPPORTED,
-                                  "Provides %s not supported",
-                                  provides_text);
+    if (!apt->init()) {
+        g_debug("Failed to create apt cache");
+        g_strfreev(values);
+        return;
     }
 
-    apt->emitFinished();
+    pk_backend_job_set_status(job, PK_STATUS_ENUM_QUERY);
+
+    PkgList output;
+    apt->providesLibrary(output, values);
+    apt->providesCodec(output, values);
+    apt->providesMimeType(output, values);
+
+    // It's faster to emit the packages here rather than in the matching part
+    apt->emitPackages(output, filters);
 }
 
 /**
@@ -501,7 +466,6 @@ static void backend_what_provides_thread(PkBackendJob *job, GVariant *params, gp
 void pk_backend_what_provides(PkBackend *backend,
                               PkBackendJob *job,
                               PkBitfield filters,
-                              PkProvidesEnum provides,
                               gchar **values)
 {
     pk_backend_job_thread_create(job, backend_what_provides_thread, NULL, NULL);
@@ -525,7 +489,6 @@ static void pk_backend_download_packages_thread(PkBackendJob *job, GVariant *par
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
     if (!apt->init()) {
         g_debug("Failed to create apt cache");
-        apt->emitFinished();
         return;
     }
 
@@ -567,7 +530,6 @@ static void pk_backend_download_packages_thread(PkBackendJob *job, GVariant *par
                                         PK_ERROR_ENUM_PACKAGE_ID_INVALID,
                                         "%s",
                                         pi);
-                apt->emitFinished();
                 return;
             }
 
@@ -593,7 +555,6 @@ static void pk_backend_download_packages_thread(PkBackendJob *job, GVariant *par
                                     ver,
                                     directory,
                                     storeFileName)) {
-                    apt->emitFinished();
                     return;
                 }
 
@@ -609,7 +570,6 @@ static void pk_backend_download_packages_thread(PkBackendJob *job, GVariant *par
                 && apt->cancelled() == false) {
             // We failed and we did not cancel
             show_errors(job, PK_ERROR_ENUM_PACKAGE_DOWNLOAD_FAILED);
-            apt->emitFinished();
             return;
         }
 
@@ -618,8 +578,6 @@ static void pk_backend_download_packages_thread(PkBackendJob *job, GVariant *par
                                   PK_ERROR_ENUM_NO_NETWORK,
                                   "Cannot download packages whilst offline");
     }
-
-    apt->emitFinished();
 }
 
 /**
@@ -643,7 +601,6 @@ static void pk_backend_refresh_cache_thread(PkBackendJob *job, GVariant *params,
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
     if (!apt->init()) {
         g_debug("Failed to create apt cache");
-        apt->emitFinished();
         return;
     }
     
@@ -659,8 +616,6 @@ static void pk_backend_refresh_cache_thread(PkBackendJob *job, GVariant *params,
                                   PK_ERROR_ENUM_NO_NETWORK,
                                   "Cannot refresh cache whilst offline");
     }
-
-    apt->emitFinished();
 }
 
 /**
@@ -684,7 +639,6 @@ static void pk_backend_resolve_thread(PkBackendJob *job, GVariant *params, gpoin
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
     if (!apt->init()) {
         g_debug("Failed to create apt cache");
-        apt->emitFinished();
         return;
     }
 
@@ -692,8 +646,6 @@ static void pk_backend_resolve_thread(PkBackendJob *job, GVariant *params, gpoin
 
     // It's faster to emmit the packages here rather than in the matching part
     apt->emitPackages(pkgs, filters);
-
-    apt->emitFinished();
 }
 
 /**
@@ -720,7 +672,6 @@ static void pk_backend_search_files_thread(PkBackendJob *job, GVariant *params,
     if (!pk_bitfield_contain(filters, PK_FILTER_ENUM_NOT_INSTALLED)) {
         if (!apt->init()) {
             g_debug("Failed to create apt cache");
-            apt->emitFinished();
             return;
         }
 
@@ -731,8 +682,6 @@ static void pk_backend_search_files_thread(PkBackendJob *job, GVariant *params,
         // It's faster to emit the packages here rather than in the matching part
         apt->emitPackages(output, filters);
     }
-
-    apt->emitFinished();
 }
 
 /**
@@ -755,20 +704,15 @@ static void backend_search_groups_thread(PkBackendJob *job, GVariant *params, gp
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
     if (!apt->init()) {
         g_debug("Failed to create apt cache");
-        apt->emitFinished();
         return;
     }
 
-    pk_backend_job_set_status(job, PK_STATUS_ENUM_QUERY);
-
     // It's faster to emmit the packages here rather than in the matching part
     PkgList output;
     output = apt->getPackagesFromGroup(search);
     apt->emitPackages(output, filters);
 
     pk_backend_job_set_percentage(job, 100);
-
-    apt->emitFinished();
 }
 
 /**
@@ -795,13 +739,11 @@ static void backend_search_package_thread(PkBackendJob *job, GVariant *params, g
     if (!apt->init()) {
         g_debug("Failed to create apt cache");
         g_free(search);
-        apt->emitFinished();
         return;
     }
 
     if (_error->PendingError() == true) {
         g_free(search);
-        apt->emitFinished();
         return;
     }
 
@@ -822,8 +764,6 @@ static void backend_search_package_thread(PkBackendJob *job, GVariant *params, g
     apt->emitPackages(output, filters);
 
     pk_backend_job_set_percentage(job, 100);
-
-    apt->emitFinished();
 }
 
 /**
@@ -896,7 +836,6 @@ static void backend_manage_packages_thread(PkBackendJob *job, GVariant *params,
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
     if (!apt->init()) {
         g_debug("Failed to create apt cache");
-        apt->emitFinished();
         return;
     }
 
@@ -911,13 +850,11 @@ static void backend_manage_packages_thread(PkBackendJob *job, GVariant *params,
             pk_backend_job_error_code(job,
                                   PK_ERROR_ENUM_NOT_SUPPORTED,
                                   "The backend can only proccess one file at time.");
-            apt->emitFinished();
             return;
         }
 
         // get the list of packages to install
         if (!apt->markFileForInstall(full_paths[0], installPkgs, removePkgs)) {
-            apt->emitFinished();
             return;
         }
 
@@ -936,7 +873,6 @@ static void backend_manage_packages_thread(PkBackendJob *job, GVariant *params,
             pk_backend_job_error_code(job,
                                       PK_ERROR_ENUM_PACKAGE_NOT_FOUND,
                                       "Could not find package(s)");
-            apt->emitFinished();
             return;
         }
     }
@@ -945,7 +881,6 @@ static void backend_manage_packages_thread(PkBackendJob *job, GVariant *params,
     bool ret;
     ret = apt->runTransaction(installPkgs,
                               removePkgs,
-                              simulate,
                               fileInstall, // Mark newly installed packages as auto-installed
                                            // (they're dependencies of the new local package)
                               fixBroken,
@@ -954,7 +889,6 @@ static void backend_manage_packages_thread(PkBackendJob *job, GVariant *params,
     if (!ret) {
         // Print transaction errors
         g_debug("AptIntf::runTransaction() failed: ", _error->PendingError());
-        apt->emitFinished();
         return;
     }
 
@@ -963,20 +897,16 @@ static void backend_manage_packages_thread(PkBackendJob *job, GVariant *params,
         gchar *path;
         for (uint i = 0; i < g_strv_length(full_paths); ++i) {
             if (apt->cancelled()) {
-                apt->emitFinished();
                 break;
             }
 
             path = full_paths[i];
             if (!apt->installFile(path, simulate)) {
                 cout << "Installation of DEB file " << path << " failed." << endl;
-                apt->emitFinished();
                 return;
             }
         }
     }
-
-    apt->emitFinished();
 }
 
 /**
@@ -1037,13 +967,14 @@ static void backend_repo_manager_thread(PkBackendJob *job, GVariant *params, gpo
 {
     // list
     PkBitfield filters;
+    PkBitfield transaction_flags = 0;
     // enable
     const gchar *repo_id;
     gboolean enabled;
+    gboolean autoremove;
     bool found = false;
     // generic
     PkRoleEnum role;
-    const char *const salt = "$1$/iSaq7rB$EoUw5jJPPvAPECNaaWzMK/";
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
 
     role = pk_backend_job_get_role(job);
@@ -1051,6 +982,11 @@ static void backend_repo_manager_thread(PkBackendJob *job, GVariant *params, gpo
         pk_backend_job_set_status(job, PK_STATUS_ENUM_QUERY);
         g_variant_get(params, "(t)",
                       &filters);
+    } else if (role == PK_ROLE_ENUM_REPO_REMOVE) {
+        g_variant_get(params, "(t&sb)",
+                      &transaction_flags,
+                      &repo_id,
+                      &autoremove);
     } else {
         pk_backend_job_set_status(job, PK_STATUS_ENUM_REQUEST);
         g_variant_get (params, "(&sb)",
@@ -1068,7 +1004,6 @@ static void backend_repo_manager_thread(PkBackendJob *job, GVariant *params, gpo
     if (_lst.ReadVendors() == false) {
         _error->Error("Cannot read vendors.list file");
         show_errors(job, PK_ERROR_ENUM_FAILED_CONFIG_PARSING);
-        apt->emitFinished();
         return;
     }
 
@@ -1078,62 +1013,87 @@ static void backend_repo_manager_thread(PkBackendJob *job, GVariant *params, gpo
             continue;
         }
 
-        string Sections;
-        for (unsigned int j = 0; j < (*it)->NumSections; ++j) {
-            Sections += (*it)->Sections[j];
-            Sections += " ";
-        }
+        string sections = (*it)->joinedSections();
+        
+        string repoId = (*it)->repoId();
 
-        if (pk_bitfield_contain(filters, PK_FILTER_ENUM_NOT_DEVELOPMENT) &&
+        if (role == PK_ROLE_ENUM_GET_REPO_LIST) {
+            if (pk_bitfield_contain(filters, PK_FILTER_ENUM_NOT_DEVELOPMENT) &&
                 ((*it)->Type & SourcesList::DebSrc ||
                  (*it)->Type & SourcesList::RpmSrc ||
                  (*it)->Type & SourcesList::RpmSrcDir ||
                  (*it)->Type & SourcesList::RepomdSrc)) {
-            continue;
-        }
+                continue;
+            }
 
-        string repo;
-        repo = (*it)->GetType();
-        repo += " " + (*it)->VendorID;
-        repo += " " + (*it)->URI;
-        repo += " " + (*it)->Dist;
-        repo += " " + Sections;
-        gchar *hash;
-        const gchar allowedChars[] =
-                "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
-        hash = crypt(repo.c_str(), salt);
-        g_strcanon(hash, allowedChars, 'D');
-        string repoId(hash);
-
-        if (role == PK_ROLE_ENUM_GET_REPO_LIST) {
             pk_backend_job_repo_detail(job,
                                        repoId.c_str(),
-                                       repo.c_str(),
+                                       (*it)->niceName().c_str(),
                                        !((*it)->Type & SourcesList::Disabled));
-        } else {
-            if (repoId.compare(repo_id) == 0) {
+        } else if (repoId.compare(repo_id) == 0) {
+            // Found the repo to enable/disable
+            found = true;
+
+            if (role == PK_ROLE_ENUM_REPO_ENABLE) {
                 if (enabled) {
                     (*it)->Type = (*it)->Type & ~SourcesList::Disabled;
                 } else {
                     (*it)->Type |= SourcesList::Disabled;
                 }
-                found = true;
-                break;
+
+                // Commit changes
+                if (!_lst.UpdateSources()) {
+                    _error->Error("Could not update sources file");
+                    show_errors(job, PK_ERROR_ENUM_CANNOT_WRITE_REPO_CONFIG);
+                }
+            } else if (role == PK_ROLE_ENUM_REPO_REMOVE) {
+                if (autoremove) {
+                    AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
+                    if (!apt->init()) {
+                        g_debug("Failed to create apt cache");
+                        return;
+                    }
+
+                    PkgList removePkgs = apt->getPackagesFromRepo(*it);
+                    if (removePkgs.size() > 0) {
+                        // Install/Update/Remove packages, or just simulate
+                        bool ret;
+                        ret = apt->runTransaction(PkgList(),
+                                                removePkgs,
+                                                false,
+                                                false,
+                                                transaction_flags,
+                                                false);
+                        if (!ret) {
+                            // Print transaction errors
+                            g_debug("AptIntf::runTransaction() failed: ", _error->PendingError());
+                            return;
+                        }
+                    }
+                }
+
+                // Now if we are not simulating remove the repository
+                if (!pk_bitfield_contain(transaction_flags, PK_TRANSACTION_FLAG_ENUM_SIMULATE)) {
+                    _lst.RemoveSource(*it);
+
+                    // Commit changes
+                    if (!_lst.UpdateSources()) {
+                        _error->Error("Could not update sources file");
+                        show_errors(job, PK_ERROR_ENUM_CANNOT_WRITE_REPO_CONFIG);
+                    }
+                }
             }
+
+            // Leave the search loop
+            break;
         }
     }
 
-    if (role == PK_ROLE_ENUM_REPO_ENABLE) {
-        if (!found) {
-            _error->Error("Could not found the repositorie");
-            show_errors(job, PK_ERROR_ENUM_REPO_NOT_AVAILABLE);
-        } else if (!_lst.UpdateSources()) {
-            _error->Error("Could not update sources file");
-            show_errors(job, PK_ERROR_ENUM_CANNOT_WRITE_REPO_CONFIG);
-        }
+    if ((role == PK_ROLE_ENUM_REPO_ENABLE || role == PK_ROLE_ENUM_REPO_REMOVE) &&
+        !found) {
+        _error->Error("Could not found the repository");
+        show_errors(job, PK_ERROR_ENUM_REPO_NOT_AVAILABLE);
     }
-
-    apt->emitFinished();
 }
 
 /**
@@ -1152,6 +1112,19 @@ void pk_backend_repo_enable(PkBackend *backend, PkBackendJob *job, const gchar *
     pk_backend_job_thread_create(job, backend_repo_manager_thread, NULL, NULL);
 }
 
+/**
+ * pk_backend_repo_remove:
+ */
+void
+pk_backend_repo_remove (PkBackend *backend,
+                        PkBackendJob *job,
+                        PkBitfield transaction_flags,
+                        const gchar *repo_id,
+                        gboolean autoremove)
+{
+    pk_backend_job_thread_create(job, backend_repo_manager_thread, NULL, NULL);
+}
+
 static void backend_get_packages_thread(PkBackendJob *job, GVariant *params, gpointer user_data)
 {
     PkBitfield filters;
@@ -1162,18 +1135,14 @@ static void backend_get_packages_thread(PkBackendJob *job, GVariant *params, gpo
     AptIntf *apt = static_cast<AptIntf*>(pk_backend_job_get_user_data(job));
     if (!apt->init()) {
         g_debug("Failed to create apt cache");
-        apt->emitFinished();
         return;
     }
 
-    pk_backend_job_set_status(job, PK_STATUS_ENUM_QUERY);
     PkgList output;
     output = apt->getPackages();
 
     // It's faster to emmit the packages rather here than in the matching part
     apt->emitPackages(output, filters);
-
-    apt->emitFinished();
 }
 
 /**
@@ -1204,10 +1173,10 @@ PkBitfield pk_backend_get_roles(PkBackend *backend)
     PkBitfield roles;
     roles = pk_bitfield_from_enums(
                 PK_ROLE_ENUM_CANCEL,
-                PK_ROLE_ENUM_GET_DEPENDS,
+                PK_ROLE_ENUM_DEPENDS_ON,
                 PK_ROLE_ENUM_GET_DETAILS,
                 PK_ROLE_ENUM_GET_FILES,
-                PK_ROLE_ENUM_GET_REQUIRES,
+                PK_ROLE_ENUM_REQUIRED_BY,
                 PK_ROLE_ENUM_GET_PACKAGES,
                 PK_ROLE_ENUM_WHAT_PROVIDES,
                 PK_ROLE_ENUM_GET_UPDATES,
@@ -1226,6 +1195,7 @@ PkBitfield pk_backend_get_roles(PkBackend *backend)
                 PK_ROLE_ENUM_GET_REPO_LIST,
                 PK_ROLE_ENUM_REPO_ENABLE,
                 PK_ROLE_ENUM_REPAIR_SYSTEM,
+                PK_ROLE_ENUM_REPO_REMOVE,
                 -1);
 
     // only add GetDistroUpgrades if the binary is present
@@ -1240,19 +1210,3 @@ PkBitfield pk_backend_get_roles(PkBackend *backend)
 
     return roles;
 }
-
-/**
- * pk_backend_get_provides:
- */
-PkBitfield pk_backend_get_provides(PkBackend *backend)
-{
-    PkBitfield provides;
-    provides = pk_bitfield_from_enums(
-        PK_PROVIDES_ENUM_SHARED_LIB,
-        PK_PROVIDES_ENUM_MIMETYPE,
-        PK_PROVIDES_ENUM_CODEC,
-        PK_PROVIDES_ENUM_ANY,
-        -1);
-
-    return provides;
-}
