@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2007-2010 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2007-2014 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -64,7 +64,7 @@ static PkBackendDummyPrivate *priv;
  * pk_backend_initialize:
  */
 void
-pk_backend_initialize (PkBackend *backend)
+pk_backend_initialize (GKeyFile *conf, PkBackend *backend)
 {
 	/* create private area */
 	priv = g_new0 (PkBackendDummyPrivate, 1);
@@ -159,10 +159,10 @@ pk_backend_cancel (PkBackend *backend, PkBackendJob *job)
 }
 
 /**
- * pk_backend_get_depends:
+ * pk_backend_depends_on:
  */
 void
-pk_backend_get_depends (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
+pk_backend_depends_on (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_job_set_status (job, PK_STATUS_ENUM_QUERY);
 
@@ -178,6 +178,38 @@ pk_backend_get_depends (PkBackend *backend, PkBackendJob *job, PkBitfield filter
 	pk_backend_job_finished (job);
 }
 
+/**
+ * pk_backend_get_details_local:
+ */
+void
+pk_backend_get_details_local (PkBackend *backend, PkBackendJob *job, gchar **files)
+{
+	pk_backend_job_set_status (job, PK_STATUS_ENUM_QUERY);
+	pk_backend_job_set_percentage (job, 0);
+	pk_backend_job_details (job, "powertop;1.8-1.fc8;i386;fedora", "Power consumption monitor", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
+				"PowerTOP is a tool that finds the software component(s) that make your "
+				"computer use more power than necessary while it is idle.", "http://live.gnome.org/powertop", 101*1024);
+	pk_backend_job_set_percentage (job, 100);
+	pk_backend_job_finished (job);
+}
+
+/**
+ * pk_backend_get_files_local:
+ */
+void
+pk_backend_get_files_local (PkBackend *backend, PkBackendJob *job, gchar **_files)
+{
+	const gchar *files[] = { "/usr/share/man/man1",
+				 "/usr/share/applications/dave.desktop",
+				 "/etc/yum.repos.d/dave.repo",
+				 NULL };
+	pk_backend_job_set_status (job, PK_STATUS_ENUM_QUERY);
+	pk_backend_job_set_percentage (job, 0);
+	pk_backend_job_files (job, "test;0.01;i386;local", (gchar **) files);
+	pk_backend_job_set_percentage (job, 100);
+	pk_backend_job_finished (job);
+}
+
 /**
  * pk_backend_get_details:
  */
@@ -193,35 +225,43 @@ pk_backend_get_details (PkBackend *backend, PkBackendJob *job, gchar **package_i
 
 	/* each one has a different detail for testing */
 	len = g_strv_length (package_ids);
-	for (i=0; i<len; i++) {
+	for (i = 0; i < len; i++) {
 		package_id = package_ids[i];
 		if (g_strcmp0 (package_id, "powertop;1.8-1.fc8;i386;fedora") == 0) {
-			pk_backend_job_details (job, "powertop;1.8-1.fc8;i386;fedora", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
+			pk_backend_job_details (job, "powertop;1.8-1.fc8;i386;fedora", "Power consumption monitor",
+						"GPL2", PK_GROUP_ENUM_PROGRAMMING,
 						"PowerTOP is a tool that finds the software component(s) that make your "
 						"computer use more power than necessary while it is idle.", "http://live.gnome.org/powertop", 101*1024);
 		} else if (g_strcmp0 (package_id, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed") == 0) {
-			pk_backend_job_details (job, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
+			pk_backend_job_details (job, "kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed",
+						"The Linux kernel (the core of the Linux operating system)",
+						"GPL2", PK_GROUP_ENUM_PROGRAMMING,
 						"The kernel package contains the Linux kernel (vmlinuz), the core of any "
 						"Linux operating system.  The kernel handles the basic functions of the "
 						"operating system: memory allocation, process allocation, device input "
 						"and output, etc.", "http://www.kernel.org", 33*1024*1024);
 		} else if (g_strcmp0 (package_id, "gtkhtml2;2.19.1-4.fc8;i386;fedora") == 0) {
-			pk_backend_job_details (job, "gtkhtml2;2.19.1-4.fc8;i386;fedora", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
+			pk_backend_job_details (job, "gtkhtml2;2.19.1-4.fc8;i386;fedora", "An HTML widget for GTK+ 2.0",
+						"GPL2", PK_GROUP_ENUM_PROGRAMMING,
 						"GtkHTML2 (sometimes called libgtkhtml) is a widget for displaying html "
 						"pages.", "http://live.gnome.org/gtkhtml", 133*1024);
 		} else if (g_strcmp0 (package_id, "vino;2.24.2.fc9;i386;fedora") == 0) {
-			pk_backend_job_details (job, "vino;2.24.2.fc9;i386;fedora", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
+			pk_backend_job_details (job, "vino;2.24.2.fc9;i386;fedora", "Remote desktop server for the desktop",
+						"GPL2", PK_GROUP_ENUM_PROGRAMMING,
 						"Vino is a VNC server for GNOME. It allows remote users to "
 						"connect to a running GNOME session using VNC.", "http://live.gnome.org/powertop", 3*1024*1024);
 		} else if (g_strcmp0 (package_id, "gnome-power-manager;2.6.19;i386;fedora") == 0) {
-			pk_backend_job_details (job, "gnome-power-manager;2.6.19;i386;fedora", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
+			pk_backend_job_details (job, "gnome-power-manager;2.6.19;i386;fedora", "GNOME power management service",
+						"GPL2", PK_GROUP_ENUM_PROGRAMMING,
 						"GNOME Power Manager uses the information and facilities provided by HAL "
 						"displaying icons and handling user callbacks in an interactive GNOME session.\n"
 						"GNOME Power Preferences allows authorised users to set policy and "
 						"change preferences.", "http://projects.gnome.org/gnome-power-manager/", 13*1024*1024);
 		//TODO: add other packages
 		} else {
-			pk_backend_job_details (job, "scribus;1.3.4-1.fc8;i386;fedora", "GPL2", PK_GROUP_ENUM_PROGRAMMING,
+			pk_backend_job_details (job, "scribus;1.3.4-1.fc8;i386;fedora", 
+						"Scribus is an desktop open source page layout program",
+						"GPL2", PK_GROUP_ENUM_PROGRAMMING,
 						"Scribus is an desktop *open source* page layöut program with "
 						"the aim of producing commercial grade output in **PDF** and "
 						"**Postscript**, primarily, though not exclusively for Linux.\n"
@@ -267,7 +307,7 @@ pk_backend_get_files (PkBackend *backend, PkBackendJob *job, gchar **package_ids
 	pk_backend_job_set_status (job, PK_STATUS_ENUM_QUERY);
 
 	len = g_strv_length (package_ids);
-	for (i=0; i<len; i++) {
+	for (i = 0; i < len; i++) {
 		package_id = package_ids[i];
 		if (g_strcmp0 (package_id, "powertop;1.8-1.fc8;i386;fedora") == 0) {
 			to_strv[0] = "/usr/share/man/man1/boo";
@@ -294,10 +334,10 @@ pk_backend_get_files (PkBackend *backend, PkBackendJob *job, gchar **package_ids
 }
 
 /**
- * pk_backend_get_requires:
+ * pk_backend_required_by:
  */
 void
-pk_backend_get_requires (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
+pk_backend_required_by (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_job_set_status (job, PK_STATUS_ENUM_QUERY);
 	pk_backend_job_package (job, PK_INFO_ENUM_INSTALLED,
@@ -342,7 +382,7 @@ pk_backend_get_update_detail_timeout (gpointer data)
 	/* each one has a different detail for testing */
 	pk_backend_job_set_percentage (job, 0);
 	len = g_strv_length (priv->package_ids);
-	for (i=0; i<len; i++) {
+	for (i = 0; i < len; i++) {
 		const gchar *to_array1[] = { NULL, NULL, NULL };
 		const gchar *to_array2[] = { NULL, NULL, NULL };
 		const gchar *to_array3[] = { NULL, NULL, NULL };
@@ -813,7 +853,7 @@ pk_backend_resolve_thread (PkBackendJob *job, GVariant *params, gpointer user_da
 
 	/* each one has a different detail for testing */
 	len = g_strv_length (search);
-	for (i=0; i<len; i++) {
+	for (i = 0; i < len; i++) {
 		if (g_strcmp0 (search[i], "vips-doc") == 0 || g_strcmp0 (search[i], "vips-doc;7.12.4-2.fc8;noarch;linva") == 0) {
 			if (!pk_bitfield_contain (filters, PK_FILTER_ENUM_INSTALLED)) {
 				pk_backend_job_package (job, PK_INFO_ENUM_AVAILABLE,
@@ -853,7 +893,6 @@ pk_backend_resolve_thread (PkBackendJob *job, GVariant *params, gpointer user_da
 		}
 	}
 	pk_backend_job_set_percentage (job, 100);
-	pk_backend_job_finished (job);
 }
 
 /**
@@ -907,7 +946,6 @@ pk_backend_search_details_thread (PkBackendJob *job, GVariant *params, gpointer
 	pk_backend_job_package (job, PK_INFO_ENUM_AVAILABLE,
 				"vips-doc;7.12.4-2.fc8;noarch;linva",
 				"The vips \"documentation\" package.");
-	pk_backend_job_finished (job);
 }
 
 /**
@@ -984,7 +1022,7 @@ pk_backend_search_names_thread (PkBackendJob *job, GVariant *params, gpointer us
 			pk_backend_job_error_code (job,
 						   PK_ERROR_ENUM_TRANSACTION_CANCELLED,
 						   "The task was stopped successfully");
-			goto out;
+			return;
 		}
 		g_usleep (2000);
 	}
@@ -1008,8 +1046,6 @@ pk_backend_search_names_thread (PkBackendJob *job, GVariant *params, gpointer us
 	pk_backend_job_package (job, PK_INFO_ENUM_AVAILABLE,
 				"vips-doc;7.12.4-2.fc8;noarch;linva",
 				"The vips documentation package.");
-out:
-	pk_backend_job_finished (job);
 }
 
 /**
@@ -1046,7 +1082,6 @@ pk_backend_update_packages_download_thread (PkBackendJob *job, GVariant *params,
 			pk_backend_job_error_code (job,
 						   PK_ERROR_ENUM_TRANSACTION_CANCELLED,
 						   "The task was stopped successfully");
-			pk_backend_job_finished (job);
 			break;
 		}
 
@@ -1057,7 +1092,6 @@ pk_backend_update_packages_download_thread (PkBackendJob *job, GVariant *params,
 							"An HTML widget for GTK+ 2.0");
 				priv->updated_gtkhtml = FALSE;
 			}
-			pk_backend_job_finished (job);
 			break;
 		}
 		if (job_data->progress_percentage == 0 && !priv->updated_powertop) {
@@ -1156,7 +1190,6 @@ pk_backend_update_system_thread (PkBackendJob *job, GVariant *params, gpointer u
 			if (job_data->socket_listen_id != 0)
 				g_source_remove (job_data->socket_listen_id);
 
-			pk_backend_job_finished (job);
 			break;
 		}
 		if (job_data->progress_percentage == 0 && !priv->updated_powertop) {
@@ -1216,20 +1249,18 @@ pk_backend_socket_has_data_cb (GSocket *socket,
 			       GIOCondition condition,
 			       PkBackendJob *job)
 {
-	GError *error = NULL;
 	gsize len;
 	gchar buffer[1024];
-	gboolean ret = TRUE;
 	gint wrote = 0;
 	PkBackendDummyJobData *job_data = pk_backend_job_get_user_data (job);
+	_cleanup_error_free_ GError *error = NULL;
 
 	/* the helper process exited */
 	if ((condition & G_IO_HUP) > 0) {
 		pk_backend_job_error_code (job, PK_ERROR_ENUM_INTERNAL_ERROR,
 					   "socket was disconnected");
 		pk_backend_job_finished (job);
-		ret = FALSE;
-		goto out;
+		return FALSE;
 	}
 
 	/* there is data */
@@ -1239,12 +1270,10 @@ pk_backend_socket_has_data_cb (GSocket *socket,
 			pk_backend_job_error_code (job, PK_ERROR_ENUM_INTERNAL_ERROR,
 						   "failed to read: %s", error->message);
 			pk_backend_job_finished (job);
-			g_error_free (error);
-			ret = FALSE;
-			goto out;
+			return FALSE;
 		}
 		if (len == 0)
-			goto out;
+			return TRUE;
 		buffer[len] = '\0';
 		if (g_strcmp0 (buffer, "pong\n") == 0) {
 			/* send a category so we can verify in the self checks */
@@ -1256,14 +1285,13 @@ pk_backend_socket_has_data_cb (GSocket *socket,
 				pk_backend_job_error_code (job, PK_ERROR_ENUM_INTERNAL_ERROR,
 							   "failed to write to socket: %s", error->message);
 				pk_backend_job_finished (job);
-				g_error_free (error);
-				goto out;
+				return FALSE;
 			}
 			if (wrote != 8) {
 				pk_backend_job_error_code (job, PK_ERROR_ENUM_INTERNAL_ERROR,
 							   "failed to write, only %i bytes", wrote);
 				pk_backend_job_finished (job);
-				goto out;
+				return FALSE;
 			}
 		} else if (g_strcmp0 (buffer, "you said to me: invalid\n") == 0) {
 			g_debug ("ignoring invalid data (one is good)");
@@ -1272,11 +1300,10 @@ pk_backend_socket_has_data_cb (GSocket *socket,
 						   "unexpected data: %s", buffer);
 			g_source_remove (job_data->signal_timeout);
 			pk_backend_job_finished (job);
-			goto out;
+			return FALSE;
 		}
 	}
-out:
-	return ret;
+	return TRUE;
 }
 
 /**
@@ -1289,13 +1316,13 @@ pk_backend_update_packages (PkBackend *backend, PkBackendJob *job, PkBitfield tr
 	const gchar *license_agreement;
 	gboolean has_eula;
 	gboolean ret;
-	gchar *frontend_socket = NULL;
-	GError *error = NULL;
 	gsize wrote;
-	GSocketAddress *address = NULL;
 	GSource *source;
 	PkBackendDummyJobData *job_data = pk_backend_job_get_user_data (job);
 	PkRoleEnum role;
+	_cleanup_error_free_ GError *error = NULL;
+	_cleanup_free_ gchar *frontend_socket = NULL;
+	_cleanup_object_unref_ GSocketAddress *address = NULL;
 
 	/* FIXME: support only_trusted */
 	role = pk_backend_job_get_role (job);
@@ -1351,7 +1378,7 @@ pk_backend_update_packages (PkBackend *backend, PkBackendJob *job, PkBitfield tr
 			pk_backend_job_error_code (job, PK_ERROR_ENUM_INTERNAL_ERROR,
 						   "failed to get frontend socket");
 			pk_backend_job_finished (job);
-			goto out;
+			return;
 		}
 
 		/* create socket */
@@ -1364,8 +1391,7 @@ pk_backend_update_packages (PkBackend *backend, PkBackendJob *job, PkBitfield tr
 						   "failed to create socket: %s",
 						   error->message);
 			pk_backend_job_finished (job);
-			g_error_free (error);
-			goto out;
+			return;
 		}
 		g_socket_set_blocking (job_data->socket, FALSE);
 		g_socket_set_keepalive (job_data->socket, TRUE);
@@ -1377,8 +1403,7 @@ pk_backend_update_packages (PkBackend *backend, PkBackendJob *job, PkBitfield tr
 			pk_backend_job_error_code (job, PK_ERROR_ENUM_INTERNAL_ERROR,
 						   "failed to open socket: %s", error->message);
 			pk_backend_job_finished (job);
-			g_error_free (error);
-			goto out;
+			return;
 		}
 
 		/* socket has data */
@@ -1392,7 +1417,7 @@ pk_backend_update_packages (PkBackend *backend, PkBackendJob *job, PkBitfield tr
 			pk_backend_job_error_code (job, PK_ERROR_ENUM_INTERNAL_ERROR,
 						   "failed to write, only %i bytes", (gint) wrote);
 			pk_backend_job_finished (job);
-			goto out;
+			return;
 		}
 
 		/* FIXME: support only_trusted */
@@ -1400,7 +1425,7 @@ pk_backend_update_packages (PkBackend *backend, PkBackendJob *job, PkBitfield tr
 						PK_RESTART_ENUM_SYSTEM,
 						"kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed");
 		pk_backend_job_thread_create (job, pk_backend_update_system_thread, NULL, NULL);
-		goto out;
+		return;
 	}
 
 	/* check if something else locked the "fake-db" */
@@ -1422,10 +1447,6 @@ pk_backend_update_packages (PkBackend *backend, PkBackendJob *job, PkBitfield tr
 	pk_backend_job_set_status (job, PK_STATUS_ENUM_DOWNLOAD);
 
 	pk_backend_job_thread_create (job, pk_backend_update_packages_download_thread, NULL, NULL);
-out:
-	if (address != NULL)
-		g_object_unref (address);
-	g_free (frontend_socket);
 }
 
 /**
@@ -1543,7 +1564,7 @@ pk_backend_what_provides_timeout (gpointer data)
  * pk_backend_what_provides:
  */
 void
-pk_backend_what_provides (PkBackend *backend, PkBackendJob *job, PkBitfield filters, PkProvidesEnum provides, gchar **values)
+pk_backend_what_provides (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **values)
 {
 	PkBackendDummyJobData *job_data = pk_backend_job_get_user_data (job);
 	priv->values = values;
@@ -1599,63 +1620,6 @@ pk_backend_download_packages (PkBackend *backend, PkBackendJob *job, gchar **pac
 	pk_backend_job_finished (job);
 }
 
-static gboolean
-pk_backend_upgrade_system_timeout (gpointer data)
-{
-	PkBackendJob *job = (PkBackendJob *) data;
-	PkBackendDummyJobData *job_data = pk_backend_job_get_user_data (job);
-
-	if (job_data->progress_percentage == 100) {
-		pk_backend_job_finished (job);
-		return FALSE;
-	}
-	if (job_data->progress_percentage == 0) {
-		pk_backend_job_set_status (job, PK_STATUS_ENUM_DOWNLOAD_UPDATEINFO);
-	}
-	if (job_data->progress_percentage == 20) {
-		pk_backend_job_package (job, PK_INFO_ENUM_DOWNLOADING,
-					"kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed",
-					"The Linux kernel (the core of the Linux operating system)");
-	}
-	if (job_data->progress_percentage == 30) {
-		pk_backend_job_package (job, PK_INFO_ENUM_DOWNLOADING,
-					"gtkhtml2;2.19.1-4.fc8;i386;fedora",
-					"An HTML widget for GTK+ 2.0");
-	}
-	if (job_data->progress_percentage == 40) {
-		pk_backend_job_set_allow_cancel (job, FALSE);
-		pk_backend_job_package (job, PK_INFO_ENUM_DOWNLOADING,
-					"powertop;1.8-1.fc8;i386;fedora",
-					"Power consumption monitor");
-	}
-	if (job_data->progress_percentage == 60) {
-		pk_backend_job_set_allow_cancel (job, TRUE);
-		pk_backend_job_package (job, PK_INFO_ENUM_DOWNLOADING,
-					"kernel;2.6.23-0.115.rc3.git1.fc8;i386;installed",
-					"The Linux kernel (the core of the Linux operating system)");
-	}
-	if (job_data->progress_percentage == 80) {
-		pk_backend_job_package (job, PK_INFO_ENUM_DOWNLOADING,
-					"powertop;1.8-1.fc8;i386;fedora",
-					"Power consumption monitor");
-	}
-	job_data->progress_percentage += 1;
-	pk_backend_job_set_percentage (job, job_data->progress_percentage);
-	return TRUE;
-}
-
-/**
- * pk_backend_upgrade_system:
- */
-void
-pk_backend_upgrade_system (PkBackend *backend, PkBackendJob *job, const gchar *distro_id, PkUpgradeKindEnum upgrade_kind)
-{
-	PkBackendDummyJobData *job_data = pk_backend_job_get_user_data (job);
-	pk_backend_job_set_status (job, PK_STATUS_ENUM_DOWNLOAD);
-	pk_backend_job_set_allow_cancel (job, TRUE);
-	job_data->signal_timeout = g_timeout_add (100, pk_backend_upgrade_system_timeout, job);
-}
-
 /**
  * pk_backend_repair_system:
  */
@@ -1728,17 +1692,3 @@ pk_backend_get_author (PkBackend *backend)
 {
 	return "Richard Hughes <richard@hughsie.com>";
 }
-
-/**
- * pk_backend_get_provides:
- */
-PkBitfield pk_backend_get_provides(PkBackend *backend)
-{
-	PkBitfield provides;
-	provides = pk_bitfield_from_enums(
-		PK_PROVIDES_ENUM_CODEC,
-		PK_PROVIDES_ENUM_ANY,
-		-1);
-
-	return provides;
-}
