@@ -16,7 +16,7 @@ typedef struct {
 	KatjaBinary parent;
 
 	/* public */
-	GString *index_file;
+	gchar *index_file;
 } KatjaDl;
 
 typedef struct {
@@ -26,11 +26,11 @@ typedef struct {
 GType katja_dl_get_type(void);
 
 /* Constructors */
-KatjaDl *katja_dl_new(gchar *name, gchar *mirror, guint i, gchar *index_file);
+KatjaDl *katja_dl_new(gchar *name, gchar *mirror, gushort order, gchar *blacklist, gchar *index_file);
 
 /* Implementations */
-GSList *katja_dl_real_collect_cache_info(KatjaPkgtools *pkgtools, const gchar *tmpl);
-void katja_dl_real_generate_cache(KatjaPkgtools *pkgtools, const gchar *tmpl);
+GSList *katja_dl_real_collect_cache_info(KatjaBinary *binary, const gchar *tmpl);
+void katja_dl_real_generate_cache(KatjaBinary *binary, PkBackendJob *job, const gchar *tmpl);
 
 G_END_DECLS
 
