@@ -29,11 +29,11 @@ GType katja_slackpkg_get_type(void);
 extern GHashTable *katja_slackpkg_cat_map;
 
 /* Constructors */
-KatjaSlackpkg *katja_slackpkg_new(gchar *name, gchar *mirror, guint order, gchar **priority);
+KatjaSlackpkg *katja_slackpkg_new(gchar *name, gchar *mirror, gushort order, gchar *blacklist, gchar **priority);
 
 /* Implementations */
-GSList *katja_slackpkg_real_collect_cache_info(KatjaPkgtools *pkgtools, const gchar *tmpl);
-void katja_slackpkg_real_generate_cache(KatjaPkgtools *pkgtools, const gchar *tmpl);
+GSList *katja_slackpkg_real_collect_cache_info(KatjaBinary *binary, const gchar *tmpl);
+void katja_slackpkg_real_generate_cache(KatjaBinary *binary, PkBackendJob *job, const gchar *tmpl);
 
 G_END_DECLS
 
