@@ -1811,8 +1811,6 @@ search_package_thread (PkBackendJob *job, GVariant *params, gpointer user_data)
 out:
 	if (array)
 		g_ptr_array_unref (array);
-
-	pk_backend_job_finished (job);
 }
 
 static void
@@ -1863,8 +1861,6 @@ update_packages_thread (PkBackendJob *job, GVariant *params, gpointer user_data)
 	}
 
 	g_free (command);
-
-	pk_backend_job_finished (job);
 }
 
 /**
@@ -1974,8 +1970,6 @@ do_simulate_packages (PkBackendJob *job, GVariant *params, gpointer user_data)
 
 	poclidek_rcmd_free (rcmd);
 	poldek_ts_free (ts);
-
-	pk_backend_job_finished (job);
 }
 
 static void
@@ -2318,7 +2312,7 @@ pk_backend_get_author (PkBackend *backend)
  * pk_backend_initialize:
  */
 void
-pk_backend_initialize (PkBackend *backend)
+pk_backend_initialize (GKeyFile *conf, PkBackend *backend)
 {
 	struct passwd *uid_ent = NULL;
 
@@ -2527,8 +2521,6 @@ backend_download_packages_thread (PkBackendJob *job, GVariant *params, gpointer
 	}
 
 	poldek_ts_free (ts);
-
-	pk_backend_job_finished (job);
 }
 
 void
@@ -2543,10 +2535,10 @@ pk_backend_download_packages (PkBackend *backend, PkBackendJob *job, gchar **pac
 }
 
 /**
- * backend_get_depends_thread:
+ * backend_depends_on_thread:
  */
 static void
-backend_get_depends_thread (PkBackendJob *job, GVariant *params, gpointer user_data)
+backend_depends_on_thread (PkBackendJob *job, GVariant *params, gpointer user_data)
 {
 	PkBitfield filters;
 	gboolean recursive;
@@ -2584,18 +2576,16 @@ backend_get_depends_thread (PkBackendJob *job, GVariant *params, gpointer user_d
 	n_array_free (deppkgs);
 	n_array_free (available);
 	n_array_free (installed);
-
-	pk_backend_job_finished (job);
 }
 
 void
-pk_backend_get_depends (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
+pk_backend_depends_on (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_job_set_status (job, PK_STATUS_ENUM_QUERY);
 	poldek_backend_set_allow_cancel (job, FALSE, TRUE);
 	pb_error_clean ();
 
-	pk_backend_job_thread_create (job, backend_get_depends_thread, NULL, NULL);
+	pk_backend_job_thread_create (job, backend_depends_on_thread, NULL, NULL);
 }
 
 /**
@@ -2624,6 +2614,7 @@ backend_get_details_thread (PkBackendJob *job, GVariant *params, gpointer user_d
 			if ((pkgu = pkg_uinf_i18n (job, pkg)) != NULL) {
 				pk_backend_job_details (job,
 							package_ids[n],
+							NULL,
 							pkguinf_get (pkgu, PKGUINF_LICENSE),
 							group,
 							pkguinf_get (pkgu, PKGUINF_DESCRIPTION),
@@ -2634,6 +2625,7 @@ backend_get_details_thread (PkBackendJob *job, GVariant *params, gpointer user_d
 				pk_backend_job_details (job,
 							package_ids[n],
 							"",
+							"",
 							group,
 							"",
 							"",
@@ -2643,8 +2635,6 @@ backend_get_details_thread (PkBackendJob *job, GVariant *params, gpointer user_d
 			pkg_free (pkg);
 		}
 	}
-
-	pk_backend_job_finished (job);
 }
 
 void
@@ -2714,8 +2704,6 @@ backend_get_files_thread (PkBackendJob *job, GVariant *params, gpointer user_dat
 			pkg_free (pkg);
 		}
 	}
-
-	pk_backend_job_finished (job);
 }
 
 void
@@ -2782,8 +2770,6 @@ backend_get_packages_thread (PkBackendJob *job, GVariant *params, gpointer user_
 	n_array_cfree (&installed);
 	n_array_cfree (&available);
 	n_array_cfree (&packages);
-
-	pk_backend_job_finished (job);
 }
 
 void
@@ -2797,10 +2783,10 @@ pk_backend_get_packages (PkBackend *backend, PkBackendJob *job, PkBitfield filte
 }
 
 /**
- * backend_get_requires_thread:
+ * backend_required_by_thread:
  */
 static void
-backend_get_requires_thread (PkBackendJob *job, GVariant *params, gpointer user_data)
+backend_required_by_thread (PkBackendJob *job, GVariant *params, gpointer user_data)
 {
 	struct pkg	*pkg;
 	tn_array	*reqpkgs, *available, *installed;
@@ -2836,18 +2822,16 @@ backend_get_requires_thread (PkBackendJob *job, GVariant *params, gpointer user_
 	n_array_free (reqpkgs);
 	n_array_free (installed);
 	n_array_free (available);
-
-	pk_backend_job_finished (job);
 }
 
 void
-pk_backend_get_requires (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
+pk_backend_required_by (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	pk_backend_job_set_status (job, PK_STATUS_ENUM_QUERY);
 	poldek_backend_set_allow_cancel (job, FALSE, TRUE);
 	pb_error_clean ();
 
-	pk_backend_job_thread_create (job, backend_get_requires_thread, NULL, NULL);
+	pk_backend_job_thread_create (job, backend_required_by_thread, NULL, NULL);
 }
 
 /**
@@ -2974,8 +2958,6 @@ backend_get_update_detail_thread (PkBackendJob *job, GVariant *params, gpointer
 
 		g_strfreev (parts);
 	}
-
-	pk_backend_job_finished (job);
 }
 
 void
@@ -3028,8 +3010,6 @@ backend_get_updates_thread (PkBackendJob *job, GVariant *params, gpointer user_d
 
 	if (sigint_reached ())
 		pk_backend_job_error_code (job, PK_ERROR_ENUM_TRANSACTION_CANCELLED, "Action cancelled.");
-
-	pk_backend_job_finished (job);
 }
 
 void
@@ -3090,8 +3070,6 @@ backend_install_packages_thread (PkBackendJob *job, GVariant *params, gpointer u
 	}
 
 	g_free (command);
-
-	pk_backend_job_finished (job);
 }
 
 void
@@ -3166,8 +3144,6 @@ backend_refresh_cache_thread (PkBackendJob *job, GVariant *params, gpointer user
 	poldek_reload (job, TRUE);
 
 	pk_backend_job_set_percentage (job, 100);
-
-	pk_backend_job_finished (job);
 }
 
 void
@@ -3228,8 +3204,6 @@ backend_remove_packages_thread (PkBackendJob *job, GVariant *params, gpointer us
 	}
 
 	g_free (command);
-
-	pk_backend_job_finished (job);
 }
 
 void
@@ -3368,7 +3342,7 @@ pk_backend_get_repo_list (PkBackend *backend, PkBackendJob *job, PkBitfield filt
  * pk_backend_what_provides:
  */
 void
-pk_backend_what_provides (PkBackend *backend, PkBackendJob *job, PkBitfield filters, PkProvidesEnum provides, gchar **values)
+pk_backend_what_provides (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **values)
 {
 	GPtrArray *array = NULL;
 	guint i;
@@ -3381,19 +3355,9 @@ pk_backend_what_provides (PkBackend *backend, PkBackendJob *job, PkBitfield filt
 	array = g_ptr_array_new_with_free_func (g_free);
 
 	for (i = 0; i < g_strv_length (values); i++) {
-		if (provides == PK_PROVIDES_ENUM_ANY) {
-			g_ptr_array_add (array, g_strdup_printf ("%s", values[i]));
-			g_ptr_array_add (array, g_strdup_printf ("gstreamer0.10\\(%s\\)", values[i]));
-			g_ptr_array_add (array, g_strdup_printf ("mimetype\\(%s\\)", values[i]));
-		} else if (provides == PK_PROVIDES_ENUM_CODEC) {
-			g_ptr_array_add (array, g_strdup_printf ("gstreamer0.10\\(%s\\)", values[i]));
-		} else if (provides == PK_PROVIDES_ENUM_MIMETYPE) {
-			g_ptr_array_add (array, g_strdup_printf ("mimetype\\(%s\\)", values[i]));
-		} else {
-			pk_backend_job_error_code (job, PK_ERROR_ENUM_PROVIDE_TYPE_NOT_SUPPORTED,
-					       "provide type '%s' not supported",
-					       pk_provides_enum_to_string (provides));
-		}
+		g_ptr_array_add (array, g_strdup_printf ("%s", values[i]));
+		g_ptr_array_add (array, g_strdup_printf ("gstreamer0.10\\(%s\\)", values[i]));
+		g_ptr_array_add (array, g_strdup_printf ("mimetype\\(%s\\)", values[i]));
 	}
 
 	pk_backend_job_thread_create (job, search_package_thread, array, NULL);
