@@ -62,7 +62,7 @@ pk_backend_start_job (PkBackend *backend, PkBackendJob *job)
  * This should only be run once per backend load, i.e. not every transaction
  */
 void
-pk_backend_initialize (PkBackend *backend)
+pk_backend_initialize (GKeyFile *conf, PkBackend *backend)
 {
 	g_debug ("backend: initialize");
 
@@ -72,7 +72,7 @@ pk_backend_initialize (PkBackend *backend)
 	g_error ("Backend needs to be ported to 0.8.x -- "
 		 "see backends/PORTING.txt for details");
 
-	spawn = pk_backend_spawn_new ();
+	spawn = pk_backend_spawn_new (conf);
 	pk_backend_spawn_set_name (spawn, "urpmi");
 }
 
@@ -137,6 +137,10 @@ pk_backend_get_filters (PkBackend *backend)
 		PK_FILTER_ENUM_DEVELOPMENT,
 		PK_FILTER_ENUM_SUPPORTED,
 		PK_FILTER_ENUM_FREE,
+		PK_FILTER_ENUM_DOWNLOADED,
+		PK_FILTER_ENUM_NOT_DOWNLOADED,
+		PK_FILTER_ENUM_APPLICATION,
+		PK_FILTER_ENUM_NOT_APPLICATION,
 		-1);
 }
 
@@ -149,10 +153,10 @@ pk_backend_get_roles (PkBackend *backend)
 	PkBitfield roles;
 	roles = pk_bitfield_from_enums (
 		PK_ROLE_ENUM_CANCEL,
-		PK_ROLE_ENUM_GET_DEPENDS,
+		PK_ROLE_ENUM_DEPENDS_ON,
 		PK_ROLE_ENUM_GET_DETAILS,
 		PK_ROLE_ENUM_GET_FILES,
-		PK_ROLE_ENUM_GET_REQUIRES,
+		PK_ROLE_ENUM_REQUIRED_BY,
 		PK_ROLE_ENUM_GET_PACKAGES,
 		PK_ROLE_ENUM_WHAT_PROVIDES,
 		PK_ROLE_ENUM_GET_UPDATES,
@@ -240,16 +244,16 @@ pk_backend_get_files (PkBackend *backend, PkBackendJob *job, gchar **package_ids
 }
 
 /**
- * pk_backend_get_depends:
+ * pk_backend_depends_on:
  */
 void
-pk_backend_get_depends (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
+pk_backend_depends_on (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	gchar *filters_text;
 	gchar *package_ids_temp;
 	package_ids_temp = pk_package_ids_to_string (package_ids);
 	filters_text = pk_filter_bitfield_to_string (filters);
-	pk_backend_spawn_helper (spawn, job, "urpmi-dispatched-backend.pl", "get-depends", filters_text, package_ids_temp, pk_backend_bool_to_string (recursive), NULL);
+	pk_backend_spawn_helper (spawn, job, "urpmi-dispatched-backend.pl", "depends-on", filters_text, package_ids_temp, pk_backend_bool_to_string (recursive), NULL);
 	g_free (filters_text);
 	g_free (package_ids_temp);
 }
@@ -374,16 +378,16 @@ pk_backend_get_repo_list (PkBackend *backend, PkBackendJob *job, PkBitfield filt
 }
 
 /**
- * pk_backend_get_requires:
+ * pk_backend_required_by:
  */
 void
-pk_backend_get_requires (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
+pk_backend_required_by (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **package_ids, gboolean recursive)
 {
 	gchar *package_ids_temp;
 	gchar *filters_text;
 	package_ids_temp = pk_package_ids_to_string (package_ids);
 	filters_text = pk_filter_bitfield_to_string (filters);
-	pk_backend_spawn_helper (spawn, job, "urpmi-dispatched-backend.pl", "get-requires", filters_text, package_ids_temp, pk_backend_bool_to_string (recursive), NULL);
+	pk_backend_spawn_helper (spawn, job, "urpmi-dispatched-backend.pl", "required-by", filters_text, package_ids_temp, pk_backend_bool_to_string (recursive), NULL);
 	g_free (filters_text);
 	g_free (package_ids_temp);
 }
@@ -465,16 +469,14 @@ pk_backend_get_distro_upgrades (PkBackend *backend, PkBackendJob *job)
  * backend_what_provides:
  */
 void
-pk_backend_what_provides (PkBackend *backend, PkBackendJob *job, PkBitfield filters, PkProvidesEnum provides, gchar **values)
+pk_backend_what_provides (PkBackend *backend, PkBackendJob *job, PkBitfield filters, gchar **values)
 {
 	gchar *search_tmp;
 	gchar *filters_text;
-	const gchar *provides_text;
 
-	provides_text = pk_provides_enum_to_string (provides);
 	filters_text = pk_filter_bitfield_to_string (filters);
 	search_tmp = g_strjoinv ("&", values);
-	pk_backend_spawn_helper (spawn, job, "urpmi-dispatched-backend.pl", "what-provides", filters_text, provides_text, search_tmp, NULL);
+	pk_backend_spawn_helper (spawn, job, "urpmi-dispatched-backend.pl", "what-provides", filters_text, "any", search_tmp, NULL);
 	g_free (filters_text);
 	g_free (search_tmp);
 }
