@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2008-2012 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2008-2014 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -383,6 +383,118 @@ pk_client_get_details (PkClient *client, gchar **package_ids, GCancellable *canc
 	return results;
 }
 
+/**
+ * pk_client_get_details_local:
+ * @client: a valid #PkClient instance
+ * @files: (array zero-terminated=1): a null terminated array of filenames
+ * @cancellable: a #GCancellable or %NULL
+ * @progress_callback: (scope call): the function to run when the progress changes
+ * @progress_user_data: data to pass to @progress_callback
+ * @error: the #GError to store any failure, or %NULL
+ *
+ * Get details of a local package, so more information can be obtained for GUI
+ * or command line tools.
+ *
+ * Warning: this function is synchronous, and may block. Do not use it in GUI
+ * applications.
+ *
+ * Return value: (transfer full): a %PkResults object, or NULL for error
+ *
+ * Since: 0.8.17
+ **/
+PkResults *
+pk_client_get_details_local (PkClient *client, gchar **files, GCancellable *cancellable,
+			     PkProgressCallback progress_callback, gpointer progress_user_data,
+			     GError **error)
+{
+	PkClientHelper helper;
+	PkResults *results;
+
+	g_return_val_if_fail (PK_IS_CLIENT (client), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	/* create temp object */
+	memset (&helper, 0, sizeof (PkClientHelper));
+	helper.context = g_main_context_new ();
+	helper.loop = g_main_loop_new (helper.context, FALSE);
+	helper.error = error;
+
+	g_main_context_push_thread_default (helper.context);
+
+	/* run async method */
+	pk_client_get_details_local_async (client, files, cancellable,
+					   progress_callback, progress_user_data,
+					   (GAsyncReadyCallback) pk_client_generic_finish_sync, &helper);
+
+	g_main_loop_run (helper.loop);
+
+	results = helper.results;
+
+	g_main_context_pop_thread_default (helper.context);
+
+	/* free temp object */
+	g_main_loop_unref (helper.loop);
+	g_main_context_unref (helper.context);
+
+	return results;
+}
+
+/**
+ * pk_client_get_files_local:
+ * @client: a valid #PkClient instance
+ * @files: (array zero-terminated=1): a null terminated array of filenames
+ * @cancellable: a #GCancellable or %NULL
+ * @progress_callback: (scope call): the function to run when the progress changes
+ * @progress_user_data: data to pass to @progress_callback
+ * @error: the #GError to store any failure, or %NULL
+ *
+ * Get file list of a local package, so more information can be obtained for GUI
+ * or command line tools.
+ *
+ * Warning: this function is synchronous, and may block. Do not use it in GUI
+ * applications.
+ *
+ * Return value: (transfer full): a %PkResults object, or NULL for error
+ *
+ * Since: 0.9.1
+ **/
+PkResults *
+pk_client_get_files_local (PkClient *client, gchar **files, GCancellable *cancellable,
+			     PkProgressCallback progress_callback, gpointer progress_user_data,
+			     GError **error)
+{
+	PkClientHelper helper;
+	PkResults *results;
+
+	g_return_val_if_fail (PK_IS_CLIENT (client), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	/* create temp object */
+	memset (&helper, 0, sizeof (PkClientHelper));
+	helper.context = g_main_context_new ();
+	helper.loop = g_main_loop_new (helper.context, FALSE);
+	helper.error = error;
+
+	g_main_context_push_thread_default (helper.context);
+
+	/* run async method */
+	pk_client_get_files_local_async (client, files, cancellable,
+					 progress_callback, progress_user_data,
+					 (GAsyncReadyCallback) pk_client_generic_finish_sync, &helper);
+
+	g_main_loop_run (helper.loop);
+
+	results = helper.results;
+
+	g_main_context_pop_thread_default (helper.context);
+
+	/* free temp object */
+	g_main_loop_unref (helper.loop);
+	g_main_context_unref (helper.context);
+
+	return results;
+}
+
 /**
  * pk_client_get_update_detail:
  * @client: a valid #PkClient instance
@@ -598,7 +710,7 @@ pk_client_get_old_transactions (PkClient *client, guint number, GCancellable *ca
 }
 
 /**
- * pk_client_get_depends:
+ * pk_client_depends_on:
  * @client: a valid #PkClient instance
  * @filters: a %PkBitfield such as %PK_FILTER_ENUM_GUI | %PK_FILTER_ENUM_FREE or %PK_FILTER_ENUM_NONE
  * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
@@ -618,7 +730,7 @@ pk_client_get_old_transactions (PkClient *client, guint number, GCancellable *ca
  * Since: 0.5.3
  **/
 PkResults *
-pk_client_get_depends (PkClient *client, PkBitfield filters, gchar **package_ids, gboolean recursive, GCancellable *cancellable,
+pk_client_depends_on (PkClient *client, PkBitfield filters, gchar **package_ids, gboolean recursive, GCancellable *cancellable,
 		       PkProgressCallback progress_callback, gpointer progress_user_data, GError **error)
 {
 	PkClientHelper helper;
@@ -636,7 +748,7 @@ pk_client_get_depends (PkClient *client, PkBitfield filters, gchar **package_ids
 	g_main_context_push_thread_default (helper.context);
 
 	/* run async method */
-	pk_client_get_depends_async (client, filters, package_ids, recursive, cancellable, progress_callback, progress_user_data,
+	pk_client_depends_on_async (client, filters, package_ids, recursive, cancellable, progress_callback, progress_user_data,
 				     (GAsyncReadyCallback) pk_client_generic_finish_sync, &helper);
 
 	g_main_loop_run (helper.loop);
@@ -706,7 +818,7 @@ pk_client_get_packages (PkClient *client, PkBitfield filters, GCancellable *canc
 }
 
 /**
- * pk_client_get_requires:
+ * pk_client_required_by:
  * @client: a valid #PkClient instance
  * @filters: a %PkBitfield such as %PK_FILTER_ENUM_GUI | %PK_FILTER_ENUM_FREE or %PK_FILTER_ENUM_NONE
  * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
@@ -726,7 +838,7 @@ pk_client_get_packages (PkClient *client, PkBitfield filters, GCancellable *canc
  * Since: 0.5.3
  **/
 PkResults *
-pk_client_get_requires (PkClient *client, PkBitfield filters, gchar **package_ids, gboolean recursive, GCancellable *cancellable,
+pk_client_required_by (PkClient *client, PkBitfield filters, gchar **package_ids, gboolean recursive, GCancellable *cancellable,
 			PkProgressCallback progress_callback, gpointer progress_user_data, GError **error)
 {
 	PkClientHelper helper;
@@ -744,7 +856,7 @@ pk_client_get_requires (PkClient *client, PkBitfield filters, gchar **package_id
 	g_main_context_push_thread_default (helper.context);
 
 	/* run async method */
-	pk_client_get_requires_async (client, filters, package_ids, recursive, cancellable, progress_callback, progress_user_data,
+	pk_client_required_by_async (client, filters, package_ids, recursive, cancellable, progress_callback, progress_user_data,
 				      (GAsyncReadyCallback) pk_client_generic_finish_sync, &helper);
 
 	g_main_loop_run (helper.loop);
@@ -764,7 +876,6 @@ pk_client_get_requires (PkClient *client, PkBitfield filters, gchar **package_id
  * pk_client_what_provides:
  * @client: a valid #PkClient instance
  * @filters: a %PkBitfield such as %PK_FILTER_ENUM_GUI | %PK_FILTER_ENUM_FREE or %PK_FILTER_ENUM_NONE
- * @provides: a #PkProvidesEnum value such as PK_PROVIDES_ENUM_CODEC
  * @values: (array zero-terminated=1): a search term such as "sound/mp3"
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
@@ -783,7 +894,10 @@ pk_client_get_requires (PkClient *client, PkBitfield filters, gchar **package_id
  * Since: 0.5.3
  **/
 PkResults *
-pk_client_what_provides (PkClient *client, PkBitfield filters, PkProvidesEnum provides, gchar **values, GCancellable *cancellable,
+pk_client_what_provides (PkClient *client,
+			 PkBitfield filters,
+			 gchar **values,
+			 GCancellable *cancellable,
 			 PkProgressCallback progress_callback, gpointer progress_user_data, GError **error)
 {
 	PkClientHelper helper;
@@ -801,7 +915,7 @@ pk_client_what_provides (PkClient *client, PkBitfield filters, PkProvidesEnum pr
 	g_main_context_push_thread_default (helper.context);
 
 	/* run async method */
-	pk_client_what_provides_async (client, filters, provides, values, cancellable, progress_callback, progress_user_data,
+	pk_client_what_provides_async (client, filters, values, cancellable, progress_callback, progress_user_data,
 				       (GAsyncReadyCallback) pk_client_generic_finish_sync, &helper);
 
 	g_main_loop_run (helper.loop);
@@ -1550,31 +1664,34 @@ pk_client_repo_set_data (PkClient *client, const gchar *repo_id, const gchar *pa
 }
 
 /**
- * pk_client_upgrade_system:
- * @distro_id: a distro ID such as "fedora-14"
- * @upgrade_kind: a #PkUpgradeKindEnum such as %PK_UPGRADE_KIND_ENUM_COMPLETE
+ * pk_client_repo_remove:
+ * @client: a valid #PkClient instance
+ * @transaction_flags: transaction flags
+ * @repo_id: a repo_id structure such as "livna-devel"
+ * @autoremove: If packages should be auto-removed
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
  * @error: the #GError to store any failure, or %NULL
  *
- * This transaction will upgrade the distro to the next version, which may
- * involve just downloading the installer and setting up the boot device,
- * or may involve doing an on-line upgrade.
- *
- * The backend will decide what is best to do.
+ * Removes a repo and optionally the packages installed from it.
  *
  * Warning: this function is synchronous, and may block. Do not use it in GUI
  * applications.
  *
  * Return value: (transfer full): a %PkResults object, or NULL for error
  *
- * Since: 0.6.11
+ * Since: 0.9.1
  **/
 PkResults *
-pk_client_upgrade_system (PkClient *client, const gchar *distro_id, PkUpgradeKindEnum upgrade_kind,
-			  GCancellable *cancellable,
-			  PkProgressCallback progress_callback, gpointer progress_user_data, GError **error)
+pk_client_repo_remove (PkClient *client,
+		       PkBitfield transaction_flags,
+		       const gchar *repo_id,
+		       gboolean autoremove,
+		       GCancellable *cancellable,
+		       PkProgressCallback progress_callback,
+		       gpointer progress_user_data,
+		       GError **error)
 {
 	PkClientHelper helper;
 	PkResults *results;
@@ -1591,9 +1708,15 @@ pk_client_upgrade_system (PkClient *client, const gchar *distro_id, PkUpgradeKin
 	g_main_context_push_thread_default (helper.context);
 
 	/* run async method */
-	pk_client_upgrade_system_async (client, distro_id, upgrade_kind,
-					cancellable, progress_callback, progress_user_data,
-					(GAsyncReadyCallback) pk_client_generic_finish_sync, &helper);
+	pk_client_repo_remove_async (client,
+				     transaction_flags,
+				     repo_id,
+				     autoremove,
+				     cancellable,
+				     progress_callback,
+				     progress_user_data,
+				     (GAsyncReadyCallback) pk_client_generic_finish_sync,
+				     &helper);
 
 	g_main_loop_run (helper.loop);
 
