@@ -47,9 +47,6 @@ struct _PkProgressPrivate
 	gchar				*package_id;
 	gchar				*transaction_id;
 	gint				 percentage;
-	gint				 subpercentage;
-	guint				 item_progress_value;
-	gchar				*item_progress_id;
 	gboolean			 allow_cancel;
 	PkRoleEnum			 role;
 	PkStatusEnum			 status;
@@ -57,7 +54,10 @@ struct _PkProgressPrivate
 	guint				 elapsed_time;
 	guint				 remaining_time;
 	guint				 speed;
+	guint64				 download_size_remaining;
+	guint64				 transaction_flags;
 	guint				 uid;
+	PkItemProgress			*item_progress;
 	PkPackage			*package;
 };
 
@@ -66,7 +66,6 @@ enum {
 	PROP_PACKAGE_ID,
 	PROP_TRANSACTION_ID,
 	PROP_PERCENTAGE,
-	PROP_SUBPERCENTAGE,
 	PROP_ALLOW_CANCEL,
 	PROP_ROLE,
 	PROP_STATUS,
@@ -74,10 +73,11 @@ enum {
 	PROP_ELAPSED_TIME,
 	PROP_REMAINING_TIME,
 	PROP_SPEED,
+	PROP_DOWNLOAD_SIZE_REMAINING,
+	PROP_TRANSACTION_FLAGS,
 	PROP_UID,
 	PROP_PACKAGE,
-	PROP_ITEM_PROGRESS_ID,
-	PROP_ITEM_PROGRESS_VALUE,
+	PROP_ITEM_PROGRESS,
 	PROP_LAST
 };
 
@@ -101,14 +101,8 @@ pk_progress_get_property (GObject *object, guint prop_id, GValue *value, GParamS
 	case PROP_PERCENTAGE:
 		g_value_set_int (value, progress->priv->percentage);
 		break;
-	case PROP_SUBPERCENTAGE:
-		g_value_set_int (value, progress->priv->subpercentage);
-		break;
-	case PROP_ITEM_PROGRESS_VALUE:
-		g_value_set_int (value, progress->priv->item_progress_value);
-		break;
-	case PROP_ITEM_PROGRESS_ID:
-		g_value_set_string (value, progress->priv->item_progress_id);
+	case PROP_ITEM_PROGRESS:
+		g_value_set_object (value, progress->priv->item_progress);
 		break;
 	case PROP_ALLOW_CANCEL:
 		g_value_set_boolean (value, progress->priv->allow_cancel);
@@ -131,6 +125,12 @@ pk_progress_get_property (GObject *object, guint prop_id, GValue *value, GParamS
 	case PROP_SPEED:
 		g_value_set_uint (value, progress->priv->speed);
 		break;
+	case PROP_DOWNLOAD_SIZE_REMAINING:
+		g_value_set_uint64 (value, progress->priv->download_size_remaining);
+		break;
+	case PROP_TRANSACTION_FLAGS:
+		g_value_set_uint64 (value, progress->priv->transaction_flags);
+		break;
 	case PROP_UID:
 		g_value_set_uint (value, progress->priv->uid);
 		break;
@@ -176,32 +176,23 @@ pk_progress_set_package_id (PkProgress *progress, const gchar *package_id)
  * pk_progress_set_item_progress:
  * @progress: a valid #PkProgress instance
  *
- * Since: 0.7.0
+ * Since: 0.8.1
  **/
 gboolean
 pk_progress_set_item_progress (PkProgress *progress,
-			       const gchar *package_id,
-			       guint percentage)
+			       PkItemProgress *item_progress)
 {
 	g_return_val_if_fail (PK_IS_PROGRESS (progress), FALSE);
 
-	/* valid? */
-	if (!pk_package_id_check (package_id)) {
-		g_warning ("invalid package_id %s", package_id);
+	/* the same as before? */
+	if (progress->priv->item_progress == item_progress)
 		return FALSE;
-	}
 
 	/* new value */
-	if (g_strcmp0 (progress->priv->item_progress_id, package_id) != 0) {
-		g_free (progress->priv->item_progress_id);
-		progress->priv->item_progress_id = g_strdup (package_id);
-		g_object_notify (G_OBJECT(progress), "item-progress-id");
-	}
-	if (progress->priv->item_progress_value != percentage) {
-		progress->priv->item_progress_value = percentage;
-		g_object_notify (G_OBJECT(progress), "item-progress-value");
-	}
-
+	if (progress->priv->item_progress != NULL)
+		g_object_unref (progress->priv->item_progress);
+	progress->priv->item_progress = g_object_ref (item_progress);
+	g_object_notify (G_OBJECT(progress), "item-progress");
 	return TRUE;
 }
 
@@ -249,27 +240,6 @@ pk_progress_set_percentage (PkProgress *progress, gint percentage)
 	return TRUE;
 }
 
-/**
- * pk_progress_set_subpercentage:
- *
- * Since: 0.5.2
- **/
-gboolean
-pk_progress_set_subpercentage (PkProgress *progress, gint subpercentage)
-{
-	g_return_val_if_fail (PK_IS_PROGRESS (progress), FALSE);
-
-	/* the same as before? */
-	if (progress->priv->subpercentage == subpercentage)
-		return FALSE;
-
-	/* new value */
-	progress->priv->subpercentage = subpercentage;
-	g_object_notify (G_OBJECT(progress), "subpercentage");
-
-	return TRUE;
-}
-
 /**
  * pk_progress_set_status:
  *
@@ -422,6 +392,48 @@ pk_progress_set_speed (PkProgress *progress, guint speed)
 	return TRUE;
 }
 
+/**
+ * pk_progress_set_speed:
+ *
+ * Since: 0.8.0
+ **/
+gboolean
+pk_progress_set_download_size_remaining (PkProgress *progress, guint64 download_size_remaining)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), FALSE);
+
+	/* the same as before? */
+	if (progress->priv->download_size_remaining == download_size_remaining)
+		return FALSE;
+
+	/* new value */
+	progress->priv->download_size_remaining = download_size_remaining;
+	g_object_notify (G_OBJECT(progress), "download-size-remaining");
+
+	return TRUE;
+}
+
+/**
+ * pk_progress_set_transaction_flags:
+ *
+ * Since: 0.8.8
+ **/
+gboolean
+pk_progress_set_transaction_flags (PkProgress *progress, guint64 transaction_flags)
+{
+	g_return_val_if_fail (PK_IS_PROGRESS (progress), FALSE);
+
+	/* the same as before? */
+	if (progress->priv->transaction_flags == transaction_flags)
+		return FALSE;
+
+	/* new value */
+	progress->priv->transaction_flags = transaction_flags;
+	g_object_notify (G_OBJECT(progress), "transaction-flags");
+
+	return TRUE;
+}
+
 /**
  * pk_progress_set_uid:
  *
@@ -484,9 +496,6 @@ pk_progress_set_property (GObject *object, guint prop_id, const GValue *value, G
 	case PROP_PERCENTAGE:
 		pk_progress_set_percentage (progress, g_value_get_int (value));
 		break;
-	case PROP_SUBPERCENTAGE:
-		pk_progress_set_subpercentage (progress, g_value_get_int (value));
-		break;
 	case PROP_ALLOW_CANCEL:
 		pk_progress_set_allow_cancel (progress, g_value_get_boolean (value));
 		break;
@@ -514,6 +523,9 @@ pk_progress_set_property (GObject *object, guint prop_id, const GValue *value, G
 	case PROP_PACKAGE:
 		pk_progress_set_package (progress, g_value_get_object (value));
 		break;
+	case PROP_ITEM_PROGRESS:
+		pk_progress_set_item_progress (progress, g_value_get_object (value));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -564,16 +576,6 @@ pk_progress_class_init (PkProgressClass *klass)
 				  G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_PERCENTAGE, pspec);
 
-	/**
-	 * PkProgress:subpercentage:
-	 *
-	 * Since: 0.5.2
-	 */
-	pspec = g_param_spec_int ("subpercentage", NULL, NULL,
-				  -1, G_MAXINT, -1,
-				  G_PARAM_READWRITE);
-	g_object_class_install_property (object_class, PROP_SUBPERCENTAGE, pspec);
-
 	/**
 	 * PkPackage:allow-cancel:
 	 *
@@ -643,6 +645,26 @@ pk_progress_class_init (PkProgressClass *klass)
 				   0, G_MAXUINT, 0,
 				   G_PARAM_READWRITE);
 	g_object_class_install_property (object_class, PROP_SPEED, pspec);
+	
+	/**
+	 * PkProgress:download-size-remaining:
+	 *
+	 * Since: 0.8.0
+	 */
+	pspec = g_param_spec_uint ("download-size-remaining", NULL, NULL,
+				   0, G_MAXUINT, 0,
+				   G_PARAM_READWRITE);
+	g_object_class_install_property (object_class, PROP_DOWNLOAD_SIZE_REMAINING, pspec);
+
+	/**
+	 * PkProgress:transaction-flags:
+	 *
+	 * Since: 0.8.8
+	 */
+	pspec = g_param_spec_uint64 ("transaction-flags", NULL, NULL,
+				     0, G_MAXUINT64, 0,
+				     G_PARAM_READWRITE);
+	g_object_class_install_property (object_class, PROP_TRANSACTION_FLAGS, pspec);
 
 	/**
 	 * PkProgress:uid:
@@ -667,22 +689,12 @@ pk_progress_class_init (PkProgressClass *klass)
 	/**
 	 * PkProgress:item-progress-id:
 	 *
-	 * Since: 0.7.0
+	 * Since: 0.8.1
 	 */
-	pspec = g_param_spec_string ("item-progress-id", NULL, NULL,
-				     NULL,
+	pspec = g_param_spec_object ("item-progress", NULL, NULL,
+				     PK_TYPE_ITEM_PROGRESS,
 				     G_PARAM_READWRITE);
-	g_object_class_install_property (object_class, PROP_ITEM_PROGRESS_ID, pspec);
-
-	/**
-	 * PkProgress:item-progress-value:
-	 *
-	 * Since: 0.7.0
-	 */
-	pspec = g_param_spec_int ("item-progress-value", NULL, NULL,
-				  -1, G_MAXINT, -1,
-				  G_PARAM_READWRITE);
-	g_object_class_install_property (object_class, PROP_ITEM_PROGRESS_VALUE, pspec);
+	g_object_class_install_property (object_class, PROP_ITEM_PROGRESS, pspec);
 
 	g_type_class_add_private (klass, sizeof (PkProgressPrivate));
 }
@@ -706,8 +718,9 @@ pk_progress_finalize (GObject *object)
 
 	if (progress->priv->package != NULL)
 		g_object_unref (progress->priv->package);
+	if (progress->priv->item_progress != NULL)
+		g_object_unref (progress->priv->item_progress);
 
-	g_free (progress->priv->item_progress_id);
 	g_free (progress->priv->package_id);
 	g_free (progress->priv->transaction_id);
 
