@@ -738,7 +738,7 @@ pk_task_get_updates_sync (PkTask *task, PkBitfield filters, GCancellable *cancel
 }
 
 /**
- * pk_task_get_depends_sync:
+ * pk_task_depends_on_sync:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
  * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
@@ -755,7 +755,7 @@ pk_task_get_updates_sync (PkTask *task, PkBitfield filters, GCancellable *cancel
  * Since: 0.6.5
  **/
 PkResults *
-pk_task_get_depends_sync (PkTask *task, PkBitfield filters, gchar **package_ids, gboolean recursive, GCancellable *cancellable,
+pk_task_depends_on_sync (PkTask *task, PkBitfield filters, gchar **package_ids, gboolean recursive, GCancellable *cancellable,
 			  PkProgressCallback progress_callback, gpointer progress_user_data,
 			  GError **error)
 {
@@ -774,10 +774,9 @@ pk_task_get_depends_sync (PkTask *task, PkBitfield filters, gchar **package_ids,
 	g_main_context_push_thread_default (helper.context);
 
 	/* run async method */
-	pk_task_get_depends_async (task, filters, package_ids, recursive, cancellable, progress_callback, progress_user_data,
+	pk_task_depends_on_async (task, filters, package_ids, recursive, cancellable, progress_callback, progress_user_data,
 				     (GAsyncReadyCallback) pk_task_generic_finish_sync, &helper);
 
-
 	g_main_loop_run (helper.loop);
 
 	results = helper.results;
@@ -843,7 +842,7 @@ pk_task_get_packages_sync (PkTask *task, PkBitfield filters, GCancellable *cance
 }
 
 /**
- * pk_task_get_requires_sync:
+ * pk_task_required_by_sync:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
  * @package_ids: (array zero-terminated=1): a null terminated array of package_id structures such as "hal;0.0.1;i386;fedora"
@@ -860,7 +859,7 @@ pk_task_get_packages_sync (PkTask *task, PkBitfield filters, GCancellable *cance
  * Since: 0.6.5
  **/
 PkResults *
-pk_task_get_requires_sync (PkTask *task, PkBitfield filters, gchar **package_ids, gboolean recursive, GCancellable *cancellable,
+pk_task_required_by_sync (PkTask *task, PkBitfield filters, gchar **package_ids, gboolean recursive, GCancellable *cancellable,
 			   PkProgressCallback progress_callback, gpointer progress_user_data,
 			   GError **error)
 {
@@ -879,10 +878,9 @@ pk_task_get_requires_sync (PkTask *task, PkBitfield filters, gchar **package_ids
 	g_main_context_push_thread_default (helper.context);
 
 	/* run async method */
-	pk_task_get_requires_async (task, filters, package_ids, recursive, cancellable, progress_callback, progress_user_data,
+	pk_task_required_by_async (task, filters, package_ids, recursive, cancellable, progress_callback, progress_user_data,
 				    (GAsyncReadyCallback) pk_task_generic_finish_sync, &helper);
 
-
 	g_main_loop_run (helper.loop);
 
 	results = helper.results;
@@ -900,7 +898,6 @@ pk_task_get_requires_sync (PkTask *task, PkBitfield filters, gchar **package_ids
  * pk_task_what_provides_sync:
  * @task: a valid #PkTask instance
  * @filters: a bitfield of filters that can be used to limit the results
- * @provides: a #PkProvidesEnum type
  * @values: (array zero-terminated=1): values to search for
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope call): the function to run when the progress changes
@@ -914,7 +911,8 @@ pk_task_get_requires_sync (PkTask *task, PkBitfield filters, gchar **package_ids
  * Since: 0.6.5
  **/
 PkResults *
-pk_task_what_provides_sync (PkTask *task, PkBitfield filters, PkProvidesEnum provides, gchar **values, GCancellable *cancellable,
+pk_task_what_provides_sync (PkTask *task, PkBitfield filters,
+			    gchar **values, GCancellable *cancellable,
 			    PkProgressCallback progress_callback, gpointer progress_user_data,
 			    GError **error)
 {
@@ -933,10 +931,9 @@ pk_task_what_provides_sync (PkTask *task, PkBitfield filters, PkProvidesEnum pro
 	g_main_context_push_thread_default (helper.context);
 
 	/* run async method */
-	pk_task_what_provides_async (task, filters, provides, values, cancellable, progress_callback, progress_user_data,
+	pk_task_what_provides_async (task, filters, values, cancellable, progress_callback, progress_user_data,
 				     (GAsyncReadyCallback) pk_task_generic_finish_sync, &helper);
 
-
 	g_main_loop_run (helper.loop);
 
 	results = helper.results;
