@@ -28,12 +28,14 @@
 
 #include <packagekit-glib2/pk-results.h>
 
+#include "pk-cleanup.h"
 #include "pk-backend.h"
 #include "pk-backend-job.h"
-#include "pk-conf.h"
 #include "pk-shared.h"
-#include "pk-sysdep.h"
-#include "pk-time.h"
+
+#ifdef PK_BUILD_DAEMON
+  #include "pk-sysdep.h"
+#endif
 
 #define PK_BACKEND_JOB_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_BACKEND_JOB, PkBackendJobPrivate))
 
@@ -97,20 +99,21 @@ struct PkBackendJobPrivate
 	guint			 speed;
 	guint			 uid;
 	GVariant		*params;
+	GCancellable		*cancellable;
 	PkBackend		*backend;
 	PkBackendJobVFuncItem	 vfunc_items[PK_BACKEND_SIGNAL_LAST];
 	PkBitfield		 transaction_flags;
-	PkConf			*conf;
+	GKeyFile		*conf;
 	PkExitEnum		 exit;
-	PkHintEnum		 allow_cancel;
-	PkHintEnum		 background;
-	PkHintEnum		 interactive;
+	gboolean		 allow_cancel;
+	gboolean		 background;
+	gboolean		 interactive;
 	gboolean		 locked;
 	PkPackage		*last_package;
 	PkErrorEnum		 last_error_code;
 	PkRoleEnum		 role;
 	PkStatusEnum		 status;
-	PkTime			*time;
+	GTimer			*timer;
 	gboolean		 started;
 };
 
@@ -158,6 +161,28 @@ pk_backend_job_get_vfunc_enabled (PkBackendJob *job,
 	return TRUE;
 }
 
+/**
+ * pk_backend_job_get_cancellable:
+ *
+ * Return value: (transfer none): a #GCancellable
+ **/
+GCancellable *
+pk_backend_job_get_cancellable (PkBackendJob *job)
+{
+	return job->priv->cancellable;
+}
+
+/**
+ * pk_backend_job_is_cancelled:
+ *
+ * Return value: (transfer none): a #GCancellable
+ **/
+gboolean
+pk_backend_job_is_cancelled (PkBackendJob *job)
+{
+	return g_cancellable_is_cancelled (job->priv->cancellable);
+}
+
 /**
  * pk_backend_job_get_backend:
  *
@@ -496,10 +521,10 @@ pk_backend_job_set_user_data (PkBackendJob *job, gpointer user_data)
 /**
  * pk_backend_job_get_background:
  **/
-PkHintEnum
+gboolean
 pk_backend_job_get_background (PkBackendJob *job)
 {
-	g_return_val_if_fail (PK_IS_BACKEND_JOB (job), PK_HINT_ENUM_UNSET);
+	g_return_val_if_fail (PK_IS_BACKEND_JOB (job), FALSE);
 	return job->priv->background;
 }
 
@@ -507,7 +532,7 @@ pk_backend_job_get_background (PkBackendJob *job)
  * pk_backend_job_set_background:
  **/
 void
-pk_backend_job_set_background (PkBackendJob *job, PkHintEnum background)
+pk_backend_job_set_background (PkBackendJob *job, gboolean background)
 {
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	job->priv->background = background;
@@ -516,10 +541,10 @@ pk_backend_job_set_background (PkBackendJob *job, PkHintEnum background)
 /**
  * pk_backend_job_get_interactive:
  **/
-PkHintEnum
+gboolean
 pk_backend_job_get_interactive (PkBackendJob *job)
 {
-	g_return_val_if_fail (PK_IS_BACKEND_JOB (job), PK_HINT_ENUM_UNSET);
+	g_return_val_if_fail (PK_IS_BACKEND_JOB (job), FALSE);
 	return job->priv->interactive;
 }
 
@@ -527,7 +552,7 @@ pk_backend_job_get_interactive (PkBackendJob *job)
  * pk_backend_job_set_interactive:
  **/
 void
-pk_backend_job_set_interactive (PkBackendJob *job, PkHintEnum interactive)
+pk_backend_job_set_interactive (PkBackendJob *job, gboolean interactive)
 {
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	job->priv->interactive = interactive;
@@ -552,7 +577,7 @@ guint
 pk_backend_job_get_runtime (PkBackendJob *job)
 {
 	g_return_val_if_fail (PK_IS_BACKEND_JOB (job), 0);
-	return pk_time_get_elapsed (job->priv->time);
+	return g_timer_elapsed (job->priv->timer, NULL) * 1000;
 }
 
 /**
@@ -597,8 +622,6 @@ pk_backend_job_signal_to_string (PkBackendJobSignal id)
 		return "DistroUpgrade";
 	if (id == PK_BACKEND_SIGNAL_FINISHED)
 		return "Finished";
-	if (id == PK_BACKEND_SIGNAL_MESSAGE)
-		return "Message";
 	if (id == PK_BACKEND_SIGNAL_PACKAGE)
 		return "Package";
 	if (id == PK_BACKEND_SIGNAL_ITEM_PROGRESS)
@@ -607,8 +630,6 @@ pk_backend_job_signal_to_string (PkBackendJobSignal id)
 		return "Files";
 	if (id == PK_BACKEND_SIGNAL_PERCENTAGE)
 		return "Percentage";
-	if (id == PK_BACKEND_SIGNAL_REMAINING)
-		return "Remaining";
 	if (id == PK_BACKEND_SIGNAL_SPEED)
 		return "Speed";
 	if (id == PK_BACKEND_SIGNAL_DOWNLOAD_SIZE_REMAINING)
@@ -646,9 +667,7 @@ pk_backend_job_call_vfunc_idle_cb (gpointer user_data)
 	/* call transaction vfunc on main thread */
 	item = &helper->job->priv->vfunc_items[helper->signal_kind];
 	if (item != NULL && item->vfunc != NULL) {
-		item->vfunc (helper->job,
-			     helper->object,
-			     item->user_data);
+		item->vfunc (helper->job, helper->object, item->user_data);
 	} else {
 		g_warning ("tried to do signal %s when no longer connected",
 			   pk_backend_job_signal_to_string (helper->signal_kind));
@@ -733,9 +752,7 @@ pk_backend_job_set_role (PkBackendJob *job, PkRoleEnum role)
 			   pk_role_enum_to_string (job->priv->role));
 	}
 
-	/* reset the timer */
-	pk_time_reset (job->priv->time);
-
+	g_timer_reset (job->priv->timer);
 	job->priv->role = role;
 	job->priv->status = PK_STATUS_ENUM_WAIT;
 	pk_backend_job_call_vfunc (job,
@@ -774,6 +791,7 @@ pk_backend_job_get_locked (PkBackendJob *job)
 
 /* simple helper to work around the GThread one pointer limit */
 typedef struct {
+	PkBackend		*backend;
 	PkBackendJob		*job;
 	PkBackendJobThreadFunc	 func;
 	gpointer		 user_data;
@@ -788,14 +806,19 @@ pk_backend_job_thread_setup (gpointer thread_data)
 {
 	PkBackendJobThreadHelper *helper = (PkBackendJobThreadHelper *) thread_data;
 
-	/* run original function */
+	/* run original function with automatic locking */
+	pk_backend_thread_start (helper->backend, helper->job, helper->func);
 	helper->func (helper->job, helper->job->priv->params, helper->user_data);
+	pk_backend_job_finished (helper->job);
+	pk_backend_thread_stop (helper->backend, helper->job, helper->func);
 
 	/* set idle IO priority */
-	if (helper->job->priv->background == PK_HINT_ENUM_TRUE) {
+#ifdef PK_BUILD_DAEMON
+	if (helper->job->priv->background == TRUE) {
 		g_debug ("setting ioprio class to idle");
 		pk_ioprio_set_idle (0);
 	}
+#endif
 
 	/* unref the thread here as it holds a reference itself and we do
 	 * not need to join() this at any stage */
@@ -821,7 +844,6 @@ pk_backend_job_thread_create (PkBackendJob *job,
 			      gpointer user_data,
 			      GDestroyNotify destroy_func)
 {
-	gboolean ret = TRUE;
 	PkBackendJobThreadHelper *helper = NULL;
 
 	g_return_val_if_fail (PK_IS_BACKEND_JOB (job), FALSE);
@@ -835,6 +857,7 @@ pk_backend_job_thread_create (PkBackendJob *job,
 	/* create a helper object to allow us to call a _setup() function */
 	helper = g_new0 (PkBackendJobThreadHelper, 1);
 	helper->job = g_object_ref (job);
+	helper->backend = job->priv->backend;
 	helper->func = func;
 	helper->user_data = user_data;
 
@@ -844,11 +867,9 @@ pk_backend_job_thread_create (PkBackendJob *job,
 					  helper);
 	if (job->priv->thread == NULL) {
 		g_warning ("failed to create thread");
-		ret = FALSE;
-		goto out;
+		return FALSE;
 	}
-out:
-	return ret;
+	return TRUE;
 }
 
 /**
@@ -857,8 +878,6 @@ out:
 void
 pk_backend_job_set_percentage (PkBackendJob *job, guint percentage)
 {
-	guint remaining;
-
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 
 	/* have we already set an error? */
@@ -892,23 +911,6 @@ pk_backend_job_set_percentage (PkBackendJob *job, guint percentage)
 				   PK_BACKEND_SIGNAL_PERCENTAGE,
 				   GUINT_TO_POINTER (percentage),
 				   NULL);
-
-	/* only compute time if we have data */
-	if (percentage != PK_BACKEND_PERCENTAGE_INVALID) {
-		/* needed for time remaining calculation */
-		pk_time_add_data (job->priv->time, percentage);
-
-		/* lets try this and print as debug */
-		remaining = pk_time_get_remaining (job->priv->time);
-		if (remaining != 0)
-			g_debug ("this will now take ~%i seconds", remaining);
-		job->priv->remaining = remaining;
-		pk_backend_job_call_vfunc (job,
-					   PK_BACKEND_SIGNAL_REMAINING,
-					   GUINT_TO_POINTER (remaining),
-					   NULL);
-	}
-
 }
 
 /**
@@ -1075,9 +1077,9 @@ pk_backend_job_package (PkBackendJob *job,
 			const gchar *package_id,
 			const gchar *summary)
 {
-	PkPackage *item = NULL;
 	gboolean ret;
-	GError *error = NULL;
+	_cleanup_error_free_ GError *error = NULL;
+	_cleanup_object_unref_ PkPackage *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	g_return_if_fail (package_id != NULL);
@@ -1088,8 +1090,7 @@ pk_backend_job_package (PkBackendJob *job,
 	if (!ret) {
 		g_warning ("package_id %s invalid and cannot be processed: %s",
 			   package_id, error->message);
-		g_error_free (error);
-		goto out;
+		return;
 	}
 	pk_package_set_info (item, info);
 	pk_package_set_summary (item, summary);
@@ -1098,7 +1099,7 @@ pk_backend_job_package (PkBackendJob *job,
 	ret = (job->priv->last_package != NULL &&
 	       pk_package_equal (job->priv->last_package, item));
 	if (ret)
-		goto out;
+		return;
 
 	/* update the 'last' package */
 	if (job->priv->last_package != NULL)
@@ -1108,7 +1109,7 @@ pk_backend_job_package (PkBackendJob *job,
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: package %s", package_id);
-		goto out;
+		return;
 	}
 
 	/* we automatically set the transaction status  */
@@ -1133,9 +1134,6 @@ pk_backend_job_package (PkBackendJob *job,
 				   PK_BACKEND_SIGNAL_PACKAGE,
 				   g_object_ref (item),
 				   g_object_unref);
-out:
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1156,9 +1154,8 @@ pk_backend_job_update_detail (PkBackendJob *job,
 			      const gchar *issued_text,
 			      const gchar *updated_text)
 {
-	PkUpdateDetail *item = NULL;
 	GTimeVal timeval;
-	gboolean ret;
+	_cleanup_object_unref_ PkUpdateDetail *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	g_return_if_fail (package_id != NULL);
@@ -1166,7 +1163,7 @@ pk_backend_job_update_detail (PkBackendJob *job,
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: update_detail %s", package_id);
-		goto out;
+		return;
 	}
 
 	/* check the dates are not empty */
@@ -1177,13 +1174,11 @@ pk_backend_job_update_detail (PkBackendJob *job,
 
 	/* check the issued dates are valid */
 	if (issued_text != NULL) {
-		ret = g_time_val_from_iso8601 (issued_text, &timeval);
-		if (!ret)
+		if (!g_time_val_from_iso8601 (issued_text, &timeval))
 			g_warning ("failed to parse issued '%s'", issued_text);
 	}
 	if (updated_text != NULL) {
-		ret = g_time_val_from_iso8601 (updated_text, &timeval);
-		if (!ret)
+		if (!g_time_val_from_iso8601 (updated_text, &timeval))
 			g_warning ("failed to parse updated '%s'", updated_text);
 	}
 
@@ -1209,9 +1204,6 @@ pk_backend_job_update_detail (PkBackendJob *job,
 				   PK_BACKEND_SIGNAL_UPDATE_DETAIL,
 				   g_object_ref (item),
 				   g_object_unref);
-out:
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1222,22 +1214,20 @@ pk_backend_job_require_restart (PkBackendJob *job,
 				PkRestartEnum restart,
 				const gchar *package_id)
 {
-	gboolean ret;
-	PkRequireRestart *item = NULL;
+	_cleanup_object_unref_ PkRequireRestart *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: require-restart %s", pk_restart_enum_to_string (restart));
-		goto out;
+		return;
 	}
 
 	/* check we are valid */
-	ret = pk_package_id_check (package_id);
-	if (!ret) {
+	if (!pk_package_id_check (package_id)) {
 		g_warning ("package_id invalid and cannot be processed: %s", package_id);
-		goto out;
+		return;
 	}
 
 	/* form PkRequireRestart struct */
@@ -1252,56 +1242,6 @@ pk_backend_job_require_restart (PkBackendJob *job,
 				   PK_BACKEND_SIGNAL_REQUIRE_RESTART,
 				   g_object_ref (item),
 				   g_object_unref);
-out:
-	if (item != NULL)
-		g_object_unref (item);
-}
-
-/**
- * pk_backend_job_message:
- **/
-void
-pk_backend_job_message (PkBackendJob *job,
-			PkMessageEnum message,
-			const gchar *format, ...)
-{
-	va_list args;
-	gchar *buffer = NULL;
-	PkMessage *item = NULL;
-
-	g_return_if_fail (PK_IS_BACKEND_JOB (job));
-
-	/* have we already set an error? */
-	if (job->priv->set_error && message != PK_MESSAGE_ENUM_BACKEND_ERROR) {
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-		g_warning ("already set error: message %s",
-			   pk_message_enum_to_string (message));
-G_GNUC_END_IGNORE_DEPRECATIONS
-		goto out;
-	}
-
-	va_start (args, format);
-	g_vasprintf (&buffer, format, args);
-	va_end (args);
-
-	/* form PkMessage struct */
-G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-	item = pk_message_new ();
-G_GNUC_END_IGNORE_DEPRECATIONS
-	g_object_set (item,
-		      "type", message,
-		      "details", buffer,
-		      NULL);
-
-	/* emit */
-	pk_backend_job_call_vfunc (job,
-				   PK_BACKEND_SIGNAL_MESSAGE,
-				   g_object_ref (item),
-				   g_object_unref);
-out:
-	g_free (buffer);
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1310,13 +1250,14 @@ out:
 void
 pk_backend_job_details (PkBackendJob *job,
 			const gchar *package_id,
+			const gchar *summary,
 			const gchar *license,
 			PkGroupEnum group,
 			const gchar *description,
 			const gchar *url,
 			gulong size)
 {
-	PkDetails *item = NULL;
+	_cleanup_object_unref_ PkDetails *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	g_return_if_fail (package_id != NULL);
@@ -1324,13 +1265,14 @@ pk_backend_job_details (PkBackendJob *job,
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: details %s", package_id);
-		goto out;
+		return;
 	}
 
 	/* form PkDetails struct */
 	item = pk_details_new ();
 	g_object_set (item,
 		      "package-id", package_id,
+		      "summary", summary,
 		      "license", license,
 		      "group", group,
 		      "description", description,
@@ -1343,9 +1285,6 @@ pk_backend_job_details (PkBackendJob *job,
 			       PK_BACKEND_SIGNAL_DETAILS,
 			       g_object_ref (item),
 				   g_object_unref);
-out:
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1358,8 +1297,7 @@ pk_backend_job_files (PkBackendJob *job,
 		      const gchar *package_id,
 		      gchar **files)
 {
-	gboolean ret;
-	PkFiles *item = NULL;
+	_cleanup_object_unref_ PkFiles *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	g_return_if_fail (files != NULL);
@@ -1367,15 +1305,14 @@ pk_backend_job_files (PkBackendJob *job,
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: files %s", package_id);
-		goto out;
+		return;
 	}
 
 	/* check we are valid if specified */
 	if (package_id != NULL) {
-		ret = pk_package_id_check (package_id);
-		if (!ret) {
+		if (!pk_package_id_check (package_id)) {
 			g_warning ("package_id invalid and cannot be processed: %s", package_id);
-			goto out;
+			return;
 		}
 	}
 
@@ -1394,9 +1331,6 @@ pk_backend_job_files (PkBackendJob *job,
 
 	/* success */
 	job->priv->download_files++;
-out:
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1408,7 +1342,7 @@ pk_backend_job_distro_upgrade (PkBackendJob *job,
 			       const gchar *name,
 			       const gchar *summary)
 {
-	PkDistroUpgrade *item = NULL;
+	_cleanup_object_unref_ PkDistroUpgrade *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	g_return_if_fail (state != PK_DISTRO_UPGRADE_ENUM_UNKNOWN);
@@ -1418,7 +1352,7 @@ pk_backend_job_distro_upgrade (PkBackendJob *job,
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: distro-upgrade");
-		goto out;
+		return;
 	}
 
 	/* form PkDistroUpgrade struct */
@@ -1434,9 +1368,6 @@ pk_backend_job_distro_upgrade (PkBackendJob *job,
 				   PK_BACKEND_SIGNAL_DISTRO_UPGRADE,
 				   g_object_ref (item),
 				   g_object_unref);
-out:
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1453,7 +1384,7 @@ pk_backend_job_repo_signature_required (PkBackendJob *job,
 					const gchar *key_timestamp,
 					PkSigTypeEnum type)
 {
-	PkRepoSignatureRequired *item = NULL;
+	_cleanup_object_unref_ PkRepoSignatureRequired *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	g_return_if_fail (repository_name != NULL);
@@ -1461,13 +1392,13 @@ pk_backend_job_repo_signature_required (PkBackendJob *job,
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: repo-sig-reqd");
-		goto out;
+		return;
 	}
 
 	/* check we don't do this more than once */
 	if (job->priv->set_signature) {
 		g_warning ("already asked for a signature, cannot process");
-		goto out;
+		return;
 	}
 
 	/* form PkRepoSignatureRequired struct */
@@ -1491,9 +1422,6 @@ pk_backend_job_repo_signature_required (PkBackendJob *job,
 
 	/* success */
 	job->priv->set_signature = TRUE;
-out:
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1506,7 +1434,7 @@ pk_backend_job_eula_required (PkBackendJob *job,
 			      const gchar *vendor_name,
 			      const gchar *license_agreement)
 {
-	PkEulaRequired *item = NULL;
+	_cleanup_object_unref_ PkEulaRequired *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	g_return_if_fail (eula_id != NULL);
@@ -1517,13 +1445,13 @@ pk_backend_job_eula_required (PkBackendJob *job,
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: eula required");
-		goto out;
+		return;
 	}
 
 	/* check we don't do this more than once */
 	if (job->priv->set_eula) {
 		g_warning ("already asked for a signature, cannot process");
-		goto out;
+		return;
 	}
 
 	/* form PkEulaRequired struct */
@@ -1543,9 +1471,6 @@ pk_backend_job_eula_required (PkBackendJob *job,
 
 	/* success */
 	job->priv->set_eula = TRUE;
-out:
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1557,7 +1482,7 @@ pk_backend_job_media_change_required (PkBackendJob *job,
 				      const gchar *media_id,
 				      const gchar *media_text)
 {
-	PkMediaChangeRequired *item = NULL;
+	_cleanup_object_unref_ PkMediaChangeRequired *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	g_return_if_fail (media_id != NULL);
@@ -1566,7 +1491,7 @@ pk_backend_job_media_change_required (PkBackendJob *job,
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: media change required");
-		goto out;
+		return;
 	}
 
 	/* form PkMediaChangeRequired struct */
@@ -1582,9 +1507,6 @@ pk_backend_job_media_change_required (PkBackendJob *job,
 				   PK_BACKEND_SIGNAL_MEDIA_CHANGE_REQUIRED,
 				   g_object_ref (item),
 				   g_object_unref);
-out:
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1596,7 +1518,7 @@ pk_backend_job_repo_detail (PkBackendJob *job,
 			    const gchar *description,
 			    gboolean enabled)
 {
-	PkRepoDetail *item = NULL;
+	_cleanup_object_unref_ PkRepoDetail *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	g_return_if_fail (repo_id != NULL);
@@ -1604,7 +1526,7 @@ pk_backend_job_repo_detail (PkBackendJob *job,
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: repo-detail %s", repo_id);
-		goto out;
+		return;
 	}
 
 	/* form PkRepoDetail struct */
@@ -1620,9 +1542,6 @@ pk_backend_job_repo_detail (PkBackendJob *job,
 				   PK_BACKEND_SIGNAL_REPO_DETAIL,
 				   g_object_ref (item),
 				   g_object_unref);
-out:
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1636,7 +1555,7 @@ pk_backend_job_category (PkBackendJob *job,
 			 const gchar *summary,
 			 const gchar *icon)
 {
-	PkCategory *item = NULL;
+	_cleanup_object_unref_ PkCategory *item = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 	g_return_if_fail (cat_id != NULL);
@@ -1644,7 +1563,7 @@ pk_backend_job_category (PkBackendJob *job,
 	/* have we already set an error? */
 	if (job->priv->set_error) {
 		g_warning ("already set error: category %s", cat_id);
-		goto out;
+		return;
 	}
 
 	/* form PkCategory struct */
@@ -1662,9 +1581,6 @@ pk_backend_job_category (PkBackendJob *job,
 				   PK_BACKEND_SIGNAL_CATEGORY,
 				   g_object_ref (item),
 				   g_object_unref);
-out:
-	if (item != NULL)
-		g_object_unref (item);
 }
 
 /**
@@ -1697,9 +1613,9 @@ pk_backend_job_error_code (PkBackendJob *job,
 			   const gchar *format, ...)
 {
 	va_list args;
-	gchar *buffer;
 	gboolean need_untrusted;
-	PkError *error = NULL;
+	_cleanup_free_ gchar *buffer = NULL;
+	_cleanup_object_unref_ PkError *error = NULL;
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 
@@ -1716,7 +1632,7 @@ pk_backend_job_error_code (PkBackendJob *job,
 			job->priv->finished = FALSE;
 		} else {
 			g_warning ("More than one error emitted! You tried to set '%s'", buffer);
-			goto out;
+			return;
 		}
 	}
 	job->priv->set_error = TRUE;
@@ -1727,7 +1643,7 @@ pk_backend_job_error_code (PkBackendJob *job,
 		pk_backend_job_set_exit_code (job, PK_EXIT_ENUM_NEED_UNTRUSTED);
 	else if (error_code == PK_ERROR_ENUM_CANCELLED_PRIORITY)
 		pk_backend_job_set_exit_code (job, PK_EXIT_ENUM_CANCELLED_PRIORITY);
-	else
+	else if (job->priv->exit == PK_EXIT_ENUM_UNKNOWN)
 		pk_backend_job_set_exit_code (job, PK_EXIT_ENUM_FAILED);
 
 	/* set the hint that RepairSystem is needed */
@@ -1750,10 +1666,6 @@ pk_backend_job_error_code (PkBackendJob *job,
 				   PK_BACKEND_SIGNAL_ERROR_CODE,
 				   g_object_ref (error),
 				   g_object_unref);
-out:
-	if (error != NULL)
-		g_object_unref (error);
-	g_free (buffer);
 }
 
 /**
@@ -1799,7 +1711,7 @@ pk_backend_job_set_allow_cancel (PkBackendJob *job, gboolean allow_cancel)
 	}
 
 	/* same as last state? */
-	if (job->priv->allow_cancel == (PkHintEnum) allow_cancel)
+	if (job->priv->allow_cancel == (gboolean) allow_cancel)
 		return;
 
 	/* emit */
@@ -1816,15 +1728,8 @@ pk_backend_job_set_allow_cancel (PkBackendJob *job, gboolean allow_cancel)
 gboolean
 pk_backend_job_get_allow_cancel (PkBackendJob *job)
 {
-	gboolean allow_cancel = FALSE;
-
 	g_return_val_if_fail (PK_IS_BACKEND_JOB (job), FALSE);
-
-	/* return FALSE if we never set state */
-	if (job->priv->allow_cancel != PK_HINT_ENUM_UNSET)
-		allow_cancel = job->priv->allow_cancel;
-
-	return allow_cancel;
+	return job->priv->allow_cancel;
 }
 
 /**
@@ -1876,21 +1781,6 @@ pk_backend_job_get_exit_code (PkBackendJob *job)
 	return job->priv->exit;
 }
 
-/**
- * pk_backend_job_use_background:
- **/
-gboolean
-pk_backend_job_use_background (PkBackendJob *job)
-{
-	/* the session has set it one way or the other */
-	if (job->priv->background == PK_HINT_ENUM_TRUE)
-		return TRUE;
-	if (job->priv->background == PK_HINT_ENUM_FALSE)
-		return FALSE;
-
-	return FALSE;
-}
-
 /**
  * pk_backend_job_finished:
  **/
@@ -1901,15 +1791,15 @@ pk_backend_job_finished (PkBackendJob *job)
 
 	g_return_if_fail (PK_IS_BACKEND_JOB (job));
 
-	/* find out what we just did */
-	role_text = pk_role_enum_to_string (job->priv->role);
-
 	/* check we have not already finished */
 	if (job->priv->finished) {
 		g_warning ("already finished");
 		return;
 	}
 
+	/* find out what we just did */
+	role_text = pk_role_enum_to_string (job->priv->role);
+
 	/* ensure the same number of ::Files() were sent as packages for DownloadPackages */
 	if (!job->priv->set_error &&
 	    job->priv->role == PK_ROLE_ENUM_DOWNLOAD_PACKAGES &&
@@ -1975,8 +1865,9 @@ pk_backend_job_finalize (GObject *object)
 	}
 	if (job->priv->params != NULL)
 		g_variant_unref (job->priv->params);
-	g_object_unref (job->priv->time);
-	g_object_unref (job->priv->conf);
+	g_timer_destroy (job->priv->timer);
+	g_key_file_unref (job->priv->conf);
+	g_object_unref (job->priv->cancellable);
 
 	G_OBJECT_CLASS (pk_backend_job_parent_class)->finalize (object);
 }
@@ -1999,8 +1890,8 @@ static void
 pk_backend_job_init (PkBackendJob *job)
 {
 	job->priv = PK_BACKEND_JOB_GET_PRIVATE (job);
-	job->priv->time = pk_time_new ();
-	job->priv->conf = pk_conf_new ();
+	job->priv->timer = g_timer_new ();
+	job->priv->cancellable = g_cancellable_new ();
 	job->priv->last_error_code = PK_ERROR_ENUM_UNKNOWN;
 	pk_backend_job_reset (job);
 }
@@ -2011,10 +1902,11 @@ pk_backend_job_init (PkBackendJob *job)
  * Return value: A new job class instance.
  **/
 PkBackendJob *
-pk_backend_job_new (void)
+pk_backend_job_new (GKeyFile *conf)
 {
 	PkBackendJob *job;
 	job = g_object_new (PK_TYPE_BACKEND_JOB, NULL);
+	job->priv->conf = g_key_file_ref (conf);
 	return PK_BACKEND_JOB (job);
 }
 
