@@ -45,12 +45,10 @@ typedef enum {
 	PK_BACKEND_SIGNAL_ERROR_CODE,
 	PK_BACKEND_SIGNAL_DISTRO_UPGRADE,
 	PK_BACKEND_SIGNAL_FINISHED,
-	PK_BACKEND_SIGNAL_MESSAGE,
 	PK_BACKEND_SIGNAL_PACKAGE,
 	PK_BACKEND_SIGNAL_ITEM_PROGRESS,
 	PK_BACKEND_SIGNAL_FILES,
 	PK_BACKEND_SIGNAL_PERCENTAGE,
-	PK_BACKEND_SIGNAL_REMAINING,
 	PK_BACKEND_SIGNAL_SPEED,
 	PK_BACKEND_SIGNAL_DOWNLOAD_SIZE_REMAINING,
 	PK_BACKEND_SIGNAL_REPO_DETAIL,
@@ -77,12 +75,14 @@ typedef struct
 } PkBackendJobClass;
 
 GType		 pk_backend_job_get_type		(void);
-PkBackendJob	*pk_backend_job_new			(void);
+PkBackendJob	*pk_backend_job_new			(GKeyFile		*conf);
 
 void		 pk_backend_job_reset			(PkBackendJob	*job);
 gpointer	 pk_backend_job_get_backend		(PkBackendJob	*job);
 void		 pk_backend_job_set_backend		(PkBackendJob	*job,
 							 gpointer	 backend);
+GCancellable	*pk_backend_job_get_cancellable		(PkBackendJob	*job);
+gboolean	 pk_backend_job_is_cancelled		(PkBackendJob	*job);
 gpointer	 pk_backend_job_get_user_data		(PkBackendJob	*job);
 void		 pk_backend_job_set_user_data		(PkBackendJob	*job,
 							 gpointer	 user_data);
@@ -92,12 +92,12 @@ void		 pk_backend_job_set_transaction_flags	(PkBackendJob	*job,
 GVariant	*pk_backend_job_get_parameters		(PkBackendJob	*job);
 void		 pk_backend_job_set_parameters		(PkBackendJob	*job,
 							 GVariant	*params);
-PkHintEnum	 pk_backend_job_get_background		(PkBackendJob	*job);
+gboolean	 pk_backend_job_get_background		(PkBackendJob	*job);
 void		 pk_backend_job_set_background		(PkBackendJob	*job,
-							 PkHintEnum	 background);
-PkHintEnum	 pk_backend_job_get_interactive		(PkBackendJob	*job);
+							 gboolean	 background);
+gboolean	 pk_backend_job_get_interactive		(PkBackendJob	*job);
 void		 pk_backend_job_set_interactive		(PkBackendJob	*job,
-							 PkHintEnum	 interactive);
+							 gboolean	 interactive);
 void		 pk_backend_job_set_locked		(PkBackendJob	*job,
 							 gboolean	 locked);
 gboolean	 pk_backend_job_get_locked		(PkBackendJob	*job);
@@ -142,7 +142,6 @@ gchar		*pk_backend_job_get_pac			(PkBackendJob	*job);
 gchar		*pk_backend_job_get_locale		(PkBackendJob	*job);
 gchar		*pk_backend_job_get_frontend_socket	(PkBackendJob	*job);
 guint		 pk_backend_job_get_cache_age		(PkBackendJob	*job);
-gboolean	 pk_backend_job_use_background		(PkBackendJob	*job);
 
 /* transaction vfuncs */
 typedef void	 (*PkBackendJobVFunc)			(PkBackendJob	*job,
@@ -190,13 +189,9 @@ void		 pk_backend_job_update_detail		(PkBackendJob	*job,
 void		 pk_backend_job_require_restart		(PkBackendJob	*job,
 							 PkRestartEnum	 restart,
 							 const gchar	*package_id);
-G_DEPRECATED
-void		 pk_backend_job_message			(PkBackendJob	*job,
-							 PkMessageEnum	 message,
-							 const gchar	*details, ...)
-							 G_GNUC_PRINTF(3,4);
 void		 pk_backend_job_details			(PkBackendJob	*job,
 							 const gchar	*package_id,
+							 const gchar    *summary,
 							 const gchar	*license,
 							 PkGroupEnum	 group,
 							 const gchar	*description,
