@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2008-2012 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2008-2014 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -30,16 +30,19 @@
 #include <glib/gi18n.h>
 #include <glib.h>
 #include <gmodule.h>
+#include <packagekit-glib2/pk-offline-private.h>
 #include <packagekit-glib2/pk-package-id.h>
 #include <packagekit-glib2/pk-results.h>
 #include <packagekit-glib2/pk-common.h>
 
-#include "pk-conf.h"
-#include "pk-network.h"
+#include "pk-cleanup.h"
 #include "pk-backend.h"
-#include "pk-conf.h"
 #include "pk-shared.h"
-#include "pk-notify.h"
+
+#ifdef PK_BUILD_DAEMON
+  #include "pk-network.h"
+  #include "pk-notify.h"
+#endif
 
 #define PK_BACKEND_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_BACKEND, PkBackendPrivate))
 
@@ -57,7 +60,8 @@
 typedef struct {
 	const gchar	*description;
 	const gchar	*author;
-	void		(*initialize)			(PkBackend	*backend);
+	void		(*initialize)			(GKeyFile		*conf,
+							 PkBackend	*backend);
 	void		(*destroy)			(PkBackend	*backend);
 	PkBitfield	(*get_groups)			(PkBackend	*backend);
 	PkBitfield	(*get_filters)			(PkBackend	*backend);
@@ -79,7 +83,7 @@ typedef struct {
 							 const gchar	*directory);
 	void		(*get_categories)		(PkBackend	*backend,
 							 PkBackendJob	*job);
-	void		(*get_depends)			(PkBackend	*backend,
+	void		(*depends_on)			(PkBackend	*backend,
 							 PkBackendJob	*job,
 							 PkBitfield	 filters,
 							 gchar		**package_ids,
@@ -87,6 +91,12 @@ typedef struct {
 	void		(*get_details)			(PkBackend	*backend,
 							 PkBackendJob	*job,
 							 gchar		**package_ids);
+	void		(*get_details_local)		(PkBackend	*backend,
+							 PkBackendJob	*job,
+							 gchar		**files);
+	void		(*get_files_local)		(PkBackend	*backend,
+							 PkBackendJob	*job,
+							 gchar		**files);
 	void		(*get_distro_upgrades)		(PkBackend	*backend,
 							 PkBackendJob	*job);
 	void		(*get_files)			(PkBackend	*backend,
@@ -98,7 +108,7 @@ typedef struct {
 	void		(*get_repo_list)		(PkBackend	*backend,
 							 PkBackendJob	*job,
 							 PkBitfield	 filters);
-	void		(*get_requires)			(PkBackend	*backend,
+	void		(*required_by)			(PkBackend	*backend,
 							 PkBackendJob	*job,
 							 PkBitfield	 filters,
 							 gchar		**package_ids,
@@ -140,6 +150,11 @@ typedef struct {
 							 const gchar	*repo_id,
 							 const gchar	*parameter,
 							 const gchar	*value);
+	void		(*repo_remove)			(PkBackend	*backend,
+							 PkBackendJob	*job,
+							 PkBitfield	 transaction_flags,
+							 const gchar	*repo_id,
+							 gboolean	 autoremove);
 	void		(*resolve)			(PkBackend	*backend,
 							 PkBackendJob	*job,
 							 PkBitfield	 filters,
@@ -167,12 +182,7 @@ typedef struct {
 	void		(*what_provides)		(PkBackend	*backend,
 							 PkBackendJob	*job,
 							 PkBitfield	 filters,
-							 PkProvidesEnum	 provides,
 							 gchar		**values);
-	void		(*upgrade_system)		(PkBackend	*backend,
-							 PkBackendJob	*job,
-							 const gchar	*distro_id,
-							 PkUpgradeKindEnum upgrade_kind);
 	void		(*repair_system)		(PkBackend	*backend,
 							 PkBackendJob	*job,
 							 PkBitfield	 transaction_flags);
@@ -189,10 +199,17 @@ struct PkBackendPrivate
 	PkBackendDesc		*desc;
 	PkBackendFileChanged	 file_changed_func;
 	PkBitfield		 roles;
-	PkConf			*conf;
+	GKeyFile		*conf;
 	GFileMonitor		*monitor;
+#ifdef PK_BUILD_DAEMON
 	PkNetwork		*network;
+#endif
 	gboolean		 backend_roles_set;
+	gpointer		 user_data;
+	GHashTable		*thread_hash;
+	GMutex			 thread_hash_mutex;
+	gboolean		 transaction_in_progress;
+	guint			 transaction_inhibit_end_idle_id;
 };
 
 G_DEFINE_TYPE (PkBackend, pk_backend, G_TYPE_OBJECT)
@@ -243,6 +260,44 @@ pk_backend_supports_parallelization (PkBackend	*backend)
 	return backend->priv->desc->supports_parallelization (backend);
 }
 
+/**
+ * pk_backend_thread_start:
+ **/
+void
+pk_backend_thread_start (PkBackend *backend, PkBackendJob *job, gpointer func)
+{
+	GMutex *mutex;
+	gboolean ret;
+
+	g_mutex_lock (&backend->priv->thread_hash_mutex);
+	mutex = g_hash_table_lookup (backend->priv->thread_hash, func);
+	if (mutex == NULL) {
+		mutex = g_new0 (GMutex, 1);
+		g_mutex_init (mutex);
+		g_hash_table_insert (backend->priv->thread_hash, func, mutex);
+	}
+	g_mutex_unlock (&backend->priv->thread_hash_mutex);
+
+	ret = g_mutex_trylock (mutex);
+	if (!ret) {
+		pk_backend_job_set_status (job,
+					   PK_STATUS_ENUM_WAITING_FOR_LOCK);
+		g_mutex_lock (mutex);
+	}
+}
+
+/**
+ * pk_backend_thread_stop:
+ **/
+void
+pk_backend_thread_stop (PkBackend *backend, PkBackendJob *job, gpointer func)
+{
+	GMutex *mutex;
+	mutex = g_hash_table_lookup (backend->priv->thread_hash, func);
+	g_assert (mutex);
+	g_mutex_unlock (mutex);
+}
+
 /**
  * pk_backend_get_filters:
  **/
@@ -278,6 +333,7 @@ pk_backend_get_roles (PkBackend *backend)
 	/* not compulsory, but use it if we've got it */
 	if (backend->priv->desc->get_roles != NULL) {
 		backend->priv->roles = backend->priv->desc->get_roles (backend);
+		pk_bitfield_add (backend->priv->roles, PK_ROLE_ENUM_GET_OLD_TRANSACTIONS);
 		goto out;
 	}
 
@@ -285,14 +341,18 @@ pk_backend_get_roles (PkBackend *backend)
 	desc = backend->priv->desc;
 	if (desc->cancel != NULL)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_CANCEL);
-	if (desc->get_depends != NULL)
-		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_DEPENDS);
+	if (desc->depends_on != NULL)
+		pk_bitfield_add (roles, PK_ROLE_ENUM_DEPENDS_ON);
 	if (desc->get_details != NULL)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_DETAILS);
+	if (desc->get_details_local != NULL)
+		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_DETAILS_LOCAL);
+	if (desc->get_files_local != NULL)
+		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_FILES_LOCAL);
 	if (desc->get_files != NULL)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_FILES);
-	if (desc->get_requires != NULL)
-		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_REQUIRES);
+	if (desc->required_by != NULL)
+		pk_bitfield_add (roles, PK_ROLE_ENUM_REQUIRED_BY);
 	if (desc->get_packages != NULL)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_PACKAGES);
 	if (desc->what_provides != NULL)
@@ -331,14 +391,15 @@ pk_backend_get_roles (PkBackend *backend)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_REPO_ENABLE);
 	if (desc->repo_set_data != NULL)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_REPO_SET_DATA);
+	if (desc->repo_remove != NULL)
+		pk_bitfield_add (roles, PK_ROLE_ENUM_REPO_REMOVE);
 	if (desc->get_distro_upgrades != NULL)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_DISTRO_UPGRADES);
 	if (desc->get_categories != NULL)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_GET_CATEGORIES);
-	if (desc->upgrade_system != NULL)
-		pk_bitfield_add (roles, PK_ROLE_ENUM_UPGRADE_SYSTEM);
 	if (desc->repair_system != NULL)
 		pk_bitfield_add (roles, PK_ROLE_ENUM_REPAIR_SYSTEM);
+	pk_bitfield_add (roles, PK_ROLE_ENUM_GET_OLD_TRANSACTIONS);
 	backend->priv->roles = roles;
 
 	backend->priv->backend_roles_set = TRUE;
@@ -346,21 +407,6 @@ out:
 	return backend->priv->roles;
 }
 
-/**
- * pk_backend_get_provides:
- **/
-PkBitfield
-pk_backend_get_provides (PkBackend *backend)
-{
-	g_return_val_if_fail (PK_IS_BACKEND (backend), PK_PROVIDES_ENUM_UNKNOWN);
-	g_return_val_if_fail (backend->priv->loaded, PK_PROVIDES_ENUM_UNKNOWN);
-
-	/* not compulsory */
-	if (backend->priv->desc->get_provides == NULL)
-		return PK_PROVIDES_ENUM_UNKNOWN;
-	return backend->priv->desc->get_provides (backend);
-}
-
 /**
  * pk_backend_is_implemented:
  **/
@@ -391,7 +437,7 @@ static gchar *
 pk_backend_build_library_path (PkBackend *backend, const gchar *name)
 {
 	gchar *path;
-	gchar *filename;
+	_cleanup_free_ gchar *filename = NULL;
 #if PK_BUILD_LOCAL
 	const gchar *directory;
 #endif
@@ -415,7 +461,6 @@ pk_backend_build_library_path (PkBackend *backend, const gchar *name)
 #else
 	path = g_build_filename (LIBDIR, "packagekit-backend", filename, NULL);
 #endif
-	g_free (filename);
 	g_debug ("dlopening '%s'", path);
 
 	return path;
@@ -437,10 +482,10 @@ gboolean
 pk_backend_load (PkBackend *backend, GError **error)
 {
 	GModule *handle;
-	gchar *path = NULL;
 	gboolean ret = FALSE;
 	gpointer func = NULL;
-	gchar *backend_name = NULL;
+	_cleanup_free_ gchar *backend_name = NULL;
+	_cleanup_free_ gchar *path = NULL;
 
 	g_return_val_if_fail (PK_IS_BACKEND (backend), FALSE);
 
@@ -449,18 +494,30 @@ pk_backend_load (PkBackend *backend, GError **error)
 		g_set_error (error, 1, 0,
 			     "already set name to %s",
 			     backend->priv->name);
-		goto out;
+		return FALSE;
 	}
 
 	/* can we load it? */
-	backend_name = pk_conf_get_string (backend->priv->conf, "DefaultBackend");
+	backend_name = g_key_file_get_string (backend->priv->conf,
+					      "Daemon",
+					      "DefaultBackend",
+					      error);
+	if (backend_name == NULL)
+		return FALSE;
+
+	/* the "hawkey" backend was renamed to "hif" */
+	if (g_strcmp0 (backend_name, "hawkey") == 0) {
+		g_free (backend_name);
+		backend_name = g_strdup ("hif");
+	}
+
 	g_debug ("Trying to load : %s", backend_name);
 	path = pk_backend_build_library_path (backend, backend_name);
 	handle = g_module_open (path, 0);
 	if (handle == NULL) {
 		g_set_error (error, 1, 0, "opening module %s failed : %s",
 			     backend_name, g_module_error ());
-		goto out;
+		return FALSE;
 	}
 
 	/* then check for the new style exported functions */
@@ -475,8 +532,10 @@ pk_backend_load (PkBackend *backend, GError **error)
 		g_module_symbol (handle, "pk_backend_destroy", (gpointer *)&desc->destroy);
 		g_module_symbol (handle, "pk_backend_download_packages", (gpointer *)&desc->download_packages);
 		g_module_symbol (handle, "pk_backend_get_categories", (gpointer *)&desc->get_categories);
-		g_module_symbol (handle, "pk_backend_get_depends", (gpointer *)&desc->get_depends);
+		g_module_symbol (handle, "pk_backend_depends_on", (gpointer *)&desc->depends_on);
 		g_module_symbol (handle, "pk_backend_get_details", (gpointer *)&desc->get_details);
+		g_module_symbol (handle, "pk_backend_get_details_local", (gpointer *)&desc->get_details_local);
+		g_module_symbol (handle, "pk_backend_get_files_local", (gpointer *)&desc->get_files_local);
 		g_module_symbol (handle, "pk_backend_get_distro_upgrades", (gpointer *)&desc->get_distro_upgrades);
 		g_module_symbol (handle, "pk_backend_get_files", (gpointer *)&desc->get_files);
 		g_module_symbol (handle, "pk_backend_get_filters", (gpointer *)&desc->get_filters);
@@ -485,7 +544,7 @@ pk_backend_load (PkBackend *backend, GError **error)
 		g_module_symbol (handle, "pk_backend_supports_parallelization", (gpointer *)&desc->supports_parallelization);
 		g_module_symbol (handle, "pk_backend_get_packages", (gpointer *)&desc->get_packages);
 		g_module_symbol (handle, "pk_backend_get_repo_list", (gpointer *)&desc->get_repo_list);
-		g_module_symbol (handle, "pk_backend_get_requires", (gpointer *)&desc->get_requires);
+		g_module_symbol (handle, "pk_backend_required_by", (gpointer *)&desc->required_by);
 		g_module_symbol (handle, "pk_backend_get_roles", (gpointer *)&desc->get_roles);
 		g_module_symbol (handle, "pk_backend_get_provides", (gpointer *)&desc->get_provides);
 		g_module_symbol (handle, "pk_backend_get_update_detail", (gpointer *)&desc->get_update_detail);
@@ -498,6 +557,7 @@ pk_backend_load (PkBackend *backend, GError **error)
 		g_module_symbol (handle, "pk_backend_remove_packages", (gpointer *)&desc->remove_packages);
 		g_module_symbol (handle, "pk_backend_repo_enable", (gpointer *)&desc->repo_enable);
 		g_module_symbol (handle, "pk_backend_repo_set_data", (gpointer *)&desc->repo_set_data);
+		g_module_symbol (handle, "pk_backend_repo_remove", (gpointer *)&desc->repo_remove);
 		g_module_symbol (handle, "pk_backend_resolve", (gpointer *)&desc->resolve);
 		g_module_symbol (handle, "pk_backend_search_details", (gpointer *)&desc->search_details);
 		g_module_symbol (handle, "pk_backend_search_files", (gpointer *)&desc->search_files);
@@ -508,7 +568,6 @@ pk_backend_load (PkBackend *backend, GError **error)
 		g_module_symbol (handle, "pk_backend_reset_job", (gpointer *)&desc->job_reset);
 		g_module_symbol (handle, "pk_backend_update_packages", (gpointer *)&desc->update_packages);
 		g_module_symbol (handle, "pk_backend_what_provides", (gpointer *)&desc->what_provides);
-		g_module_symbol (handle, "pk_backend_upgrade_system", (gpointer *)&desc->upgrade_system);
 		g_module_symbol (handle, "pk_backend_repair_system", (gpointer *)&desc->repair_system);
 
 		/* get old static string data */
@@ -523,8 +582,10 @@ pk_backend_load (PkBackend *backend, GError **error)
 		backend->priv->desc = desc;
 	} else {
 		g_module_close (handle);
-		g_set_error (error, 1, 0, "could not find description in plugin %s, not loading", backend_name);
-		goto out;
+		g_set_error (error, 1, 0,
+			     "could not find description in plugin %s, not loading",
+			     backend_name);
+		return FALSE;
 	}
 
 	/* save the backend name and handle */
@@ -535,14 +596,11 @@ pk_backend_load (PkBackend *backend, GError **error)
 	/* initialize if we can */
 	if (backend->priv->desc->initialize != NULL) {
 		backend->priv->during_initialize = TRUE;
-		backend->priv->desc->initialize (backend);
+		backend->priv->desc->initialize (backend->priv->conf, backend);
 		backend->priv->during_initialize = FALSE;
 	}
 	backend->priv->loaded = TRUE;
-out:
-	g_free (path);
-	g_free (backend_name);
-	return ret;
+	return TRUE;
 }
 
 /**
@@ -577,19 +635,88 @@ pk_backend_unload (PkBackend *backend)
 /**
  * pk_backend_repo_list_changed:
  **/
-gboolean
+void
 pk_backend_repo_list_changed (PkBackend *backend)
 {
-	PkNotify *notify;
+#ifdef PK_BUILD_DAEMON
+	_cleanup_object_unref_ PkNotify *notify = NULL;
 
-	g_return_val_if_fail (PK_IS_BACKEND (backend), FALSE);
-	g_return_val_if_fail (backend->priv->loaded, FALSE);
+	g_return_if_fail (PK_IS_BACKEND (backend));
+	g_return_if_fail (backend->priv->loaded);
 
 	notify = pk_notify_new ();
 	pk_notify_repo_list_changed (notify);
-	g_object_unref (notify);
+#endif
+}
 
-	return TRUE;
+/**
+ * pk_backend_installed_db_changed:
+ *
+ * This method signals PackageKit to drop any internal caches that should be
+ * invalidated when something external changes the package database, e.g. a
+ * native command line package management tool.
+ *
+ * Typically, a backend would set up a file monitor and call this method when
+ * the package database file has changed. To avoid invalidating caches for
+ * transactions done by PackageKit itself, a backend would call
+ * pk_backend_transaction_inhibit_start() before each transaction and
+ * pk_backend_transaction_inhibit_end() after the transaction has finished.
+ **/
+void
+pk_backend_installed_db_changed (PkBackend *backend)
+{
+	_cleanup_error_free_ GError *error = NULL;
+
+	g_return_if_fail (PK_IS_BACKEND (backend));
+	g_return_if_fail (backend->priv->loaded);
+
+	if (!backend->priv->transaction_in_progress) {
+		g_debug ("invalidating offline updates");
+		if (!pk_offline_auth_invalidate (&error))
+			g_warning ("failed to invalidate: %s", error->message);
+	}
+}
+
+/**
+ * pk_backend_transaction_inhibit_start:
+ *
+ * Call this method before each transaction that touches the installed package
+ * database.
+ **/
+void
+pk_backend_transaction_inhibit_start (PkBackend *backend)
+{
+	backend->priv->transaction_in_progress = TRUE;
+}
+
+static gboolean
+transaction_inhibit_end_idle (gpointer user_data)
+{
+	PkBackend *backend = user_data;
+
+	backend->priv->transaction_in_progress = FALSE;
+	backend->priv->transaction_inhibit_end_idle_id = 0;
+
+	return G_SOURCE_REMOVE;
+}
+
+/**
+ * pk_backend_transaction_inhibit_end:
+ *
+ * Call this method after each transaction that touches the installed package
+ * database.
+ **/
+void
+pk_backend_transaction_inhibit_end (PkBackend *backend)
+{
+	if (backend->priv->transaction_inhibit_end_idle_id > 0)
+		g_source_remove (backend->priv->transaction_inhibit_end_idle_id);
+
+	/* delay for 3 seconds in order to cover the 2 second rate limit
+           timeout used by the gio file monitor */
+	backend->priv->transaction_inhibit_end_idle_id = g_timeout_add_seconds (3,
+	                                                                        transaction_inhibit_end_idle,
+	                                                                        backend);
 }
 
 /**
@@ -715,6 +842,7 @@ pk_backend_bool_to_string (gboolean value)
 gboolean
 pk_backend_is_online (PkBackend *backend)
 {
+#ifdef PK_BUILD_DAEMON
 	PkNetworkEnum state;
 	g_return_val_if_fail (PK_IS_BACKEND (backend), FALSE);
 	state = pk_network_get_network_state (backend->priv->network);
@@ -724,6 +852,9 @@ pk_backend_is_online (PkBackend *backend)
 	    state == PK_NETWORK_ENUM_WIRED)
 		return TRUE;
 	return FALSE;
+#else
+	return TRUE;
+#endif
 }
 
 /**
@@ -804,15 +935,14 @@ gchar *
 pk_backend_get_accepted_eula_string (PkBackend *backend)
 {
 	GString *string;
-	gchar *result = NULL;
-	GList *keys = NULL;
 	GList *l;
+	_cleanup_list_free_ GList *keys = NULL;
 
 	g_return_val_if_fail (PK_IS_BACKEND (backend), FALSE);
 
 	/* optimise for the common case */
 	if (g_hash_table_size (backend->priv->eulas) == 0)
-		goto out;
+		return NULL;
 
 	/* create a string of the accepted EULAs */
 	string = g_string_new ("");
@@ -822,10 +952,29 @@ pk_backend_get_accepted_eula_string (PkBackend *backend)
 
 	/* remove the trailing ';' */
 	g_string_set_size (string, string->len -1);
-	result = g_string_free (string, FALSE);
-out:
-	g_list_free (keys);
-	return result;
+	return g_string_free (string, FALSE);
+}
+
+/**
+ * pk_backend_get_user_data:
+ *
+ * Return value: (transfer none): Job user data
+ **/
+gpointer
+pk_backend_get_user_data (PkBackend *backend)
+{
+	g_return_val_if_fail (PK_IS_BACKEND (backend), NULL);
+	return backend->priv->user_data;
+}
+
+/**
+ * pk_backend_set_user_data:
+ **/
+void
+pk_backend_set_user_data (PkBackend *backend, gpointer user_data)
+{
+	g_return_if_fail (PK_IS_BACKEND (backend));
+	backend->priv->user_data = user_data;
 }
 
 /**
@@ -853,9 +1002,8 @@ pk_backend_watch_file (PkBackend *backend,
 		       PkBackendFileChanged func,
 		       gpointer data)
 {
-	gboolean ret = FALSE;
-	GError *error = NULL;
-	GFile *file = NULL;
+	_cleanup_error_free_ GError *error = NULL;
+	_cleanup_object_unref_ GFile *file = NULL;
 
 	g_return_val_if_fail (PK_IS_BACKEND (backend), FALSE);
 	g_return_val_if_fail (filename != NULL, FALSE);
@@ -863,7 +1011,7 @@ pk_backend_watch_file (PkBackend *backend,
 
 	if (backend->priv->file_changed_func != NULL) {
 		g_warning ("already set");
-		goto out;
+		return FALSE;
 	}
 
 	/* monitor config files for changes */
@@ -874,22 +1022,16 @@ pk_backend_watch_file (PkBackend *backend,
 						      &error);
 	if (backend->priv->monitor == NULL) {
 		g_warning ("Failed to set watch on %s: %s",
-			   filename,
-			   error->message);
-		g_error_free (error);
-		goto out;
+			   filename, error->message);
+		return FALSE;
 	}
 
 	/* success */
-	ret = TRUE;
 	g_signal_connect (backend->priv->monitor, "changed",
 			  G_CALLBACK (pk_backend_file_monitor_changed_cb), backend);
 	backend->priv->file_changed_func = func;
 	backend->priv->file_changed_data = data;
-out:
-	if (file != NULL)
-		g_object_unref (file);
-	return ret;
+	return TRUE;
 }
 
 /**
@@ -904,12 +1046,19 @@ pk_backend_finalize (GObject *object)
 
 	g_free (backend->priv->name);
 
+#ifdef PK_BUILD_DAEMON
 	g_object_unref (backend->priv->network);
-	g_object_unref (backend->priv->conf);
+#endif
+	g_key_file_unref (backend->priv->conf);
 	g_hash_table_destroy (backend->priv->eulas);
 
+	g_mutex_clear (&backend->priv->thread_hash_mutex);
+	g_hash_table_unref (backend->priv->thread_hash);
+
 	if (backend->priv->monitor != NULL)
 		g_object_unref (backend->priv->monitor);
+	if (backend->priv->transaction_inhibit_end_idle_id > 0)
+		g_source_remove (backend->priv->transaction_inhibit_end_idle_id);
 	if (backend->priv->handle != NULL)
 		g_module_close (backend->priv->handle);
 	G_OBJECT_CLASS (pk_backend_parent_class)->finalize (object);
@@ -932,7 +1081,15 @@ pk_backend_class_init (PkBackendClass *klass)
 void
 pk_backend_cancel (PkBackend *backend, PkBackendJob *job)
 {
+	GCancellable *cancellable;
 	g_return_if_fail (PK_IS_BACKEND (backend));
+	g_return_if_fail (PK_IS_BACKEND_JOB (job));
+
+	/* cancel */
+	cancellable = pk_backend_job_get_cancellable (job);
+	if (g_cancellable_is_cancelled (cancellable))
+		return;
+	g_cancellable_cancel (cancellable);
 
 	/* call into the backend */
 	backend->priv->desc->cancel (backend, job);
@@ -977,27 +1134,27 @@ pk_backend_get_categories (PkBackend *backend, PkBackendJob *job)
 }
 
 /**
- * pk_backend_get_depends:
+ * pk_backend_depends_on:
  */
 void
-pk_backend_get_depends (PkBackend *backend,
+pk_backend_depends_on (PkBackend *backend,
 			PkBackendJob *job,
 			PkBitfield filters,
 			gchar **package_ids,
 			gboolean recursive)
 {
 	g_return_if_fail (PK_IS_BACKEND (backend));
-	g_return_if_fail (backend->priv->desc->get_depends != NULL);
+	g_return_if_fail (backend->priv->desc->depends_on != NULL);
 
 	/* final pre-flight checks */
 	g_assert (pk_backend_job_get_vfunc_enabled (job, PK_BACKEND_SIGNAL_FINISHED));
 
-	pk_backend_job_set_role (job, PK_ROLE_ENUM_GET_DEPENDS);
+	pk_backend_job_set_role (job, PK_ROLE_ENUM_DEPENDS_ON);
 	pk_backend_job_set_parameters (job, g_variant_new ("(t^asb)",
 							   filters,
 							   package_ids,
 							   recursive));
-	backend->priv->desc->get_depends (backend, job, filters, package_ids, recursive);
+	backend->priv->desc->depends_on (backend, job, filters, package_ids, recursive);
 }
 
 /**
@@ -1020,6 +1177,46 @@ pk_backend_get_details (PkBackend *backend,
 	backend->priv->desc->get_details (backend, job, package_ids);
 }
 
+/**
+ * pk_backend_get_details_local:
+ */
+void
+pk_backend_get_details_local (PkBackend *backend,
+			      PkBackendJob *job,
+			      gchar **files)
+{
+	g_return_if_fail (PK_IS_BACKEND (backend));
+	g_return_if_fail (backend->priv->desc->get_details != NULL);
+
+	/* final pre-flight checks */
+	g_assert (pk_backend_job_get_vfunc_enabled (job, PK_BACKEND_SIGNAL_FINISHED));
+
+	pk_backend_job_set_role (job, PK_ROLE_ENUM_GET_DETAILS_LOCAL);
+	pk_backend_job_set_parameters (job, g_variant_new ("(^as)",
+							   files));
+	backend->priv->desc->get_details_local (backend, job, files);
+}
+
+/**
+ * pk_backend_get_files_local:
+ */
+void
+pk_backend_get_files_local (PkBackend *backend,
+			    PkBackendJob *job,
+			    gchar **files)
+{
+	g_return_if_fail (PK_IS_BACKEND (backend));
+	g_return_if_fail (backend->priv->desc->get_details != NULL);
+
+	/* final pre-flight checks */
+	g_assert (pk_backend_job_get_vfunc_enabled (job, PK_BACKEND_SIGNAL_FINISHED));
+
+	pk_backend_job_set_role (job, PK_ROLE_ENUM_GET_FILES_LOCAL);
+	pk_backend_job_set_parameters (job, g_variant_new ("(^as)",
+							   files));
+	backend->priv->desc->get_files_local (backend, job, files);
+}
+
 /**
  * pk_backend_get_distro_upgrades:
  */
@@ -1057,27 +1254,27 @@ pk_backend_get_files (PkBackend *backend,
 }
 
 /**
- * pk_backend_get_requires:
+ * pk_backend_required_by:
  */
 void
-pk_backend_get_requires (PkBackend *backend,
+pk_backend_required_by (PkBackend *backend,
 			 PkBackendJob *job,
 			 PkBitfield filters,
 			 gchar **package_ids,
 			 gboolean recursive)
 {
 	g_return_if_fail (PK_IS_BACKEND (backend));
-	g_return_if_fail (backend->priv->desc->get_requires != NULL);
+	g_return_if_fail (backend->priv->desc->required_by != NULL);
 
 	/* final pre-flight checks */
 	g_assert (pk_backend_job_get_vfunc_enabled (job, PK_BACKEND_SIGNAL_FINISHED));
 
-	pk_backend_job_set_role (job, PK_ROLE_ENUM_GET_REQUIRES);
+	pk_backend_job_set_role (job, PK_ROLE_ENUM_REQUIRED_BY);
 	pk_backend_job_set_parameters (job, g_variant_new ("(t^asb)",
 							   filters,
 							   package_ids,
 							   recursive));
-	backend->priv->desc->get_requires (backend, job, filters, package_ids, recursive);
+	backend->priv->desc->required_by (backend, job, filters, package_ids, recursive);
 }
 
 /**
@@ -1425,11 +1622,40 @@ pk_backend_repo_set_data (PkBackend *backend, PkBackendJob *job, const gchar *re
 	backend->priv->desc->repo_set_data (backend, job, repo_id, parameter, value);
 }
 
+/**
+ * pk_backend_repo_remove:
+ */
+void
+pk_backend_repo_remove (PkBackend *backend,
+			PkBackendJob *job,
+			PkBitfield transaction_flags,
+			const gchar *repo_id,
+			gboolean autoremove)
+{
+	g_return_if_fail (PK_IS_BACKEND (backend));
+	g_return_if_fail (backend->priv->desc->repo_remove != NULL);
+
+	/* final pre-flight checks */
+	g_assert (pk_backend_job_get_vfunc_enabled (job, PK_BACKEND_SIGNAL_FINISHED));
+
+	pk_backend_job_set_role (job, PK_ROLE_ENUM_REPO_REMOVE);
+	pk_backend_job_set_parameters (job, g_variant_new ("(tsb)",
+							   transaction_flags,
+							   repo_id,
+							   autoremove));
+	backend->priv->desc->repo_remove (backend,
+					  job,
+					  transaction_flags,
+					  repo_id,
+					  autoremove);
+}
+
 /**
  * pk_backend_what_provides:
  */
 void
-pk_backend_what_provides (PkBackend *backend, PkBackendJob *job, PkBitfield filters, PkProvidesEnum provides, gchar **values)
+pk_backend_what_provides (PkBackend *backend, PkBackendJob *job,
+			  PkBitfield filters, gchar **values)
 {
 	g_return_if_fail (PK_IS_BACKEND (backend));
 	g_return_if_fail (backend->priv->desc->what_provides != NULL);
@@ -1438,11 +1664,10 @@ pk_backend_what_provides (PkBackend *backend, PkBackendJob *job, PkBitfield filt
 	g_assert (pk_backend_job_get_vfunc_enabled (job, PK_BACKEND_SIGNAL_FINISHED));
 
 	pk_backend_job_set_role (job, PK_ROLE_ENUM_WHAT_PROVIDES);
-	pk_backend_job_set_parameters (job, g_variant_new ("(tu^as)",
+	pk_backend_job_set_parameters (job, g_variant_new ("(t^as)",
 							   filters,
-							   provides,
 							   values));
-	backend->priv->desc->what_provides (backend, job, filters, provides, values);
+	backend->priv->desc->what_provides (backend, job, filters, values);
 }
 
 /**
@@ -1463,25 +1688,6 @@ pk_backend_get_packages (PkBackend *backend, PkBackendJob *job, PkBitfield filte
 	backend->priv->desc->get_packages (backend, job, filters);
 }
 
-/**
- * pk_backend_upgrade_system:
- */
-void
-pk_backend_upgrade_system (PkBackend *backend, PkBackendJob *job, const gchar *distro_id, PkUpgradeKindEnum upgrade_kind)
-{
-	g_return_if_fail (PK_IS_BACKEND (backend));
-	g_return_if_fail (backend->priv->desc->upgrade_system != NULL);
-
-	/* final pre-flight checks */
-	g_assert (pk_backend_job_get_vfunc_enabled (job, PK_BACKEND_SIGNAL_FINISHED));
-
-	pk_backend_job_set_role (job, PK_ROLE_ENUM_UPGRADE_SYSTEM);
-	pk_backend_job_set_parameters (job, g_variant_new ("(su)",
-							   distro_id,
-							   upgrade_kind));
-	backend->priv->desc->upgrade_system (backend, job, distro_id, upgrade_kind);
-}
-
 /**
  * pk_backend_repair_system:
  */
@@ -1494,7 +1700,6 @@ pk_backend_repair_system (PkBackend *backend, PkBackendJob *job, PkBitfield tran
 	/* final pre-flight checks */
 	g_assert (pk_backend_job_get_vfunc_enabled (job, PK_BACKEND_SIGNAL_FINISHED));
 
-	pk_backend_job_set_role (job, PK_ROLE_ENUM_REPAIR_SYSTEM);
 	pk_backend_job_set_role (job, PK_ROLE_ENUM_REPAIR_SYSTEM);
 	pk_backend_job_set_transaction_flags (job, transaction_flags);
 	pk_backend_job_set_parameters (job, g_variant_new ("(t)",
@@ -1509,9 +1714,15 @@ static void
 pk_backend_init (PkBackend *backend)
 {
 	backend->priv = PK_BACKEND_GET_PRIVATE (backend);
-	backend->priv->conf = pk_conf_new ();
+#ifdef PK_BUILD_DAEMON
 	backend->priv->network = pk_network_new ();
+#endif
 	backend->priv->eulas = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+	backend->priv->thread_hash = g_hash_table_new_full (g_direct_hash,
+							    g_direct_equal,
+							    NULL,
+							    g_free);
+	g_mutex_init (&backend->priv->thread_hash_mutex);
 }
 
 /**
@@ -1520,10 +1731,11 @@ pk_backend_init (PkBackend *backend)
  * Return value: A new backend class backend.
  **/
 PkBackend *
-pk_backend_new (void)
+pk_backend_new (GKeyFile *conf)
 {
 	PkBackend *backend;
 	backend = g_object_new (PK_TYPE_BACKEND, NULL);
+	backend->priv->conf = g_key_file_ref (conf);
 	return PK_BACKEND (backend);
 }
 
