@@ -33,12 +33,17 @@
 #include <glib/gi18n.h>
 #include <packagekit-glib2/pk-debug.h>
 
-#include "pk-conf.h"
+#include "pk-cleanup.h"
 #include "pk-engine.h"
+#include "pk-shared.h"
 #include "pk-transaction.h"
 
-static guint exit_idle_time;
-static GMainLoop *loop;
+typedef struct {
+	GMainLoop	*loop;
+	PkEngine	*engine;
+	guint		 exit_idle_time;
+	guint		 timer_id;
+} PkMainHelper;
 
 /**
  * timed_exit_cb:
@@ -59,14 +64,14 @@ timed_exit_cb (GMainLoop *mainloop)
  * pk_main_timeout_check_cb:
  **/
 static gboolean
-pk_main_timeout_check_cb (PkEngine *engine)
+pk_main_timeout_check_cb (PkMainHelper *helper)
 {
 	guint idle;
-	idle = pk_engine_get_seconds_idle (engine);
+	idle = pk_engine_get_seconds_idle (helper->engine);
 	g_debug ("idle is %i", idle);
-	if (idle > exit_idle_time) {
-		g_warning ("exit!!");
-		g_main_loop_quit (loop);
+	if (idle > helper->exit_idle_time) {
+		g_main_loop_quit (helper->loop);
+		helper->timer_id = 0;
 		return FALSE;
 	}
 	return TRUE;
@@ -94,97 +99,32 @@ pk_main_sigint_cb (gpointer user_data)
 	return FALSE;
 }
 
-/**
- * pk_main_sort_backends_cb:
- **/
-static gint
-pk_main_sort_backends_cb (const gchar **store1,
-			  const gchar **store2)
-{
-	return g_strcmp0 (*store2, *store1);
-}
-
-/**
- * pk_main_set_auto_backend:
- **/
-static gboolean
-pk_main_set_auto_backend (PkConf *conf, GError **error)
-{
-	const gchar *tmp;
-	gboolean ret = TRUE;
-	gchar *name_tmp;
-	GDir *dir = NULL;
-	GPtrArray *array = NULL;
-
-	dir = g_dir_open (LIBDIR "/packagekit-backend", 0, error);
-	if (dir == NULL)
-		goto out;
-	array = g_ptr_array_new_with_free_func (g_free);
-	do {
-		tmp = g_dir_read_name (dir);
-		if (tmp == NULL)
-			break;
-		if (!g_str_has_prefix (tmp, "libpk_backend_"))
-			continue;
-		if (!g_str_has_suffix (tmp, G_MODULE_SUFFIX))
-			continue;
-		if (g_strstr_len (tmp, -1, "libpk_backend_dummy"))
-			continue;
-		if (g_strstr_len (tmp, -1, "libpk_backend_test"))
-			continue;
-
-		/* turn 'libpk_backend_test.so' into 'test' */
-		name_tmp = g_strdup (tmp + 14);
-		g_strdelimit (name_tmp, ".", '\0');
-		g_ptr_array_add (array,
-				 name_tmp);
-	} while (1);
-
-	/* need to sort by id predictably */
-	g_ptr_array_sort (array,
-			  (GCompareFunc) pk_main_sort_backends_cb);
-
-	/* set best backend */
-	if (array->len == 0) {
-		g_set_error_literal (error, 1, 0, "No backends found");
-		ret = FALSE;
-		goto out;
-	}
-	tmp = g_ptr_array_index (array, 0);
-	pk_conf_set_string (conf,
-			    "DefaultBackend",
-			    tmp);
-
-out:
-	if (array != NULL)
-		g_ptr_array_unref (array);
-	if (dir != NULL)
-		g_dir_close (dir);
-	return ret;
-}
-
 /**
  * main:
  **/
 int
 main (int argc, char *argv[])
 {
+	GMainLoop *loop = NULL;
+	GOptionContext *context;
+	PkMainHelper helper;
 	gboolean ret = TRUE;
 	gboolean disable_timer = FALSE;
 	gboolean version = FALSE;
 	gboolean timed_exit = FALSE;
 	gboolean immediate_exit = FALSE;
 	gboolean keep_environment = FALSE;
-	gchar *backend_name = NULL;
-	PkEngine *engine = NULL;
-	PkConf *conf = NULL;
-	GError *error = NULL;
-	GOptionContext *context;
+	gint exit_idle_time;
 	guint timer_id = 0;
+	_cleanup_error_free_ GError *error = NULL;
+	_cleanup_free_ gchar *backend_name = NULL;
+	_cleanup_free_ gchar *conf_filename = NULL;
+	_cleanup_keyfile_unref_ GKeyFile *conf = NULL;
+	_cleanup_object_unref_ PkEngine *engine = NULL;
 
 	const GOptionEntry options[] = {
 		{ "backend", '\0', 0, G_OPTION_ARG_STRING, &backend_name,
-		  /* TRANSLATORS: a backend is the system package tool, e.g. yum, apt */
+		  /* TRANSLATORS: a backend is the system package tool, e.g. hif, apt */
 		  _("Packaging backend to use, e.g. dummy"), NULL },
 		{ "disable-timer", '\0', 0, G_OPTION_ARG_NONE, &disable_timer,
 		  /* TRANSLATORS: if we should not monitor how long we are inactive for */
@@ -226,9 +166,6 @@ main (int argc, char *argv[])
 		goto exit_program;
 	}
 
-	/* don't let GIO start it's own session bus: http://bugzilla.gnome.org/show_bug.cgi?id=526454 */
-	setenv ("GIO_USE_VFS", "local", 1);
-
 	/* we don't actually need to do this, except it rules out the
 	 * 'it works from the command line but not service activation' bugs */
 #ifdef HAVE_CLEARENV
@@ -237,31 +174,37 @@ main (int argc, char *argv[])
 #endif
 
 	/* get values from the config file */
-	conf = pk_conf_new ();
-	pk_conf_set_bool (conf, "KeepEnvironment", keep_environment);
+	conf = g_key_file_new ();
+	conf_filename = pk_util_get_config_filename ();
+	ret = g_key_file_load_from_file (conf, conf_filename,
+					 G_KEY_FILE_NONE, &error);
+	if (!ret) {
+		g_print ("Failed to load config file: %s", error->message);
+		goto out;
+	}
+	g_key_file_set_boolean (conf, "Daemon", "KeepEnvironment", keep_environment);
 
 	/* log the startup */
 	syslog (LOG_DAEMON | LOG_DEBUG, "daemon start");
 
 	/* after how long do we timeout? */
-	exit_idle_time = pk_conf_get_int (conf, "ShutdownTimeout");
+	exit_idle_time = g_key_file_get_integer (conf, "Daemon", "ShutdownTimeout", NULL);
 	g_debug ("daemon shutdown set to %i seconds", exit_idle_time);
 
 	/* override the backend name */
 	if (backend_name != NULL) {
-		pk_conf_set_string (conf,
-				    "DefaultBackend",
-				    backend_name);
+		g_key_file_set_string (conf,
+				       "Daemon",
+				       "DefaultBackend",
+				       backend_name);
 	}
 
 	/* resolve 'auto' to an actual name */
-	backend_name = pk_conf_get_string (conf, "DefaultBackend");
-	if (g_strcmp0 (backend_name, "auto") == 0) {
-		ret  = pk_main_set_auto_backend (conf, &error);
+	backend_name = g_key_file_get_string (conf, "Daemon", "DefaultBackend", NULL);
+	if (backend_name == NULL || g_strcmp0 (backend_name, "auto") == 0) {
+		ret  = pk_util_set_auto_backend (conf, &error);
 		if (!ret) {
-			g_print ("Failed to resolve auto: %s",
-				 error->message);
-			g_error_free (error);
+			g_print ("Failed to resolve auto: %s", error->message);
 			goto out;
 		}
 	}
@@ -269,7 +212,7 @@ main (int argc, char *argv[])
 	loop = g_main_loop_new (NULL, FALSE);
 
 	/* create a new engine object */
-	engine = pk_engine_new ();
+	engine = pk_engine_new (conf);
 	g_signal_connect (engine, "quit",
 			  G_CALLBACK (pk_main_quit_cb), loop);
 
@@ -284,9 +227,7 @@ main (int argc, char *argv[])
 	ret = pk_engine_load_backend (engine, &error);
 	if (!ret) {
 		/* TRANSLATORS: cannot load the backend the user specified */
-		g_print ("Failed to load the backend: %s",
-			 error->message);
-		g_error_free (error);
+		g_print ("Failed to load the backend: %s", error->message);
 		goto out;
 	}
 
@@ -296,9 +237,12 @@ main (int argc, char *argv[])
 		g_timeout_add_seconds (20, (GSourceFunc) timed_exit_cb, loop);
 
 	/* only poll when we are alive */
-	if (exit_idle_time != 0 && !disable_timer) {
-		timer_id = g_timeout_add_seconds (5, (GSourceFunc) pk_main_timeout_check_cb, engine);
-		g_source_set_name_by_id (timer_id, "[PkMain] main poll");
+	if (exit_idle_time > 0 && !disable_timer) {
+		helper.engine = engine;
+		helper.exit_idle_time = exit_idle_time;
+		helper.loop = loop;
+		helper.timer_id = g_timeout_add_seconds (5, (GSourceFunc) pk_main_timeout_check_cb, &helper);
+		g_source_set_name_by_id (helper.timer_id, "[PkMain] main poll");
 	}
 
 	/* immediatly exit */
@@ -314,14 +258,8 @@ out:
 
 	if (timer_id > 0)
 		g_source_remove (timer_id);
-
 	if (loop != NULL)
 		g_main_loop_unref (loop);
-	g_object_unref (conf);
-	if (engine != NULL)
-		g_object_unref (engine);
-	g_free (backend_name);
-
 exit_program:
 	return 0;
 }
