@@ -25,18 +25,18 @@
 #include <glib-object.h>
 #include <glib/gstdio.h>
 
+#include "pk-cleanup.h"
 #include "pk-backend.h"
 #include "pk-backend-spawn.h"
-#include "pk-conf.h"
 #include "pk-dbus.h"
 #include "pk-engine.h"
 #include "pk-notify.h"
 #include "pk-spawn.h"
-#include "pk-time.h"
 #include "pk-transaction-db.h"
 #include "pk-transaction.h"
 #include "pk-transaction-private.h"
-#include "pk-transaction-list.h"
+#include "pk-scheduler.h"
+
 
 #define PK_TRANSACTION_ERROR_INPUT_INVALID	14
 
@@ -105,19 +105,8 @@ _g_test_loop_quit (void)
 
 /**********************************************************************/
 
-static guint number_messages = 0;
 static guint number_packages = 0;
 
-/**
- * pk_test_backend_message_cb:
- **/
-static void
-pk_test_backend_message_cb (PkBackend *backend, PkMessageEnum message, const gchar *details, gpointer data)
-{
-	g_debug ("details=%s", details);
-	number_messages++;
-}
-
 /**
  * pk_test_backend_finished_cb:
  **/
@@ -175,16 +164,17 @@ pk_test_backend_package_cb (PkBackend *backend, PkPackage *package, gpointer use
 static void
 pk_test_backend_func (void)
 {
-	PkBackend *backend;
-	PkBackendJob *job;
-	PkConf *conf;
 	const gchar *text;
 	gboolean ret;
 	const gchar *filename;
 	GError *error = NULL;
+	_cleanup_keyfile_unref_ GKeyFile *conf = NULL;
+	_cleanup_object_unref_ PkBackend *backend = NULL;
+	_cleanup_object_unref_ PkBackendJob *job = NULL;
 
 	/* get an backend */
-	backend = pk_backend_new ();
+	conf = g_key_file_new ();
+	backend = pk_backend_new (conf);
 	g_assert (backend != NULL);
 
 	/* create a config file */
@@ -208,16 +198,12 @@ pk_test_backend_func (void)
 	g_assert (!ret);
 
 	/* connect */
-	job = pk_backend_job_new ();
+	job = pk_backend_job_new (conf);
 	pk_backend_job_set_backend (job, backend);
 	pk_backend_job_set_vfunc (job,
 				  PK_BACKEND_SIGNAL_PACKAGE,
 				  (PkBackendJobVFunc) pk_test_backend_package_cb,
 				  NULL);
-	pk_backend_job_set_vfunc (job,
-				  PK_BACKEND_SIGNAL_MESSAGE,
-				  (PkBackendJobVFunc) pk_test_backend_message_cb,
-				  NULL);
 	pk_backend_job_set_vfunc (job,
 				  PK_BACKEND_SIGNAL_FINISHED,
 				  (PkBackendJobVFunc) pk_test_backend_finished_cb,
@@ -238,15 +224,14 @@ pk_test_backend_func (void)
 	pk_backend_accept_eula (backend, "license_foo");
 
 	/* load an invalid backend */
-	conf = pk_conf_new ();
-	pk_conf_set_string (conf, "DefaultBackend", "invalid");
+	g_key_file_set_string (conf, "Daemon", "DefaultBackend", "invalid");
 	ret = pk_backend_load (backend, &error);
 	g_assert_error (error, 1, 0);
 	g_assert (!ret);
 	g_clear_error (&error);
 
 	/* try to load a valid backend */
-	pk_conf_set_string (conf, "DefaultBackend", "dummy");
+	g_key_file_set_string (conf, "Daemon", "DefaultBackend", "dummy");
 	ret = pk_backend_load (backend, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
@@ -298,7 +283,7 @@ pk_test_backend_func (void)
 	pk_backend_reset_job (backend, job);
 	pk_backend_stop_job (backend, job);
 	g_object_unref (job);
-	job = pk_backend_job_new ();
+	job = pk_backend_job_new (conf);
 	pk_backend_job_set_backend (job, backend);
 
 	/* wait for a thread to return false (straight away) */
@@ -338,10 +323,6 @@ pk_test_backend_func (void)
 
 	/* stop the job again */
 	pk_backend_stop_job (backend, job);
-
-	g_object_unref (conf);
-	g_object_unref (job);
-	g_object_unref (backend);
 }
 
 static guint _backend_spawn_number_packages = 0;
@@ -372,20 +353,23 @@ static void
 pk_test_backend_spawn_func (void)
 {
 	PkBackendSpawn *backend_spawn;
-	PkBackend *backend;
-	PkBackendJob *job;
-	PkConf *conf;
 	const gchar *text;
 	gboolean ret;
 	gchar *uri;
+	GError *error = NULL;
+	_cleanup_keyfile_unref_ GKeyFile *conf = NULL;
+	_cleanup_object_unref_ PkBackend *backend = NULL;
+	_cleanup_object_unref_ PkBackendJob *job = NULL;
 
 	/* get an backend_spawn */
-	backend_spawn = pk_backend_spawn_new ();
+	conf = g_key_file_new ();
+	g_key_file_set_string (conf, "Daemon", "DefaultBackend", "test_spawn");
+	backend_spawn = pk_backend_spawn_new (conf);
 	g_assert (backend_spawn != NULL);
 
 	/* private copy for unref testing */
-	backend = pk_backend_new ();
-	job = pk_backend_job_new ();
+	backend = pk_backend_new (conf);
+	job = pk_backend_job_new (conf);
 	pk_backend_job_set_backend (job, backend);
 
 	/* get backend name */
@@ -401,9 +385,8 @@ pk_test_backend_spawn_func (void)
 	g_assert_cmpstr (text, ==, "test_spawn");
 
 	/* needed to avoid an error */
-	conf = pk_conf_new ();
-	pk_conf_set_string (conf, "DefaultBackend", "test_spawn");
-	ret = pk_backend_load (backend, NULL);
+	ret = pk_backend_load (backend, &error);
+	g_assert_no_error (error);
 	g_assert (ret);
 
 	/* test pk_backend_spawn_inject_data Percentage1 */
@@ -486,7 +469,7 @@ pk_test_backend_spawn_func (void)
 	g_object_unref (backend_spawn);
 
 	/* new */
-	backend_spawn = pk_backend_spawn_new ();
+	backend_spawn = pk_backend_spawn_new (conf);
 
 	/* set backend name */
 	ret = pk_backend_spawn_set_name (backend_spawn, "test_spawn");
@@ -506,6 +489,7 @@ pk_test_backend_spawn_func (void)
 
 	/* needed to avoid an error */
 	ret = pk_backend_load (backend, NULL);
+	g_assert (ret);
 
 	/* test search-name.sh running */
 	ret = pk_backend_spawn_helper (backend_spawn, job, "search-name.sh", "none", "bar", NULL);
@@ -523,59 +507,15 @@ pk_test_backend_spawn_func (void)
 
 	/* done */
 	g_object_unref (backend_spawn);
-
-	/* we ref'd it manually for checking, so we need to unref it */
-	g_object_unref (job);
-	g_object_unref (backend);
-	g_object_unref (conf);
-}
-
-static void
-pk_test_conf_func (void)
-{
-	PkConf *conf;
-	gchar *text;
-	gint value;
-
-	conf = pk_conf_new ();
-	g_assert (conf != NULL);
-
-	/* get the default backend */
-	text = pk_conf_get_string (conf, "DefaultBackend");
-	g_assert (text != NULL);
-	g_free (text);
-
-	/* get a string that doesn't exist */
-	text = pk_conf_get_string (conf, "FooBarBaz");
-	g_assert (text == NULL);
-	g_free (text);
-
-	/* get the shutdown timeout */
-	value = pk_conf_get_int (conf, "ShutdownTimeout");
-	g_assert (value != PK_CONF_VALUE_INT_MISSING);
-
-	/* get an int that doesn't exist */
-	value = pk_conf_get_int (conf, "FooBarBaz");
-	g_assert_cmpint (value, ==, PK_CONF_VALUE_INT_MISSING);
-
-	/* override a value */
-	pk_conf_set_string (conf, "FooBarBaz", "zif");
-	text = pk_conf_get_string (conf, "FooBarBaz");
-	g_assert_cmpstr (text, ==, "zif");
-	g_free (text);
-
-	g_object_unref (conf);
 }
 
 static void
 pk_test_dbus_func (void)
 {
-	PkDbus *dbus;
+	_cleanup_object_unref_ PkDbus *dbus = NULL;
 
 	dbus = pk_dbus_new ();
 	g_assert (dbus != NULL);
-
-	g_object_unref (dbus);
 }
 
 PkSpawnExitType mexit = PK_SPAWN_EXIT_TYPE_UNKNOWN;
@@ -615,9 +555,11 @@ cancel_cb (gpointer data)
 static void
 new_spawn_object (PkSpawn **pspawn)
 {
+	_cleanup_keyfile_unref_ GKeyFile *conf = NULL;
 	if (*pspawn != NULL)
 		g_object_unref (*pspawn);
-	*pspawn = pk_spawn_new ();
+	conf = g_key_file_new ();
+	*pspawn = pk_spawn_new (conf);
 	g_signal_connect (*pspawn, "exit",
 			  G_CALLBACK (pk_test_exit_cb), NULL);
 	g_signal_connect (*pspawn, "stdout",
@@ -636,11 +578,11 @@ idle_cb (gpointer user_data)
 static void
 pk_test_spawn_func (void)
 {
-	PkSpawn *spawn = NULL;
 	GError *error = NULL;
 	gboolean ret;
-	gchar **argv;
-	gchar **envp;
+	_cleanup_object_unref_ PkSpawn *spawn = NULL;
+	_cleanup_strv_free_ gchar **argv = NULL;
+	_cleanup_strv_free_ gchar **envp = NULL;
 
 	new_spawn_object (&spawn);
 
@@ -811,88 +753,23 @@ pk_test_spawn_func (void)
 	/* ask dispatcher to close (again) */
 	ret = pk_spawn_exit (spawn);
 	g_assert (!ret);
-
-	g_strfreev (argv);
-	g_strfreev (envp);
-	g_object_unref (spawn);
-}
-
-static void
-pk_test_time_func (void)
-{
-	PkTime *pktime = NULL;
-	gboolean ret;
-	guint value;
-
-	pktime = pk_time_new ();
-	g_assert (pktime != NULL);
-
-	/* get elapsed correctly at startup */
-	value = pk_time_get_elapsed (pktime);
-	g_assert_cmpint (value, <, 10);
-
-	/* ignore remaining correctly */
-	value = pk_time_get_remaining (pktime);
-	g_assert_cmpint (value, ==, 0);
-
-	g_usleep (1000*1000);
-
-	/* get elapsed correctly */
-	value = pk_time_get_elapsed (pktime);
-	g_assert_cmpint (value, >, 900);
-	g_assert_cmpint (value, <, 1100);
-
-	/* ignore remaining correctly when not enough entries */
-	value = pk_time_get_remaining (pktime);
-	g_assert_cmpint (value, ==, 0);
-
-	/* make sure we can add data */
-	ret = pk_time_add_data (pktime, 10);
-	g_assert (ret);
-
-	/* make sure we can get remaining correctly */
-	value = 20;
-	while (value < 60) {
-		pk_time_advance_clock (pktime, 2000);
-		pk_time_add_data (pktime, value);
-		value += 10;
-	}
-	value = pk_time_get_remaining (pktime);
-	g_assert_cmpint (value, >, 9);
-	g_assert_cmpint (value, <, 11);
-
-	/* reset */
-	g_object_unref (pktime);
-	pktime = pk_time_new ();
-
-	/* make sure we can do long times */
-	value = 10;
-	pk_time_add_data (pktime, 0);
-	while (value < 60) {
-		pk_time_advance_clock (pktime, 4*60*1000);
-		pk_time_add_data (pktime, value);
-		value += 10;
-	}
-	value = pk_time_get_remaining (pktime);
-	g_assert_cmpint (value, >=, 1199);
-	g_assert_cmpint (value, <=, 1201);
-
-	g_object_unref (pktime);
 }
 
 static void
 pk_test_transaction_func (void)
 {
-	PkTransaction *transaction = NULL;
 	gboolean ret;
 	GError *error = NULL;
 	GDBusNodeInfo *introspection;
+	_cleanup_object_unref_ PkTransaction *transaction = NULL;
+	_cleanup_keyfile_unref_ GKeyFile *conf = NULL;
 
 	introspection = pk_load_introspection (PK_DBUS_INTERFACE_TRANSACTION ".xml", NULL);
 	g_assert (introspection != NULL);
 
 	/* get PkTransaction object */
-	transaction = pk_transaction_new (introspection);
+	conf = g_key_file_new ();
+	transaction = pk_transaction_new (conf, introspection);
 	g_assert (transaction != NULL);
 
 	/* validate incorrect text */
@@ -907,21 +784,20 @@ pk_test_transaction_func (void)
 	g_assert (ret);
 	g_clear_error (&error);
 
-	g_object_unref (transaction);
 	g_dbus_node_info_unref (introspection);
 }
 
 static void
 pk_test_transaction_db_func (void)
 {
-	PkTransactionDb *db;
 	guint value;
 	gchar *tid;
 	gboolean ret;
 	gdouble ms;
-	gchar *proxy_http = NULL;
-	gchar *proxy_ftp = NULL;
 	GError *error = NULL;
+	_cleanup_object_unref_ PkTransactionDb *db = NULL;
+	_cleanup_free_ gchar *proxy_http = NULL;
+	_cleanup_free_ gchar *proxy_ftp = NULL;
 
 	/* remove the self check file */
 #if PK_BUILD_LOCAL
@@ -1037,55 +913,55 @@ pk_test_transaction_db_func (void)
 	g_assert (ret);
 	g_assert_cmpstr (proxy_http, ==, "127.0.0.1:80");
 	g_assert_cmpstr (proxy_ftp, ==, "127.0.0.1:21");
-
-	g_free (proxy_http);
-	g_free (proxy_ftp);
-	g_object_unref (db);
 }
 
 static PkTransactionDb *db = NULL;
 
 /**
- * pk_test_transaction_list_finished_cb:
+ * pk_test_scheduler_finished_cb:
  **/
 static void
-pk_test_transaction_list_finished_cb (PkTransaction *transaction, const gchar *exit_text, guint time, gpointer user_data)
+pk_test_scheduler_finished_cb (PkTransaction *transaction, const gchar *exit_text, guint time, gpointer user_data)
 {
 	_g_test_loop_quit ();
 }
 
 /**
- * pk_test_transaction_list_create_transaction:
+ * pk_test_scheduler_create_transaction:
  **/
 static gchar *
-pk_test_transaction_list_create_transaction (PkTransactionList *tlist)
+pk_test_scheduler_create_transaction (PkScheduler *tlist)
 {
 	gchar *tid;
+	gboolean ret;
+	GError *error = NULL;
 
 	/* get tid */
 	tid = pk_transaction_db_generate_id (db);
 
 	/* create PkTransaction instance */
-	pk_transaction_list_create (tlist, tid, ":org.freedesktop.PackageKit", NULL);
+	ret = pk_scheduler_create (tlist, tid, ":org.freedesktop.PackageKit", &error);
+	g_assert_no_error (error);
+	g_assert (ret);
 
 	return tid;
 }
 
 static void
-pk_test_transaction_list_func (void)
+pk_test_scheduler_func (void)
 {
-	PkTransactionList *tlist;
 	gboolean ret;
 	gchar *tid;
 	guint size;
 	gchar **array;
 	PkTransaction *transaction;
-	gchar *tid_item1;
-	gchar *tid_item2;
-	gchar *tid_item3;
-	PkBackend *backend;
-	PkConf *conf;
 	GError *error = NULL;
+	_cleanup_free_ gchar *tid_item1 = NULL;
+	_cleanup_free_ gchar *tid_item2 = NULL;
+	_cleanup_free_ gchar *tid_item3 = NULL;
+	_cleanup_keyfile_unref_ GKeyFile *conf = NULL;
+	_cleanup_object_unref_ PkBackend *backend = NULL;
+	_cleanup_object_unref_ PkScheduler *tlist = NULL;
 
 	/* remove the self check file */
 #if PK_BUILD_LOCAL
@@ -1104,50 +980,54 @@ pk_test_transaction_list_func (void)
 	g_assert (ret);
 
 	/* try to load a valid backend */
-	backend = pk_backend_new ();
-	conf = pk_conf_new ();
-	pk_conf_set_string (conf, "DefaultBackend", "dummy");
+	conf = g_key_file_new ();
+	backend = pk_backend_new (conf);
+	g_key_file_set_string (conf, "Daemon", "DefaultBackend", "dummy");
+	g_key_file_set_string (conf, "Daemon", "MaximumPackagesToProcess", "1000");
 	ret = pk_backend_load (backend, NULL);
 	g_assert (ret);
 
 	/* get a transaction list object */
-	tlist = pk_transaction_list_new ();
+	tlist = pk_scheduler_new (conf);
 	g_assert (tlist != NULL);
 
 	/* make sure we get a valid tid */
-	pk_transaction_list_set_backend (tlist, backend);
+	pk_scheduler_set_backend (tlist, backend);
 	tid = pk_transaction_db_generate_id (db);
 	g_assert (tid != NULL);
 
 	/* create a transaction object */
-	ret = pk_transaction_list_create (tlist, tid, ":org.freedesktop.PackageKit", NULL);
+	ret = pk_scheduler_create (tlist, tid, ":org.freedesktop.PackageKit", &error);
+	g_assert_no_error (error);
 	g_assert (ret);
 
 	/* make sure we get the right object back */
-	transaction = pk_transaction_list_get_transaction (tlist, tid);
+	transaction = pk_scheduler_get_transaction (tlist, tid);
 	g_assert (transaction != NULL);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_NEW);
 
 	/* get size one we have in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 1);
 
 	/* get transactions (committed, not finished) in progress */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 0);
 	g_strfreev (array);
 
 	/* add again the same tid (should fail) */
-	ret = pk_transaction_list_create (tlist, tid, ":org.freedesktop.PackageKit", NULL);
+	ret = pk_scheduler_create (tlist, tid, ":org.freedesktop.PackageKit", &error);
+	g_assert_error (error, 1, 0);
 	g_assert (!ret);
+	g_clear_error (&error);
 
 	/* remove without ever committing */
-	ret = pk_transaction_list_remove (tlist, tid);
+	ret = pk_scheduler_remove (tlist, tid);
 	g_assert (ret);
 
 	/* get size none we have in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 0);
 
 	/* get a new tid */
@@ -1155,14 +1035,15 @@ pk_test_transaction_list_func (void)
 	tid = pk_transaction_db_generate_id (db);
 
 	/* create another transaction */
-	ret = pk_transaction_list_create (tlist, tid, ":org.freedesktop.PackageKit", NULL);
+	ret = pk_scheduler_create (tlist, tid, ":org.freedesktop.PackageKit", &error);
+	g_assert_no_error (error);
 	g_assert (ret);
 
 	/* get from db */
-	transaction = pk_transaction_list_get_transaction (tlist, tid);
+	transaction = pk_scheduler_get_transaction (tlist, tid);
 	g_assert (transaction != NULL);
 	g_signal_connect (transaction, "finished",
-			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
+			  G_CALLBACK (pk_test_scheduler_finished_cb), NULL);
 
 	/* this tests the run-on-commit action */
 	pk_transaction_get_updates (transaction,
@@ -1171,83 +1052,81 @@ pk_test_transaction_list_func (void)
 				    NULL);
 
 	/* make sure transaction has correct flags */
-	transaction = pk_transaction_list_get_transaction (tlist, tid);
+	transaction = pk_scheduler_get_transaction (tlist, tid);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_RUNNING);
 
 	/* get present role */
-	ret = pk_transaction_list_role_present (tlist, PK_ROLE_ENUM_GET_UPDATES);
+	ret = pk_scheduler_role_present (tlist, PK_ROLE_ENUM_GET_UPDATES);
 	g_assert (ret);
 
 	/* get non-present role */
-	ret = pk_transaction_list_role_present (tlist, PK_ROLE_ENUM_SEARCH_NAME);
+	ret = pk_scheduler_role_present (tlist, PK_ROLE_ENUM_SEARCH_NAME);
 	g_assert (!ret);
 
 	/* get size we have in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 1);
 
 	/* get transactions (committed, not finished) in progress */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 1);
 	g_strfreev (array);
 
-//g_error ("Moo");
-
 	/* wait for Finished */
 	_g_test_loop_run_with_timeout (2000);
 
 	/* get size one we have in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 1);
 
 	/* get transactions (committed, not finished) in progress (none) */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 0);
 	g_strfreev (array);
 
 	/* remove already removed */
-	ret = pk_transaction_list_remove (tlist, tid);
+	ret = pk_scheduler_remove (tlist, tid);
 	g_assert (!ret);
 
 	/* wait for Cleanup */
 	_g_test_loop_wait (10000);
 
 	/* make sure queue empty */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 0);
 
 	g_free (tid);
 
 	/* create three instances in list */
-	tid_item1 = pk_test_transaction_list_create_transaction (tlist);
-	tid_item2 = pk_test_transaction_list_create_transaction (tlist);
-	tid_item3 = pk_test_transaction_list_create_transaction (tlist);
+	tid_item1 = pk_test_scheduler_create_transaction (tlist);
+	tid_item2 = pk_test_scheduler_create_transaction (tlist);
+	tid_item3 = pk_test_scheduler_create_transaction (tlist);
 
 	/* get all transactions in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 3);
 
 	/* get transactions (committed, not finished) committed */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 0);
 	g_strfreev (array);
 
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item1);
 	g_signal_connect (transaction, "finished",
-			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
+			  G_CALLBACK (pk_test_scheduler_finished_cb), NULL);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item2);
 	g_signal_connect (transaction, "finished",
-			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
+			  G_CALLBACK (pk_test_scheduler_finished_cb), NULL);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item3);
 	g_signal_connect (transaction, "finished",
-			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
+			  G_CALLBACK (pk_test_scheduler_finished_cb), NULL);
 
 	/* this starts one action */
 	array = g_strsplit ("dave", " ", -1);
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item1);
 	pk_transaction_make_exclusive (transaction);
 	pk_transaction_search_details (transaction,
 				       g_variant_new ("(t^as)",
@@ -1258,7 +1137,7 @@ pk_test_transaction_list_func (void)
 
 	/* this should be chained after the first action completes */
 	array = g_strsplit ("power", " ", -1);
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item2);
 	pk_transaction_make_exclusive (transaction);
 	pk_transaction_search_names (transaction,
 				     g_variant_new ("(t^as)",
@@ -1269,7 +1148,7 @@ pk_test_transaction_list_func (void)
 
 	/* this starts be chained after the second action completes */
 	array = g_strsplit ("paul", " ", -1);
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item3);
 	pk_transaction_make_exclusive (transaction);
 	pk_transaction_search_details (transaction,
 				       g_variant_new ("(t^as)",
@@ -1279,7 +1158,7 @@ pk_test_transaction_list_func (void)
 	g_strfreev (array);
 
 	/* get transactions (committed, not finished) in progress (all) */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 3);
 	g_strfreev (array);
@@ -1288,105 +1167,96 @@ pk_test_transaction_list_func (void)
 	_g_test_loop_run_with_timeout (10000);
 
 	/* get all transactions in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 3);
 
 	/* get transactions (committed, not finished) (two, first one finished) */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 2);
 	g_strfreev (array);
 
 	/* make sure transaction1 has correct flags */
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item1);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction2 has correct flags */
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item2);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_RUNNING);
 
 	/* make sure transaction3 has correct flags */
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item3);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_READY);
 
 	/* wait for second action */
 	_g_test_loop_run_with_timeout (10000);
 
 	/* get all transactions in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 3);
 
 	/* get transactions (committed, not finished) in progress (one) */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 1);
 	g_strfreev (array);
 
 	/* make sure transaction1 has correct flags */
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item1);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction2 has correct flags */
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item2);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction3 has correct flags */
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item3);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_RUNNING);
 
 	/* wait for third action */
 	_g_test_loop_run_with_timeout (10000);
 
 	/* get all transactions in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 3);
 
 	/* get transactions (committed, not finished) in progress (none) */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 0);
 	g_strfreev (array);
 
 	/* make sure transaction1 has correct flags */
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item1);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item1);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction2 has correct flags */
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item2);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item2);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction3 has correct flags */
-	transaction = pk_transaction_list_get_transaction (tlist, tid_item3);
+	transaction = pk_scheduler_get_transaction (tlist, tid_item3);
 	g_assert_cmpint (pk_transaction_get_state (transaction), ==, PK_TRANSACTION_STATE_FINISHED);
 
-	/* free tids */
-	g_free (tid_item1);
-	g_free (tid_item2);
-	g_free (tid_item3);
-
 	/* wait for Cleanup */
 	_g_test_loop_wait (10000);
 
 	/* get transactions in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, <, 3); /* at least one should have timed out */
 
 	/* get transactions (committed, not finished) in progress (neither - again) */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 0);
 	g_strfreev (array);
 
-	g_object_unref (tlist);
-	g_object_unref (backend);
 	g_object_unref (db);
-	g_object_unref (conf);
 }
 
 static void
-pk_test_transaction_list_parallel_func (void)
+pk_test_scheduler_parallel_func (void)
 {
-	PkTransactionList *tlist;
 	guint size;
 	gboolean ret;
 	guint i;
@@ -1394,14 +1264,15 @@ pk_test_transaction_list_parallel_func (void)
 	PkTransaction *transaction1;
 	PkTransaction *transaction2;
 	PkTransaction *transaction3;
-	gchar *tid_item1;
-	gchar *tid_item2;
-	gchar *tid_item3;
-	gchar *tid_item4;
-	gchar *tid_item5;
-	PkBackend *backend;
-	PkConf *conf;
 	GError *error = NULL;
+	_cleanup_free_ gchar *tid_item1 = NULL;
+	_cleanup_free_ gchar *tid_item2 = NULL;
+	_cleanup_free_ gchar *tid_item3 = NULL;
+	_cleanup_free_ gchar *tid_item4 = NULL;
+	_cleanup_free_ gchar *tid_item5 = NULL;
+	_cleanup_keyfile_unref_ GKeyFile *conf = NULL;
+	_cleanup_object_unref_ PkBackend *backend = NULL;
+	_cleanup_object_unref_ PkScheduler *tlist = NULL;
 
 	db = pk_transaction_db_new ();
 	ret = pk_transaction_db_load (db, &error);
@@ -1409,54 +1280,55 @@ pk_test_transaction_list_parallel_func (void)
 	g_assert (ret);
 
 	/* try to load a valid backend */
-	backend = pk_backend_new ();
-	conf = pk_conf_new ();
-	pk_conf_set_string (conf, "DefaultBackend", "dummy");
+	conf = g_key_file_new ();
+	g_key_file_set_string (conf, "Daemon", "MaximumPackagesToProcess", "1000");
+	g_key_file_set_string (conf, "Daemon", "DefaultBackend", "dummy");
+	backend = pk_backend_new (conf);
 	ret = pk_backend_load (backend, NULL);
 	g_assert (ret);
 
 	/* get a transaction list object */
-	tlist = pk_transaction_list_new ();
+	tlist = pk_scheduler_new (conf);
 	g_assert (tlist != NULL);
 
-	pk_transaction_list_set_backend (tlist, backend);
+	pk_scheduler_set_backend (tlist, backend);
 
 	/* create three instances in list */
-	tid_item1 = pk_test_transaction_list_create_transaction (tlist);
-	tid_item2 = pk_test_transaction_list_create_transaction (tlist);
-	tid_item3 = pk_test_transaction_list_create_transaction (tlist);
-	tid_item4 = pk_test_transaction_list_create_transaction (tlist);
-	tid_item5 = pk_test_transaction_list_create_transaction (tlist);
+	tid_item1 = pk_test_scheduler_create_transaction (tlist);
+	tid_item2 = pk_test_scheduler_create_transaction (tlist);
+	tid_item3 = pk_test_scheduler_create_transaction (tlist);
+	tid_item4 = pk_test_scheduler_create_transaction (tlist);
+	tid_item5 = pk_test_scheduler_create_transaction (tlist);
 
 	/* get all transactions in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 5);
 
 	/* get transactions (committed, not finished) committed */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 0);
 	g_strfreev (array);
 
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item1);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item1);
 	g_signal_connect (transaction1, "finished",
-			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item2);
+			  G_CALLBACK (pk_test_scheduler_finished_cb), NULL);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item2);
 	g_signal_connect (transaction1, "finished",
-			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item3);
+			  G_CALLBACK (pk_test_scheduler_finished_cb), NULL);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item3);
 	g_signal_connect (transaction1, "finished",
-			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item4);
+			  G_CALLBACK (pk_test_scheduler_finished_cb), NULL);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item4);
 	g_signal_connect (transaction1, "finished",
-			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item5);
+			  G_CALLBACK (pk_test_scheduler_finished_cb), NULL);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item5);
 	g_signal_connect (transaction1, "finished",
-			  G_CALLBACK (pk_test_transaction_list_finished_cb), NULL);
+			  G_CALLBACK (pk_test_scheduler_finished_cb), NULL);
 
 	/* this starts one action */
 	array = g_strsplit ("dave", " ", -1);
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item1);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item1);
 	pk_transaction_search_details (transaction1,
 				       g_variant_new ("(t^as)",
 						      pk_bitfield_value (PK_FILTER_ENUM_NONE),
@@ -1466,7 +1338,7 @@ pk_test_transaction_list_parallel_func (void)
 
 	/* run a second (and exclusive!) action in parallel */
 	array = g_strsplit ("libawesome;42;i386;debian", " ", -1);
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item2);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item2);
 	pk_transaction_skip_auth_checks (transaction1, TRUE);
 	pk_transaction_install_packages (transaction1,
 				       g_variant_new ("(t^as)",
@@ -1477,7 +1349,7 @@ pk_test_transaction_list_parallel_func (void)
 
 	/* run a third action in parallel */
 	array = g_strsplit ("power", " ", -1);
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item3);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item3);
 	pk_transaction_search_names (transaction1,
 				     g_variant_new ("(t^as)",
 						    pk_bitfield_value (PK_FILTER_ENUM_NONE),
@@ -1487,7 +1359,7 @@ pk_test_transaction_list_parallel_func (void)
 
 	/* run a fourth (and exclusive!) action in parallel */
 	array = g_strsplit ("foobar;1.1.0;i386;debian", " ", -1);
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item4);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item4);
 	pk_transaction_skip_auth_checks (transaction1, TRUE);
 	pk_transaction_install_packages (transaction1,
 				       g_variant_new ("(t^as)",
@@ -1497,7 +1369,7 @@ pk_test_transaction_list_parallel_func (void)
 	g_strfreev (array);
 
 	/* get transactions (committed, not finished) in progress (all should be RUNNING now) */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 4);
 	g_strfreev (array);
@@ -1506,20 +1378,20 @@ pk_test_transaction_list_parallel_func (void)
 	_g_test_loop_run_with_timeout (10000);
 
 	/* make sure transaction4 (second exclusive) has correct flags (should be waiting for transaction2 to complete) */
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item4);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item4);
 	g_assert_cmpint (pk_transaction_get_state (transaction1), ==, PK_TRANSACTION_STATE_READY);
 
 	/* make sure transaction3 (non-exlusive) is running (should still be running, because it was run at last) */
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item3);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item3);
 	g_assert_cmpint (pk_transaction_get_state (transaction1), ==, PK_TRANSACTION_STATE_RUNNING);
 
 	/* make sure transaction2 (exlusive) is running too */
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item2);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item2);
 	g_assert_cmpint (pk_transaction_get_state (transaction1), ==, PK_TRANSACTION_STATE_RUNNING);
 
 	/* run a fifth (non-exclusive) action in parallel to the running exclusive */
 	array = g_strsplit ("paul", " ", -1);
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item5);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item5);
 	pk_transaction_search_details (transaction1,
 				       g_variant_new ("(t^as)",
 						      pk_bitfield_value (PK_FILTER_ENUM_NONE),
@@ -1528,7 +1400,7 @@ pk_test_transaction_list_parallel_func (void)
 	g_strfreev (array);
 
 	/* get all transactions in queue */
-	size = pk_transaction_list_get_size (tlist);
+	size = pk_scheduler_get_size (tlist);
 	g_assert_cmpint (size, ==, 5);
 
 	/* wait for all non-exclusive actions to complete */
@@ -1538,15 +1410,15 @@ pk_test_transaction_list_parallel_func (void)
 		i++;
 
 		/* ensure transaction objects are up-to-date */
-		transaction1 = pk_transaction_list_get_transaction (tlist, tid_item1);
-		transaction2 = pk_transaction_list_get_transaction (tlist, tid_item3);
-		transaction3 = pk_transaction_list_get_transaction (tlist, tid_item5);
+		transaction1 = pk_scheduler_get_transaction (tlist, tid_item1);
+		transaction2 = pk_scheduler_get_transaction (tlist, tid_item3);
+		transaction3 = pk_scheduler_get_transaction (tlist, tid_item5);
 
 		if (i >= 100 ||
 		    transaction1 == NULL ||
 		    transaction2 == NULL ||
 		    transaction3 == NULL) {
-			g_print ("Dumping transaction-list state:\n%s\n", pk_transaction_list_get_state (tlist));
+			g_print ("Dumping scheduler state:\n%s\n", pk_scheduler_get_state (tlist));
 			g_warning ("did not reach state where all non-exclusive transactions are finished");
 			g_assert_not_reached ();
 		}
@@ -1558,7 +1430,7 @@ pk_test_transaction_list_parallel_func (void)
 	}
 
 	/* we should have two exlusive transactions left */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 2);
 	g_strfreev (array);
@@ -1567,37 +1439,27 @@ pk_test_transaction_list_parallel_func (void)
 	_g_test_loop_run_with_timeout (10000);
 
 	/* make sure transaction2 (first exclusive) is FINISHED */
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item2);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item2);
 	g_assert_cmpint (pk_transaction_get_state (transaction1), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* make sure transaction4 (second exclusive) is RUNNING now */
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item4);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item4);
 	g_assert_cmpint (pk_transaction_get_state (transaction1), ==, PK_TRANSACTION_STATE_RUNNING);
 
 	/* wait for last exclusive transaction to complete */
 	_g_test_loop_run_with_timeout (20000);
 
 	/* make sure transaction4 (second exclusive) is now finished too */
-	transaction1 = pk_transaction_list_get_transaction (tlist, tid_item4);
+	transaction1 = pk_scheduler_get_transaction (tlist, tid_item4);
 	g_assert_cmpint (pk_transaction_get_state (transaction1), ==, PK_TRANSACTION_STATE_FINISHED);
 
 	/* we shouldn't have transactions left */
-	array = pk_transaction_list_get_array (tlist);
+	array = pk_scheduler_get_array (tlist);
 	size = g_strv_length (array);
 	g_assert_cmpint (size, ==, 0);
 	g_strfreev (array);
 
-	/* free tids */
-	g_free (tid_item1);
-	g_free (tid_item2);
-	g_free (tid_item3);
-	g_free (tid_item4);
-	g_free (tid_item5);
-
-	g_object_unref (tlist);
-	g_object_unref (backend);
 	g_object_unref (db);
-	g_object_unref (conf);
 }
 
 int
@@ -1608,22 +1470,21 @@ main (int argc, char **argv)
 #endif
 	g_test_init (&argc, &argv, NULL);
 
+#ifndef PK_ENABLE_DAEMON_TESTS
 	/* don't run when using make distcheck */
-	if (g_strcmp0 (DEFAULT_BACKEND, "dummy") == 0)
-		return 0;
+	return 0;
+#endif
 
 #ifndef PK_BUILD_LOCAL
 	g_warning ("you need to compile with --enable-local for make check support");
 #endif
 
 	/* components */
-	g_test_add_func ("/packagekit/time", pk_test_time_func);
 	g_test_add_func ("/packagekit/dbus", pk_test_dbus_func);
-	g_test_add_func ("/packagekit/conf", pk_test_conf_func);
 	g_test_add_func ("/packagekit/spawn", pk_test_spawn_func);
 	g_test_add_func ("/packagekit/transaction", pk_test_transaction_func);
-	g_test_add_func ("/packagekit/transaction-list", pk_test_transaction_list_func);
-	g_test_add_func ("/packagekit/transaction-list-parallel", pk_test_transaction_list_parallel_func);
+	g_test_add_func ("/packagekit/scheduler", pk_test_scheduler_func);
+	g_test_add_func ("/packagekit/scheduler-parallel", pk_test_scheduler_parallel_func);
 	g_test_add_func ("/packagekit/transaction-db", pk_test_transaction_db_func);
 
 	/* backend stuff */
