@@ -26,7 +26,6 @@
 #include <packagekit-glib2/pk-enum.h>
 #include <packagekit-glib2/pk-results.h>
 
-#include "pk-conf.h"
 #include "pk-backend.h"
 
 G_BEGIN_DECLS
@@ -53,51 +52,37 @@ typedef struct
 typedef enum {
 	PK_TRANSACTION_STATE_NEW,
 	PK_TRANSACTION_STATE_WAITING_FOR_AUTH,
-	PK_TRANSACTION_STATE_COMMITTED,
 	PK_TRANSACTION_STATE_READY,
 	PK_TRANSACTION_STATE_RUNNING,
 	PK_TRANSACTION_STATE_FINISHED,
+	PK_TRANSACTION_STATE_ERROR,
 	PK_TRANSACTION_STATE_UNKNOWN
 } PkTransactionState;
 
 GQuark		 pk_transaction_error_quark			(void);
 GType		 pk_transaction_get_type			(void);
-PkTransaction	*pk_transaction_new				(GDBusNodeInfo	*introspection);
+PkTransaction	*pk_transaction_new				(GKeyFile		*conf,
+								 GDBusNodeInfo	*introspection);
 
 /* go go go! */
 gboolean	 pk_transaction_run				(PkTransaction	*transaction)
 								 G_GNUC_WARN_UNUSED_RESULT;
 /* internal status */
 void		 pk_transaction_cancel_bg			(PkTransaction	*transaction);
+gboolean	 pk_transaction_get_background			(PkTransaction	*transaction);
 PkRoleEnum	 pk_transaction_get_role			(PkTransaction	*transaction);
 guint		 pk_transaction_get_uid				(PkTransaction	*transaction);
-PkConf		*pk_transaction_get_conf			(PkTransaction	*transaction);
 void		 pk_transaction_set_backend			(PkTransaction	*transaction,
 								 PkBackend	*backend);
 PkBackendJob	*pk_transaction_get_backend_job 		(PkTransaction	*transaction);
-PkResults	*pk_transaction_get_results			(PkTransaction	*transaction);
-gchar		**pk_transaction_get_package_ids		(PkTransaction	*transaction);
-PkBitfield	 pk_transaction_get_transaction_flags		(PkTransaction	*transaction);
-void		 pk_transaction_set_package_ids			(PkTransaction	*transaction,
-								 gchar		**package_ids);
-gchar		**pk_transaction_get_values			(PkTransaction	*transaction);
-gchar		**pk_transaction_get_full_paths			(PkTransaction	*transaction);
-void		 pk_transaction_set_full_paths			(PkTransaction	*transaction,
-								 gchar		**full_paths);
 PkTransactionState pk_transaction_get_state			(PkTransaction	*transaction);
-gboolean	 pk_transaction_set_state			(PkTransaction	*transaction,
+void		 pk_transaction_set_state			(PkTransaction	*transaction,
 								 PkTransactionState state);
 const gchar	*pk_transaction_state_to_string			(PkTransactionState state);
 const gchar	*pk_transaction_get_tid				(PkTransaction	*transaction);
 gboolean	 pk_transaction_is_exclusive			(PkTransaction	*transaction);
-void		 pk_transaction_add_supported_content_type	(PkTransaction	*transaction,
-								 const gchar	*mime_type);
 void		 pk_transaction_set_supported_roles		(PkTransaction	*transaction,
 								 GPtrArray	*plugins);
-void		 pk_transaction_set_plugins			(PkTransaction	*transaction,
-								 GPtrArray	*plugins);
-void		 pk_transaction_signals_reset			(PkTransaction	*transaction,
-								 PkBackendJob	*job);
 gboolean	 pk_transaction_is_finished_with_lock_required	(PkTransaction *transaction);
 void		 pk_transaction_reset_after_lock_error		(PkTransaction *transaction);
 void		 pk_transaction_make_exclusive			(PkTransaction *transaction);
